/*
* ============================================================================
* <p>
* Copyright (C) 2010 Nokia.  All rights reserved.
* <p>
* This material, including documentation and any related computer
* programs, is protected by copyright controlled by Nokia.  All
* rights are reserved.  Copying, including reproducing, storing,
* adapting or translating, any or all of this material requires the
* prior written consent of Nokia.  This material also contains
* confidential information which may not be disclosed to others
* without the prior written consent of Nokia.
* <p>
* ============================================================================
*
*/

/**
 * @fileOverview
 * This file provides email value validator.
 */
ovi.provide("ope.models.validators.EmailValidator");
ovi.require("ope.internals.common.Constants");
ovi.require("ope.models.validators.Validator");

ovi.declare("ope.models.validators.EmailValidator",
    /** @lend ope.models.validators.EmailValidator.prototype */ {
    /** Base class. */
    Extends: ope.models.validators.Validator,

    NOA_EMAIL_ALLOWED: /^[A-Za-z0-9_!#$%\*\/\?\|\^\{\}`~&'\+\-=]+(\.[A-Za-z0-9_!#$%\*\/\?\|\^\{\}`~&'\+\-=]+)*@[A-Za-z0-9\-]+(\.[A-Za-z0-9\-]+)*(\.[A-Za-z0-9\-]{2,6})$/,
    NOA_EMAIL_RESTRICTED: /^.*[\!\#\$\%\*\/\?\|\^\{\}\`\~\&\'\=]+.*$/,
    NOA_EMAIL_MIN_LENGTH: 1,
    NOA_EMAIL_MAX_LENGTH: 50,


    /** Value validation implementation. Otherwise exception is thrown. */
    _validate : function (value, validationResult) {
        //OPEQA-1976, jtuppura, Email can be empty
        if (!value) {
            return true;
        }

        debugger;
        //OPEQA-2138, jtuppura, email can be "@"
        if (value && value == "@") {
            return true;
        }

        if (!this._super(value, validationResult)) {
            return false;
        }

        // Validate syntax.
        if (!this._validateMail(value)) {
            validationResult.errorMessage = ope_error_incorrect_format_email_message;
            return (validationResult.valid = false);
        }

        //Validation passed successfully.
        return (validationResult.valid = true);
    },

    _validateMail : function(value) {
        if (value.length < this.NOA_EMAIL_MIN_LENGTH && value.length > this.NOA_EMAIL_MAX_LENGTH) {
            return false;
        }

        try {
            if (this.NOA_EMAIL_RESTRICTED.exec(value)) {
                return false;
            }
            if (!this.NOA_EMAIL_ALLOWED.exec(value)) {
                return false;
            }
            return true;
        } catch (e) {
            ovi.error("Validation exception happened in EmailValidator: " + e.toString());
        }
        return false;
    }
});