﻿/*
* ============================================================================
* <p>
* Copyright (C) 2010 Nokia.  All rights reserved.
* <p>
* This material, including documentation and any related computer
* programs, is protected by copyright controlled by Nokia.  All
* rights are reserved.  Copying, including reproducing, storing,
* adapting or translating, any or all of this material requires the
* prior written consent of Nokia.  This material also contains
* confidential information which may not be disclosed to others
* without the prior written consent of Nokia.
* <p>
* ============================================================================
*
*/

/**
 * @fileOverview
 * This file provides password value validator.
 */
ovi.provide("ope.models.validators.PasswordValidator");

ovi.require("ope.models.validators.Validator");

ovi.declare("ope.models.validators.PasswordValidator",
    /** @lend ope.models.validators.PasswordValidator.prototype */ {
    /** Base class. */
    Extends: ope.models.validators.Validator,

    // NOA regular expression patterns copied from:
    // http://devx.nokia.com/web/sso/document-library?p_p_id=20&p_p_lifecycle=1&p_p_state=exclusive&p_p_mode=
    // view&_20_struts_action=/document_library/get_file&_20_folderId=56313&_20_name=DLFE-2208.pdf
    NOA_PASSWORD_RESTRICTED: /^.*[\s]+.*$/,
    NOA_PASSWORD_MIN_LENGTH: 6,
    NOA_PASSWORD_MAX_LENGTH: 18,

    /** Value validation implementation. Otherwise exception is thrown. */
    _validate : function (value, validationResult) {
        if (!this._super(value, validationResult)) {
            return false;
        }
        // Validate syntax.
        if (value.length < this.NOA_PASSWORD_MIN_LENGTH || value.length > this.NOA_PASSWORD_MAX_LENGTH ||
            !this._validatePassword(value)) {
            validationResult.errorMessage = ope_widget_renter_password_message_password_not_valid;
            return (validationResult.valid = false);
        }

        // Validation passed successfully.
        return (validationResult.valid = true);
    },

    /** Helper to validate password value. */
    _validatePassword: function(value) {
        try {
            if (this.NOA_PASSWORD_RESTRICTED.exec(value)) {
                return false;
            }

            return true;
        } catch (e) {
            ovi.error("Validation exception happened in PasswordValidator: " + e.toString());
        }
        return false;
    }
});