/**
 *
 * Description : 
 * <p>
 * Filename    : SSOUI.js
 * <p>
 * Part of     : SSO JS UI Component
 * Description : This exposes the API's for external applications for using 
 * SSO functionalities 
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class ovi.serviceui.ssoui.SSOUI
 * @name ovi.serviceui.ssoui.SSOUI
 * @version %version:   %
 */

/**
 * Class to launch the SSOUI widget in an iframe. 
 * This class is exposed to the clients.
 * 
 * 
 */ 
 //@TODO: CR: Add space before closing parenthesis. 
 //@TODO: CR: Why do we need name space for SSOUI in upper case? 
 //@TODO: CR: Why SSOConstant & SSOUtil is still under lazy loading?
 
 ovi.provide( 'ovi.serviceui.ssoui.SSOUI' );
 ovi.require( 'ovi.ConsoleLogger');
 ovi.require( 'ovi.service.sfwapi', false );
 ovi.require( 'ovi.service.sfwiter', false );
 ovi.require( 'ovi.service.exceptions', false );
 ovi.require( 'ovi.service.ApplicationManagement', false );
 ovi.require( 'ovi.service.EventMessage', false );
 ovi.require( 'ovi.service.sso.SSO', false);
 ovi.require( 'ovi.serviceui.ssoui.utils.SSOConstant',false)
 ovi.require( 'ovi.serviceui.ssoui.utils.SSOUtil',false);
 
 /**
  * @class ovi.serviceui.ssoui.SSOUI
  */   
 ovi.declare( 'ovi.serviceui.ssoui.SSOUI', /** @lends ovi.serviceui.ssoui.SSOUI */{  
 
	/**
	 * Function to initialize required elements
	 * 
	 * @function initialize
	 */
	 initialize: function() {
	  	// no implementation
	  },   
	
	//@TODO: CR: MANDATED
	//@TODO: CR: rename ssobaseurl to deploymentMode. Create a constant / enum
	//@TODO: CR: Re-arrange the parameters description in sync with the 
	//			config object
	//@TODO: CR: Return not specified. If nothing is returned, say void.
	//@TODO: CR: Doc missing for kind of event listners required & appropriate
	//			action on each of them.
	//@TODO: CR: In sample, add a snippet for Callback method.
   /**
    * Function to launch the SSOJSUI widget
    * @function launch
    * @example
    * Sample code for launching SSOJSUI
    *     
    *     this.ssoui = new ovi.serviceui.ssoui.SSOUI();
    *     var _useCase = "Sign In";
    *     var baseurl =  "Nabbi";
    *     var consumerKey = "e8f928d703804ceba4dffe6cce52b089";
    *     var consumerSecret = "xFeE9mGA2XW4T7k1Qkl91mY32WzANkdIu0CTzOAbNiWCaSzU8dpHyyvAR+gw8Zo7";    *     
    *     var _baseurl = Number(baseurl);
    *     //Get the force SignIn value set by the user.
    *     var _forceSignIn = document.getElementById("forceSignIn").value;
    *     var _serviceId = "ovi";
    *     var config = { ssoUIContext: _useCase,
    *                   soUIEventListener: this.listenSSOEvents,
    *               	ssoConsumerKey: consumerKey,
    *               	ssoConsumerSecret: consumerSecret,
    *               	ssoServiceId: _serviceId,
    *               	ssoForceSignIn: _forceSignIn,
    *               	ssobaseurl:_baseurl
    *                 };
    *     this.ssoui.launch(config);
    *
    * @param wconfig {object}
    *     
    * Object that contains these properties: <i>ssoUIContext, ssoConsumerKey, ssoConsumerSecret, ssobaseurl, ssoServiceId, ssoForceSignIn</i><br><br>  	 
    * Here is the description for these properties: <p>
    * <b>ssoUIContext</b>		   : The context for which the widget should be launched.[SignIn,AccountManagement]<p>
    * <b>soUIEventListener</b>	   : This call-back function is triggered when (a) an operation is completed (b) SSOUI JS is cancelled. (c) Error conditions. Parameter passed in call-back is a JSON String. 	 
    * <b>ssoConsumerKey</b>		   : Consumer key of the client application.<p>
    * <b>ssoConsumerSecret</b>	   : Consumer secret of the client application.<p>     	 
    * <b>ssobaseurl</b>		       : URL of the server<p>
    * <b>ssoServiceId</b>		   : Service ID of the client application<p>     	 
    * <b>ssoForceSignIn</b>		   : Set <i>true</i> if you want to bring Sign In screen all the time <i>false</i> for default behaviour.<p>	 
    */
    launch: function(wconfig) {
		
		//@TODO: CR: MANDATED:
		//		Validation of non-undefined values for each var expected.
		// 		For misconfiguration, display appropriate error. 
		  this.ssoConfig = wconfig;  
		  //Create the authentictaion object here. 
		  //To keep the session alive  so that a valid token can be returned to the client
		  //@TODO: CR: Use '!==' while comparing undefined
		  if(typeof ovi.serviceui.ssoui.authobj != "undefined") {
			  ovi.debug("Authobj already exixts calling _onNoaAuthenticationLoaded");
			  //@TODO: CR: Why do we need _self here? 
			  // 		Below method is not called async?
			  var _self = this;
			  this._onNoaAuthenticationLoaded(_self);
		  } else {	  
			  ovi.debug("calling createNoaAuthentication");
			  //@TODO: CR: MANDATED: Below method is local method
			  //		Remove passing of all paramters, as it can access this.ssoConfig
			  this.createNoaAuthentication(wconfig.ssoConsumerKey, wconfig.ssoConsumerSecret,wconfig.ssobaseurl);
		  }
    },
	
    /**
	 * Function to listen to all the events occurring on the SSOUI on complete/cancel scenario.
	 * @function eventReceived
         * @param {value} e:  the message object received from the widget
         * @param {obj} aContext: the calling class pointer
	 */
    eventReceived: function(e, aContext) {
        //Fetch the information from the message object recieved
        //the format is - eventtype and eventvalue
        var data       = e.data.toString();    
        var regexindex = data.search(/,/);
        var eventType  = data.slice(0, regexindex);  
        var eventValue = data.slice(regexindex + 1);   
        this.handleCancel(eventType, eventValue);      
        //If there is a callback provided by the client application
        // then pass the message to the client
        if(aContext.ssoConfig.ssoUIEventListener) {        
            aContext.ssoConfig.ssoUIEventListener(eventType,eventValue);
        }
    },
    
    /**
	 * Function to close the SSOUI iframe. 
	 * @function handleCancel
         * @param {value} aEventType - the usecase
	 * @param {value} aEventValues - the value of the event - completion/cancel/error
	 */
    handleCancel: function(aEventType, aEventValues) {      
        //Parse the event values to get the objects
        var eventvaluesobj = JSON.parse(aEventValues);                                            
        // If the status message is cancelled or Exit then we need to remove the iframe and 
        // Go back to client, also if we have successfully signed in, then we need to remove the
        // iframe. If we have successfully signed in from account management then we are not removing
        // the ssoui iframe
        if(eventvaluesobj.statusMessage == "Cancelled" || eventvaluesobj.statusMessage == "Exit" || eventvaluesobj.statusCode == "Completed" || eventvaluesobj.statusMessage == "Error" ) 
        {
            var container = document.getElementById("ssouiiframecontainer");
            document.body.removeChild(container);
        }
    },
    
    /**
     * Function to create the NoA authentication. 
     * @function createNoaAuthentication
     * @param {var} aConsumerKey:	Consumer key
     * @param {var} aConsumerSecret:	Consumer secret
     * @param {int} aBaseurl:		For testing purpose only and is an optional parameter. 
     *					If not provided, it will be set to '3' by default.     
     */
	//@TODO:CR: MANDATED: This func is now local. Use _method.
	// 			Remove parameters as well.
     createNoaAuthentication: function(aConsumerKey, aConsumerSecret, aBaseurl) {
    	ovi.debug("Inside createNoaAuthentication");
        
        var _self = this; 
        //Load the authentication plugin. Its an async call    
		//@TODO: CR: Rename this.initAuthObj to initAuthCB. Confusing terminology
		//		for Object / function call back.
		//@TODO: CR: Use Try/Catch for failure. 
		//			Display error if required. 
        this._authObj = new ovi.service.sso.NoaAuthentication(this.initAuthObj, _self);
        
        ovi.debug("Exit createNoaAuthentication");
     },
     
	 //@TODO: CR: Function description block does not follow guidelines.
     //Callback function when the authentication plugin is loaded.
     initAuthObj: function(aContext) {
        var baseurl;
        //Check if the base url is given by the user,
        //This is an optional param and is used for testing purpose only
		//@TODO: CR: Use '===' for comparing undefined.
         if (aContext.ssoConfig.ssobaseurl == "undefined") {
            //Production server
			//@TODO: CR: Remove MAGICAL #s. Use Constant Enumeration. 
			//			Wrong variable Name. Usage eg: deploymentModel.
            baseurl = 2;
        } else {
            baseurl = aContext.ssoConfig.ssobaseurl;
        }   
     	
        //Init the authentication object with the provided consumer key and secret.    
		//@TODO: CR: Error not handled within TRY / Catch block 	 
        aContext._authObj.initialiseAsync(aContext._onNoaAuthenticationLoaded, aContext.ssoConfig.ssoConsumerKey,aContext.ssoConfig.ssoConsumerSecret,new ConnectionDetail(baseurl), aContext);
     },
     
	 //@TODO: CR: Function description is missing
	 //			@return void is missing
     /**
      *@function  _onNoaAuthenticationCreate
      */
     _onNoaAuthenticationLoaded: function(aContext) {
	 	//@TODO: CR: Unable to read below english.
    	 //aContext._authObj will be undefined, if the global ovi.serviceui.ssoui.authobj is already present.
    	 if(aContext._authObj) {
    		 ovi.serviceui.ssoui.authobj = aContext._authObj;
    	 }
    	 
    	 ovi.debug("inside _onNoaAuthenticationLoaded");
    	 try {
		 	ovi.debug("Check for presence of a valid token");
			
	    	 if(aContext.ssoConfig.ssoForceSignIn == false && 
			 (ovi.serviceui.ssoui.authobj.token().toString().length > 0) &&  
			 (aContext.ssoConfig.ssoUIContext == SSOConstant.SignIn)) {
				//@TODO: CR: Missing documentation on business logic
				ovi.debug("before dummy sign in");
				//@TODO: CR: What is magical # 2 (Remember me - settings unchanged)?
				//@TODO: CR: General comment: For all magical numbers, use enum
				ovi.serviceui.ssoui.authobj.signIn(aContext._signInCallback, "", "", 2, aContext);
				ovi.debug("after calling dummy sign-in");
	    	 } else {
                ovi.debug("isAuthenticated/force sign in is false");
	    		aContext._launchUI(); 
	    	 }
    	 } catch(ex) {
		 	//@TODO: CR: Use ovi.error logging
			//@TODO: CR: Trigger error call back
    		 ovi.debug("Error: " + ex);
    	 }
     },
     
	 //@TODO: CR: Function description, params, return is missing
	 /**
      * @function _launchUI
      */
     _launchUI: function() {
	 	//@TODO: CR: use _self instead of this.
    	 var _this = this;
         // Save the values in global namespace so that the sendparams() function can access.
         //parameters are required to launch the widget 	
         ovi.serviceui.ssoui.ssoUIContext       = this.ssoConfig.ssoUIContext; 
         ovi.serviceui.ssoui.ssoConsumerKey     = this.ssoConfig.ssoConsumerKey;
         ovi.serviceui.ssoui.ssoConsumerSecret  = this.ssoConfig.ssoConsumerSecret;
         ovi.serviceui.ssoui.ssobaseurl         = this.ssoConfig.ssobaseurl;
         ovi.serviceui.ssoui.ssoServiceId       = this.ssoConfig.ssoServiceId;
         ovi.serviceui.ssoui.ssoForceSignIn     = this.ssoConfig.ssoForceSignIn;

		//@TODO: CR: When this UI is relaunched for signIn Error, 
		//	We do not need to re-build everything. It can be skipped.

		 //@TODO: CR: Can use as stated below to avoid containerdiv.id
		 //	within the handleCancel method. 
		 //var this._containerDiv = document.createElement("div");

         var containerdiv = document.createElement("div");
         containerdiv.id = "ssouiiframecontainer";
         containerdiv.style.overflow = "hidden";
		 
		if(sisuConfig.useSharedLib) {
            var path = (sisuConfig.modulePaths['ovi.serviceui.ssoui']? sisuConfig.modulePaths['ovi.serviceui.ssoui'] :
                     sisuConfig.modulePaths['ovi.serviceui']? sisuConfig.modulePaths['ovi.serviceui']+'ssoui/' :
                     sisuConfig.oviRoot+'serviceui/ssoui/') + 'main.html';
		} else{
            var path = "libs/ovi1/serviceui/ssoui/main.html"; 
        }

		 
		 //TODO : Check with CP/Ovi.js on usage of this
		 //var path = (oviConfig.modulePaths['ovi.serviceui.ssoui']? oviConfig.modulePaths['ovi.serviceui.ssoui'] :
         //          oviConfig.modulePaths['ovi.serviceui']? oviConfig.modulePaths['ovi.serviceui']+'ssoui/' :
         //        oviRoot+'serviceui/ssoui/') + 'main.html';			
		 
         // This is the iframe which the clients would use for integration 
		 //@TODO: CR: id can be removed
         containerdiv.innerHTML = "<iframe name='ssouiframe' id = 'ssouiframe' src = '" + path + "' style='position:absolute;top:0px;left:0px;width:100%;height:100%;z-index:999' onload='JavaScript:SSOUI.sendParams();' frameborder='no'></iframe>";
         document.body.appendChild(containerdiv);
         
         // now listen to any event fired from widget 
         window.addEventListener("message", function(event) {_this.eventReceived(event, _this);}, false); 
     },
     
	 //@TODO: CR: Function description, params, return is missing
     /**
      * @function _signInCallback
      */
     _signInCallback: function(aError, aType, aRequestId, aContext) {
    	ovi.debug("inside _signIncallback"); 
		//@TODO: CR: Why do we need try/catch block here.
    	try {
	    	//If the sign in was successfull
    		if( aType == RequestType.requestSignIn && ( aError == ErrorCode.errorNone || aError == ErrorCode.errorAccountNotActivated ) ) {
				//@TODO: CR: Why ssoUIEventListener is checked for existence? 
				//		It must be defined in initialization.
	 			if(aContext.ssoConfig.ssoUIEventListener) {
	 				ovi.debug("Post the messsage to the service client");
	 				var eventType = aContext.ssoConfig.ssoUIContext; 
	 				var eventValue = ssoui.utils.SSOUtil.convertToJSONFormat(SSOConstant.Completed,SSOConstant.SignInCompleted);	
	 	            aContext.ssoConfig.ssoUIEventListener(eventType, eventValue);
	 	        }
	 		} else {
				//@TODO: CR: Add log in, which can be helpful in debugging by itself
	 			ovi.debug("launching UI");
	 			aContext._launchUI();
	 		}
    	} catch(ex) {
			//@TODO: CR: Notify using event notification for error.
    		ovi.debug("Exception in sign callback : "+ ex.message);
    	}
     },
    
	//@TODO: CR: Rename Baseurl. In description, remove '3'.
    /**
     * Function to return the authentication object to clients.
     * 
     * @function getNoaAuthentication
     * @param {var} aConsumerKey:	Consumer key
     * @param {var} aConsumerSecret:	Consumer secret
     * @param {function} aCallback:	API to be called when the object is loaded
     * @param {obj} aContext:		Calling object pointer
     * @param {int} aBaseurl:		For testing purposes only and is an optional parameter 
     *					If not provided, it will be set to '3' by default
     * @return {obj} authObj: 	Newly created auth object
     */
     getNoaAuthentication: function(aConsumerKey, aConsumerSecret, aCallback, aContext, aBaseurl) {                      
    	 //Declare the authentictaion object
         var authObj; 
         //Check if the base url is given by the user,
         //This is an optional param and is used for testing purpose only
          if (aBaseurl == "undefined") {   
		  	//@TODO: CR: No magical number. Use enum   
			//@TODO: CR: MANDATED. use var baseurl to force local otherwise it
			//		is right now as global.  
             baseurl = 2;
         } else {
             baseurl = aBaseurl; 
         }
          
         //Callback function when the authentictaion plugin is loaded.
         function _initAuthObj() {
             //Init the authentication object with the provided consumer key and secret.
        	 authObj.initialise(aConsumerKey,aConsumerSecret,new ConnectionDetail(baseurl));   
             //Object is initilizaed. Provide the callback
             aCallback( authObj, aContext );   
         }        
		 //@TODO: CR: Use try-catch around below code.
          //Load the authentication plugin. Its an async call    
         authObj = new ovi.service.sso.NoaAuthentication(_initAuthObj);
     },
     
	//@TODO: CR: Rename Baseurl. In description, remove '3'.
     /**
     * Function to return the registration object to the clients.
     * @function getNoaRegistration
     * @param {var} aConsumerKey:	Consumer key
     * @param {var} aConsumerSecret:	Consumer secret
     * @param {function} aCallback:	API to be called when the object is loaded.
     * @param {obj} aContext:		calling objects pointer.
     * @param {int} aBaseurl:		For testing purposes only and is an optional parameter. 
     *					If not provided, it will be set to '3' by default.
     * @return {obj} regObj
     */
     getNoaRegistration: function(aConsumerKey, aConsumerSecret, aCallback, aContext, aBaseurl) {          
        //Declare the authentictaion object
        var regObj; 
        //Check if the base url is given by the user,
        //This is an optional param and is used for testing purpose only
         if (aBaseurl == "undefined") {     
		    //@TODO: CR: No magical number. Use enum   
			//@TODO: CR: MANDATED. use var baseurl to force local otherwise it
			//		is right now as global.  
            baseurl = 2;
        } else {
            baseurl = aBaseurl; 
        }     
        //Callback function when the registration plugin is loaded.
        function initRegObj() {
            //Init the Registration object with the provided consumer key and secret.
            regObj.initialise(aConsumerKey,aConsumerSecret,new ConnectionDetail(baseurl));   
            //Object is initilizaed. Provide the callback
            aCallback( regObj, aContext );   
        }        

		 //@TODO: CR: Use try-catch around below code.

         //Load the authentication plugin. Its an async call    
         regObj = new ovi.service.sso.NoaRegistration(initRegObj);   
     },
     
	//@TODO: CR: Rename Baseurl. In description, remove '3'.
   /**
     * Function to return the profile manager object to the clients.
     * @function getNoaProfileManager
     * @param {var} aConsumerKey - Consumer key
     * @param {var} aConsumerSecret - Consumer secret
     * @param {function} aCallback - API to be called when the object is loaded.
     * @param {obj} aContext - callinf objects pointer.
     * @param {int} aBaseurl - Testing purpose only and is an optional param. 
     *                         If not provided will be set to 3 by default.
     * @return {obj} profObj in the callback;
     */
     getNoaProfileManager: function(aConsumerKey, aConsumerSecret, aCallback, aContext, aBaseurl) {          
        //Declare the Profile Manager object
        var profObj; 
        //Check if the base url is given by the user,
        //This is an optional param and is used for testing purpose only
         if (aBaseurl == "undefined") {  
		    //@TODO: CR: No magical number. Use enum   
			//@TODO: CR: MANDATED. use var baseurl to force local otherwise it
			//		is right now as global.  		       
            baseurl = 2;
        } else {
            baseurl = aBaseurl; 
        }     
        //Callback function when the registration plugin is loaded.
        function initProfObj() {
            //Init the Registration object with the provided consumer key and secret.
            profObj.initialise(aConsumerKey,aConsumerSecret,new ConnectionDetail(baseurl));   
            //Object is initilizaed. Provide the callback
            aCallback( profObj, aContext );   
        }        

		 //@TODO: CR: Use try-catch around below code.
         //Load the authentication plugin. Its an async call    
         profObj = new ovi.service.sso.NoaProfileManager(initProfObj);   
     },
     
	//@TODO: CR: Rename Baseurl. In description, remove '3'.
    /**
     * Function to return the password manager object to the clients.
     * @function getNoaPasswordManager
     * @param {var} aConsumerKey - Consumer key
     * @param {var} aConsumerSecret - Consumer secret
     * @param {function} aCallback - API to be called when the object is loaded.
     * @param {obj} aContext - calling objects pointer.
     * @param {int} aBaseurl - Testing purpose only and is an optional param. 
     *                         If not provided will be set to 3 by default.
     * @return {obj} pswdMgrObj;
     */
     getNoaPasswordManager: function(aConsumerKey, aConsumerSecret, aCallback, aContext, aBaseurl) {          
        //Declare the Password Manager object
        var pswdMgrObj; 
        //Check if the base url is given by the user,
        //This is an optional param and is used for testing purpose only
         if (aBaseurl == "undefined") {        
		    //@TODO: CR: No magical number. Use enum   
			//@TODO: CR: MANDATED. use var baseurl to force local otherwise it
			//		is right now as global. 
            baseurl = 2;
        } else {
            baseurl = aBaseurl; 
        }     
        //Callback function when the registration plugin is loaded.
        function initPswdMgrObj() {
            //Init the Registration object with the provided consumer key and secret.
            pswdMgrObj.initialise( aConsumerKey, aConsumerSecret, new ConnectionDetail(baseurl));   
            //Object is initilizaed. Provide the callback
            aCallback( pswdMgrObj, aContext );   
        }        
		 //@TODO: CR: Use try-catch around below code.
		 //@TODO: CR: Below comment is not valid. Loads Password manager& not auth
         //Load the authentication plugin. Its an async call    
         pswdMgrObj = new ovi.service.sso.NoaPasswordManager(initPswdMgrObj);   
     }
});

//@TODO: CR: Function description is missing
//@TODO: CR: No magical hard-coding
//@TODO: CR: We need to move below method as a class with Initialize method
//		instead of just a function call. Usage of this inside it is sounding
//		dangerous. As learned it is this way only - due to dependency problem
//		please document the dependency reason.
//@TODO: CR: Same method is found in SSOApplicationController.js as well. Have
//	only 1 method.
function ConnectionDetail(aBaseurl) {       
    //Proxy settings
    this.proxyType = 1;
    //Time oout given as 1 min
    this.timeout = 60000;
    //Base url is set to 0 - nabbi    
    this.baseUrl = aBaseurl;    
};

//@TODO: CR: Use '==='
//@TODO: CR: Where is this code used?
if(typeof SSOUI == "undefined"){
	SSOUI={}; 
}

/**
 * Function called on completion of iframe loading. A JSON string is created and posted using the  HTML 5 postMessage API. 
 * @function sendParams	 
 */	
SSOUI.sendParams = function() {
  // JSON string contruction
  var json = '{"ssoUIContext":"' + ovi.serviceui.ssoui.ssoUIContext + '","ssoConsumerKey": "' + ovi.serviceui.ssoui.ssoConsumerKey + '", "ssoConsumerSecret": "' + ovi.serviceui.ssoui.ssoConsumerSecret +'","ssobaseurl": "' + ovi.serviceui.ssoui.ssobaseurl + '","ssoServiceId": "' + ovi.serviceui.ssoui.ssoServiceId + '","ssoForceSignIn": "' + ovi.serviceui.ssoui.ssoForceSignIn + '" }';
  // Send the JSON string  
  ssouiframe.postMessage(json, "*");
};