/**
 *
 * Description : A class that extends SSOWizardController
 *               Maintains the wizard for the signup usecase for account creation
 * <p>
 * Filename    : SSOAccCreateWizardController.js
 * <p>
 * Part of     : Controllers
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   23.2.6 %
 * @class SSOAccCreateWizardController
 * @name SSOAccCreateWizardController 
 */

ovi.provide('ssoui.controllers.SSOAccCreateWizardController');
ovi.require('ssoui.controllers.SSOWizardController');
ovi.require('ssoui.utils.SSOConstant',false);
ovi.require( 'ssoui.ui.SSOError');
ovi.require( 'ssoui.services.SSOCountryName', false );
ovi.require('ssoui.utils.SSOUtil', false);
ovi.declare('ssoui.controllers.SSOAccCreateWizardController',{
    
    /**
     * SSOAccCreateWizardController extends the SSOWizardController class.
     * @extends ssoui.controllers.SSOWizardController
     */
    Extends: ssoui.controllers.SSOWizardController,
    
    /**
     * Creates the objects needed for this controller
     * Calls the base class init function which initiliazes the noa objects needed
     * @function initialize
     */
    initialize: function() {
        this._super();
        this.model = null;
        //this.isCaptachRequired = false;
		//@TODO: CR: SEVERITY: HIGH: Move settings property-value to constant
        this.settings.set('isParentCreatedAcc', false);
        this.settings.set('isParentSignUp', false);
        this.settings.set('isParentalConsent', false);
        this.settings.set("isParentDenied", false);
    },
    	
    /**
     * function to call the register account API of the signup model 
     * @function doRegister
     */
    doRegister: function(aModel, aContext) {
        //@TODO: CR: Severity: CRITICAL Use !== instead of !=
		//@TODO: CR: Severity: HIGH. Is there a scenario when the view is not
		//        defined? 
    	if(typeof aContext.view != "undefined") {
    		aContext.view.showSpinner();
    		//aContext.view.disableLSK();
            //aContext.view.disableRSK();
		}
    	aModel.registerAccount(aContext.onRegisterComplete, aContext);    	
    },
    
    /**
     * callback function which will be triggered after parent account creation 
     * @function parentSignUpComplete
     */
    parentSignUpComplete: function(aResult, aErrorCode, aContext) {
		//@TODO: CR: CRITICAL: Use !==
    	if(typeof aContext.view != "undefined") {
    		aContext.view.hideProgress();
			//@TODO: CR: HIGH: Don't we need to enableRSK()?
    		aContext.view.enableLSK();
    	}

    	if(aErrorCode == ErrorCode.errorTooYoung) {
			aContext.applicationController.activate("SSOAccFailed");
    	} else {    	
		//@TODO: CR: HIGH: Use constants as property names. It avoids
		//        any property typo mistakes. 
			aContext.settings.set('isParentCreatedAcc', true);		
			aContext.settings.set('isParentSignUp', false);
			aContext.settings.set('isParentalConsent', true);
			aContext.addStep("SSOAccCreated", 2, false);
			aContext.addStep("SSOParentalConsent", 3, false);
			aContext.gotoStep(2);
    	}	
    },
    
	//@TODO: CR: MEDIUM: Below method is private. Use Prefix "_"
    /**
     * @private:
     * Callback which will be triggered after account creation.
     * @function onRegisterComplete
     */
    onRegisterComplete: function(aResult, aErrorCode, aContext) {
        //@TODO: CR: HIGH: Use constants as property names. It avoids
        //        any property typo mistakes. 
    	var _isParent = aContext.settings.get('isParentSignUp');
    	if(aResult == SSOConstant.Success) {  
		//@TODO: CR: MEDIUM: Below code news documentation on logic  		
    		if(_isParent) {			
    			var _model = this.getModel("SSOParentSignUp");
    			_model.setUsername(_model.getEmailid());
    			_model.signInAsGuardian(aContext.parentSignUpComplete ,aContext);
    		} else {
				//@TODO: CR: CRITICAL: Use !==. No need to have 'typeof'
    			if(typeof aContext.view != "undefined") {
    	    		aContext.view.hideProgress();
    	    		aContext.view.enableLSK();
                    aContext.view.enableRSK();
    	    	}
    			aContext.gotoNextStep();
    		}
    	} else {
    		
            //@TODO: CR: CRITICAL: Use !==. No need to have 'typeof'
    		if(typeof aContext.view != "undefined") {
        		aContext.view.hideProgress();
        		aContext.view.enableLSK();
                aContext.view.enableRSK();
        	}
    		
    		switch (aErrorCode) {
	            
    			case ErrorCode.errorAgeVerificationSimpleConsent :
    				try {
    					if(_isParent) {
    						this.applicationController.activate("SSOAccFailed");
    					} else {
    						var _model = aContext.model;
    						//getRegsiterationInfo throws exception
        					aContext.settings.set('childRegisterationInfo', _model.getRegsiterationInfo());
    						this.applicationController.activate("SSOPermission");
    					}
	    			} catch(ex) {
	    				ovi.error("Exception while retriving child info & activating parent sign-up  " +  ex + "  -  " + ex.message);
	    				var _errorMessage = SSOError.getErrorMessage(ErrorCode.errorGeneralError);
						SSOUIHelper.showWarning(_errorMessage);	    					    				
	    			}
	                break;
	            
	            case ErrorCode.errorAgeVerificationDisallowed :
	            	//@TODO: CR: CRITICAL Why do we need TRY-CATCH Block below?
	            	//@TODO: CR: CRITICAL Capture error in ovi.error                                                
	            	try {
	            		this.applicationController.activate("SSOAccFailed");
	            	} catch(ex) { 
	            		ovi.debug("Exception in SSOAccCreateWizardController.js " +  ex + "  -  " + ex.message); 
            		}
	                break;	                

                //@TODO: CR: MEDIUM:	            
				// Below few cases, where in we jump to step(1) can be clubed
	            case ErrorCode.errorInvalidPhoneNumber :
	            	aContext.gotoStep(1);
	            	var _errorMessage = SSOError.getErrorMessage(aErrorCode);
	            	SSOUIHelper.showWarning(_errorMessage);	            	
	                break;
	                
	            case ErrorCode.errorInvalidEmailAddress :
	            	aContext.gotoStep(1);
	            	var _errorMessage = SSOError.getErrorMessage(aErrorCode);
	            	SSOUIHelper.showWarning(_errorMessage);	            	
	                break;
	                
	            case ErrorCode.errorInvalidCountry :
	            	aContext.gotoStep(1);
	            	var _errorMessage = SSOError.getErrorMessage(aErrorCode);
	            	SSOUIHelper.showWarning(_errorMessage);	            	
	                break;
	                
	            case ErrorCode.errorDateOfbirthNotFound :
	            	aContext.gotoStep(1);
	            	var _errorMessage = SSOError.getErrorMessage(aErrorCode);
	            	SSOUIHelper.showWarning(_errorMessage);	            	
	            	break;
	            	
	            case ErrorCode.errorUsernameReserved :	            	
	            	aContext.gotoStep(0);
	            	var _errorMessage = SSOError.getErrorMessage(aErrorCode);
	            	SSOUIHelper.showWarning(_errorMessage);
	            	break;
	            	
	            case ErrorCode.errorCaptchaError :
                    if (aContext.settings.get('isParentalConsent') == true) {   
                        aContext.gotoStep(3);
                    } else {
                        aContext.gotoStep(2);
                    }
	            	var _errorMessage = SSOError.getErrorMessage(aErrorCode);
	            	SSOUIHelper.showWarning(_errorMessage);
	            	break;
	            
               case ErrorCode.errorServicetagError :
            	   if (aContext.settings.get('isParentalConsent') == true) {               
            		   aContext.addStep("SSOConfirmation", 3, false);
            		   aContext.gotoStep(3);                        
            	   } else {
            		   //This use case error says that service tag has exceeded the desired limit, 
            		   //so now we need to display captcha screen and still continue to usecase	
                    	aContext.addStep("SSOConfirmation", 2, false);
                    	aContext.gotoStep(2);
                    }
	            	break;
	            	
            	default:	            		            	
	            	aContext.gotoPreviousStep();
	            	var _errorMessage = SSOError.getErrorMessage(aErrorCode);
	            	SSOUIHelper.showWarning(_errorMessage);
	            	break;
            }
    	}
    },
    
    /**
     * Renders the SSOAccFailedView
     * @function showAccFailedView
     */
    showAccFailedView: function() {
		//@TODO: CR: HIGH: Why do we need try-catch block below?
    	try {
    		this.deactivate();
    		
    		this.view = this.getView("SSOAccFailed");
    		this.view.render();

    	} catch(ex) {
			//@TODO: CR: CRITICAL: Use ovi.error
        ovi.debug("Exception in SSOAccCreateWizardController.js" +  ex + "  -  " + ex.message);
    	}
    },
    
    /**
     * 
     * @ startParentSignUp
     */
    startParentSignUp: function() {
    	this.applicationController.activate("SSOParentSignUp");
    },
    
   /**
     * Activate the view     
     * @function activate
     */
    activate: function() {
    	ovi.debug("SSOAccCreateWizardController: Activate Entry");
    	
    	//@todo move this into a function
    	/*
    	 * Generate the steps required for creating account.
    	 * Steps Generation has to happen only in the activation part. 
    	 */
    	try {
            var _signupModel = this.getModel("SSOSignUp");           
            this.isCaptachRequired = _signupModel.isCaptchaRequired();
            
            //clear all steps before adding the steps.
    	  	this.clearAllSteps();
    	  	
    	  	//add account create wizard steps
            this.addStep("SSOAccDetails");
            this.addStep("SSOAboutYou");
            if(this.isCaptachRequired) {
            	ovi.debug("Adding captcha screen support");
                this.addStep("SSOConfirmation");
            }        
            this.addStep(this.doRegister);
            this.addStep("SSOAccCreated");
        } catch(ex) {
            ovi.error("Exception in SSOAccCreateWizardController.js" +  ex + "  -  " + ex.message);
		}
		
    	this._super();    	
    	console.log("inside SSOAccCreateWizardController activate");    	
    	
    	var _parent = this.settings.get('isParentSignUp');
		if(_parent) {	
			this.model = this.getModel("SSOParentSignUp");
			ovi.debug("Model is parentSignup");
		} else {
			this.model = this.getModel("SSOSignUp");	
			ovi.debug("Model is signup");
		}	
        
        try {
            //Get the country code from the sysinfo
            //this.applicationController.getSysInfoObj().getCountryInfo(this._countryInfoObtained,this);
        }catch(ex){
            ovi.error("Exception in SSOAccCreateWizardController.js" +  ex + "  -  " + ex.message);
		}        
        
        //Start the wizard
        this.start();
        ovi.debug("Create Wizard COntroller : Activate Exit");    	
    },
	
	/**
	 * Callback for the country Information
	 * @function _countryInfoObtained
	 */
	_countryInfoObtained: function(aCountryCode,aContext) {		
		ovi.debug("CountryInfo obtained and countrycode is " + aCountryCode);		
		//Get the countryname for the given country code        	
		var countryname = SSOCountryName.getCountryNameFromCode(aCountryCode);	
		//Set the country name to the model
		aContext.model.setCountry(countryname);							
	},
	
    
    /**
	 * Destroys the view when deactivate is called
	 * @function closeApplication	 
	 */
    deactivate: function() {
    	//console.log("inside SSOAccCreateWizardController deactivate");
        // This patch is done because, this._domNode is the property which is set when we call/override
        // render function. Now when isauthenticated is true, i.e when we launch 'Sign in' second after
        // a successful sign in, then isauthenticated will be 'true'. In that case we are just calling 
        // Sign in API which in turn calls TOS View if there is an updation of any of the TOS' in the backend.
        // When we do 'activate' of TOS view, it internally calls the 'deactivate' of the current view(SSOSIGNIN view)
        // Since we have not rendered the view, this._domNode is not defined, it will result in a JS error, thus by checking
        // for this._domNode we are making sure, view.destroy() works in all the cases. (for more info, refer htmlview.js in ovi library)
        if(this.view._renderer){   				
          // Destroy the view
          this.view.destroy();
        }
    },
    
    /**
     * 
     * @function onWizardFinish
     */
    onWizardFinish: function() {
    	this._super().apply(this, arguments);
    },
    
    /**
     * 
     * @function onWizardCancel
     */
    onWizardCancel: function() {
    	this._super().apply(this, arguments);
        var _signupModel = this.getModel("SSOSignUp");   
		//@TODO: CR: CRITICAL.Use !== instead of !=     
        if( _signupModel !=null) {
        	_signupModel._clear();
        }
        
        var _parentSignupModel = this.getModel("SSOParentSignUp");
        //@TODO: CR: CRITICAL.Use !== instead of !=     
        if( _parentSignupModel !=null) {
        	_parentSignupModel._clear();
        }
    	this.settings.set('isParentSignUp', false);
    }
});