/**
 *
 * Description : A class that extends SSOWizardViewController
 *               Maintains the wizard for the Account management usecase 
 * <p>
 * Filename    : SSOAccountManagementController.js
 * <p>
 * Part of     : Controllers
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOAccountManagementController
 * @name SSOAccountManagementController 
 */

ovi.provide( 'ssoui.controllers.SSOAccountManagementController' );
ovi.require( 'ssoui.controllers.SSOViewController' );
ovi.require( 'ssoui.utils.SSOConstant',false )
ovi.declare( 'ssoui.controllers.SSOAccountManagementController',{
    
    /**
     * SSOAccountManagementController extends the SSOViewController class.
     * @extends ssoui.controllers.SSOViewController
     */
    Extends: ssoui.controllers.SSOViewController,
    
    /**
     * Creates the objects needed for this controller
     * Gets the view and model for the account management
     * @function initialize
     */
    initialize: function() {
        this._super();        
        //Get the view to be displayed
        this.view  = this.getView();         
        //Get the account management model to store the data
        this.model = this.getModel();    
    },
    
   /**
     * Activate the view     
     * @function activate
     */
    activate: function() {            
        // Dispaly the main setting screen.
        this.view.render();
    },
    
    /**
     * Subscribe for the navigation events - Cancel 
     * @function subscribers
     */
    subscribers: {
        "movenext" : function(){    
            //No Implementation
        },
        "movebackaccmgmt" : function(){
                
            //Post the event to the client.
            var eventMessageObj= this.applicationController.getEventMessageObj();
            eventMessageObj.post(SSOConstant.AccountManagement, ssoui.utils.SSOUtil.convertToJSONFormat(SSOConstant.Completed,SSOConstant.Exit));
            //Cancel has been trigerred. Close the application
            //As the RSK for the account management usecase is always Cancel
            this.closeApplication();
        }        
    },        
   
    
    /**
     * Destroys the view when deactivate is called
     * @function closeApplication     
     */
    deactivate: function() {                   
        // Destroy the view
        this.view.destroy();
    }    
});