/**
 *
 * Description : A class that extends SSOWizardViewController
 *               Maintains the wizard for the Account management - Change password usecase 
 * <p>
 * Filename    : SSOAcctMngtChangePasswordController.js
 * <p>
 * Part of     : Controllers
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   7 %
 * @class SSOAcctMngtChangePasswordController
 * @name SSOAcctMngtChangePasswordController 
 */

ovi.provide( 'ssoui.controllers.SSOAcctMngtChangePasswordController' );
ovi.require( 'ssoui.controllers.SSOViewController' );
ovi.require( 'ssoui.utils.SSOConstant',false )
ovi.declare( 'ssoui.controllers.SSOAcctMngtChangePasswordController',{
    
    /**
     * SSOAcctMngtChangePasswordController extends the SSOViewController class.
     * @extends ssoui.controllers.SSOViewController
     */
    Extends: ssoui.controllers.SSOViewController,
    
    /**
     * Creates the objects needed for this controller
      * Gets the view and model for the change password
     * @function initialize
     */
    initialize: function() {
        this._super();        
        //Get the view to be displayed
        this.view  = this.getView();         
        //Get the signin model to get and store the data
        this.model = this.getModel();    
    },
    
   /**
     * Activate the view     
     * @function activate
     */
    activate: function() {            
        // Dispaly the main setting screen.
        this.view.render();
    },
      
    /**
     * Move to the next action           
     * @function movenext
     */
    movenext: function() { 
        //Display the progress bar as the request has been sent.
        this.view.showProgress(true);
        //Disable the LSK
        this.view.disableLSK();
        //Disable the RSK
        this.view.disableRSK();
        //Call the password change API when the save is clicked     
		//@TODO: CR: MEDIUM: Better to call this.model.changePassword()   
        this.changePassword(this._changePasswordComplete,this);
    },
    
    /**
     * Callback API for the change password completion
     * @function _changePasswordComplete
     * @param {aResult} - Success/Failed
     * @param {int} aErrorCode - errorcode returned by the enbaler
	 * @param {object} aContext - SSOAcctMngtChangePasswordController pointer returned 
     */
    _changePasswordComplete: function(aResult,aErrorCode,aContext) {
         //Hide the progress bar 
        aContext.view.hideProgress();
        //Enable the LSK
         aContext.view.enableLSK();
         //Enable the RSK
        aContext.view.enableRSK();
        if( aResult == SSOConstant.Success ) {
			//@TODO: CR: HIGH: If change password can only be triggered
			//   from AccountMngmt, then we can use moveback()            
            aContext.applicationController.activate('SSOAccountManagement');  
        } else {
           var _errorMsg = SSOError.getErrorMessage(aErrorCode);
            SSOUIHelper.showError(_errorMsg);
        }
    },
    
    /**
     * Triggered when cancel is pressed in Account Management Screen
     * Move to the account management screen
     * @function moveback
     */
    moveback: function() {   
        //Should load the account management view when we click on Cancel
		//@TODO: CR: MEDIUM: Can't we directly use sisu controller.moveback()?
        this.applicationController.activate('SSOAccountManagement'); 
    },
    
    
    /**
     * Destroys the view when deactivate is called
     * @function closeApplication     
     */
    deactivate: function() {                   
        // Destroy the view
        this.view.destroy();
    }    
});