/**
 *
 * Description : A class that extends ApplicationController
 *               Loads the plugin needed for the application
 * <p>
 * Filename    : SSOApplicationController.js
 * <p>
 * Part of     : Controllers
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   37.1.2.1.8 %
 * @class SSOApplicationController
 * @name SSOApplicationController 
 */

ovi.provide( 'ssoui.controllers.SSOApplicationController' );
ovi.require( 'ovi.sisu.ApplicationController' );
ovi.require( 'ovi.ConsoleLogger' );
ovi.require( 'ovi.ui.Dialog' );
ovi.require( 'ssoui.services.SSOLanguageCode',false );
ovi.require( 'ssoui.SSOBuildConfigure',false );
ovi.declare( 'ssoui.controllers.SSOApplicationController', {

    /**
     * SSOApplicationController extends the ApplicationController class.
     * @extends ssoui.controllers.ApplicationController
     */
    Extends: ovi.sisu.ApplicationController,
    
    /**
     * Creates the objects needed for the application
     * Initializes the enabler objects.
     * @function initialize
     */
    initialize: function() {
		//Base class init
        this._super();
        
        this._resetAllSettings();
        
        //From  wk04 onwards window.xwidget is depricated
		//@TODO: CR: If code is depricated, please remove them. 
        if(typeof window.xwidget == 'undefined') {
            window.xwidget = window.widget;
        }
        
		// This is initialized to false by default, if "No Email" is clicked
		// On account Details screen, it will be reset.
		this.settings.set('isEmailAccountCreationInitiated', false);
		//@TODO: CR: Is there a way to flush all properties in settings?
		//	or reset each value to default?
		
        	// Show the loading indicator popup
        this.settings.set('ssoServiceState', 'Launching');
        
        this.activate('SSOLaunchDialog');

        
		//@TODO: CR: Use '===' instead of '=='
        if( typeof window.xwidget == 'undefined'  || typeof window.xwidget.commandline == 'undefined') {        
            // Store the context in a local variable
            // This will be used to send the context as paramenter to event listener
            var currentcontext = this;        
            // Fire the event to recieve the configuration parameters sent by client.
            // We also require the context (currentcontext) to use settings().
            window.addEventListener("message", function(event) {currentcontext._onParametersRecieved(event, currentcontext);}, false);
        } else{            
        	//read the command line param
            //These param are sent by the client
			
			//@TODO: CR: Need to validate input parameter ie. commandline. 
			//	For any missing params / invalid input, share error
            var jsonStr = decodeURI(window.xwidget.commandline);        
            var cmdConfig =  JSON.parse(jsonStr); 
            //Please Note: In Qt launch mode, jsui is responsibe to hide default softkeys provided by widget.
            // This softkey hiding will not have any affect on Caller's Native softkeys.
            window.menu.hideSoftkeys();
            this._initServiceManager(cmdConfig);           
        }        
    },
	
    /**
     * Clears the settings object.
     * @function _resetAllSettings
     */
    _resetAllSettings : function() {
    	//@todo check if setting to undefined is the properway
    	this.settings.set('isParentCreatedAcc', undefined);
    	this.settings.set('isParentSignUp', undefined);
    	this.settings.set('isParentalConsent', undefined);
    	this.settings.set('isParentDenied', undefined);
    	this.settings.set('isParentApproved', undefined);    	
    	this.settings.set('childRegisterationInfo', undefined);
    	this.settings.set('isEmailAccountCreationInitiated', undefined);
    	this.settings.set('ssoServiceState', undefined);
    	this.settings.set('ssoUIContext', undefined);
    	this.settings.set('forceSignIn', undefined);
    	this.settings.set('ssoServiceId', undefined);
    	this.settings.set('useCase', undefined);
    	this.settings.set('onWizardFinish', undefined);
    	this.settings.set('onWizardCancel', undefined);
    	this.settings.set('preaccountid', undefined);
    	this.settings.set('HasAcceptedTos', undefined);
    	this.settings.set('HasAcceptedServiceSpecificTos', undefined);
    	this.settings.set('HasAcceptedPrivacyPolicy', undefined);
    	this.settings.set('signintosupdate', undefined);
    },
    
    /**
     * @private
     */
    _initServiceManager : function(aConfig) {
    	
    	// save the usecase context in settings object for later use to post event.
        this.settings.set('ssoUIContext', aConfig.ssoUIContext);
        
        //Store the forc SignIn to the settings
        //We need the value set by the user in the signin controller        
        this.settings.set('forceSignIn', aConfig.ssoForceSignIn);
        
        // set the serviceID to be used for service specific url retreval.
        this.settings.set('ssoServiceId', aConfig.ssoServiceId);
        var _self = this;
		//@TODO: CR: How is '5' arrived as optimal time?
        setTimeout(function() { _self._startServiceMananer(aConfig);  }, 5);
        
    },
    
    /**
     * @private 
     * Function to load & initialize the service manager.
     * @function _startServiceMananer
     */
    _startServiceMananer : function(aConfig) {    	
    	ovi.require( 'ssoui.services.SSOServiceManager');
    	this._serviceManager = new ssoui.services.SSOServiceManager(aConfig, this._launchWizard, this);
    },
    
    
    /**
     * @private
     * This is the callback function that will be fired whenever event type "message" is fired.
     * This will be fired when we recieve the parameters sent via postMessage() API by clients     
     * @function _onParametersRecieved
     * @param {object} aEvent This object contains the data and other fields
     * @param {object} aContext Current context from which this function was fired
     */
    _onParametersRecieved: function(aEvent, aContext) {
        //read the command line param
        //These param are sent by the client
        var cmdconfig =  JSON.parse(aEvent.data);
        aContext._initServiceManager(cmdconfig);
    },
    
    //@TODO: CR: If below method is private, prefix with "_". Add note of method only called for QT.
	//		Add return (or notification information as well). 
    /**
     * Close the application
     * @function closeApplication
     * @param {object} aContext - this pointer
     */
    closeApplication: function() {
        // send the information to client regarding some error occured and then close the widget
        var eventMessageObj= this.getEventMessageObj(); 
         var _context = this.settings.get('ssoUIContext');         
         eventMessageObj.post(_context, ssoui.utils.SSOUtil.convertToJSONFormat(SSOConstant.Error,SSOConstant.Error));         
         window.close();
         
        
    },
    
    //@TODO: CR: Function paramters are not explained. @return void missing
    /**
     * Launch the wizard based on the given use case     
     * @function _launchWizard     
     */
    _launchWizard: function(aUsecase, aContext) {
		//@TODO: CR: Why do we reset only 1 property?
		//@TODO: CR: We need a generic place holder to reset all
		// 	relevant settings in one common method.
        aContext.settings.set('isParentalConsent', false);
		
		//@TODO: CODE Remove the loading screen
		//aContext._loadingdialog.close();
    	    	
    	try {
    		aContext.settings.set("useCase", aUsecase);
	        switch (aUsecase) {    
	      		case SSOConstant.SignIn :   
	      		case SSOConstant.SignUp :                
	      		var _authobj = aContext.applicationController.getAuthObj();
			//Get the last logged in user id from the enabler.
			var loginIdPreFilled = "";
			try {
				loginIdPreFilled = _authobj.lastLoggedInIdentifier();
			} catch(ex) {
				ovi.error("Exception in get username in application controller " +  ex + "  -  " + ex.message);
			}						
                        aContext.settings.set("onWizardFinish", "CLOSEAPP");
	                // username is not available in securestorage  may be this is first time launch, 
	                //so go for signup                   
	                if(ssoui.utils.SSOUtil.isEmpty(loginIdPreFilled) == true) {
						//@TODO: CR: Instead of using undefined, can set "" as well
	                	aContext.settings.set("preaccountid", undefined);
	                	//Before starting SingUp wizard detect preaccount.	            	
	                	aContext.settings.set("onWizardCancel", "CLOSEAPP");
	                	aContext.detectAccount();
	                } else {
	                	// user had already logged in on this device sometime back  so launch sign in
	                	//Activate the signin controller.          	
	                	aContext.applicationController.activate('SSOSignUp');
	                	
	                	//A dummy call is made to establish a SSL handshaking with the server. This is done
	                	//to reduce the next server call time.
	                	var _signUpModel = aContext.getModel("SSOSignUp");
	                	_signUpModel.retrieveUsernameAvailability(function(){}, "dummyuser", this);
	                }                    
                break;	            
	            
	            case SSOConstant.AccountManagement :
	                //Activate the SignIn controller here as 
	                //the session should be active before launching account
	                //managememt.
	            	aContext.applicationController.activate('SSOSignUp');
	               break;        
	        }
    	} catch(ex) {
            ovi.require( 'ssoui.ui.SSOUIHelper' );
            SSOUIHelper.showSystemError(aContext.applicationController,sso_msg_0026);   
    		
    	}
    },
    
	//@TODO: CR: If below is a private method, please add @private & prefix
	// function name with "_". 
    /**
     * Function to detect account associated with the sim.
     * @function detectAccount
     */
    detectAccount: function() {
    	ovi.debug("Inside detectAccount");
    	try {
	        var _signupModel = this.getModel("SSOSignUp");
	        _signupModel.detectPreAccount(this.onDetectAccountComplete, this);
        } catch(ex) {
        	//In case of any error in detectPreaccount launch SignUp directly
        	this.settings.set("preaccountid", undefined);
			this.applicationController.activate("SSOSignUp");
        }
    },
    
	//@TODO: CR: Function description block, parameters, return type missing.
	//@TODO: CR: If below is a private method, please add @private & prefix
	// function name with "_". 
    /**
     * 
     * @function onDetectAccountComplete
     */
    onDetectAccountComplete: function(aResult, aErrorCode, aContext) {
        try {
			//If detect pre account was successfull
            if(aResult == SSOConstant.Success) { // there was some info 
                // regarding PreAccount
                //try to get the pre account info   
                // preaccountid / username
                var _preAccount = aContext.getModel("SSOSignUp").getPreAccount();
                if(typeof _preAccount !== "undefined") {
                    var userpreaccountName = _preAccount.username;
                    
                    // If username available -> welcomeback screen will be 
                    // activated
                    if( ssoui.utils.SSOUtil.isEmpty(userpreaccountName) == false) {
                        // Activate welcomeback screen
                        aContext.applicationController.activate("SSOAccIdentified");                                            
                    } else if(_preAccount.preaccountid != "undefined") {
                        // pre account id is available so, Sign up with pre account
                        aContext.settings.set("preaccountid", _preAccount.preaccountid);                
                        aContext.applicationController.activate("SSOSignUp");                                      
                    } else {            
                        aContext.settings.set("preaccountid", undefined);
                        aContext.applicationController.activate("SSOSignUp");
                    }
                } else {
                    aContext.settings.set("preaccountid", undefined);
                    aContext.applicationController.activate("SSOSignUp");
                }
            } else { // some problem calling detect pre account go for normal account creation
                
                aContext.settings.set("preaccountid", undefined);
                aContext.applicationController.activate("SSOSignUp");     
			}
    	} catch(ex) {
    		//Incase of error somewhere launch SignUp directly.
    		aContext.settings.set("preaccountid", undefined);
			aContext.applicationController.activate("SSOSignUp");
    	}
    },
    
    //@TODO : check if the object can be returned using the ovi.settings - set/get API
    //Values can be set/get but there are few issues in object
    getAuthObj: function() {    
        return this._serviceManager.getNoaAuthentication();
    },    

    //@TODO: CR: Function description block missing
    getRegObj: function() {    
        return this._serviceManager.getNoaRegisteration();
    },    
    
    //@TODO: CR: Function description block missing
    getPswdObj: function() {    
        return this._serviceManager.getNoaPasswordManager();
    },    
    
    //@TODO: CR: Function description block missing
    getProfObj: function() {    
        return this._serviceManager.getNoaProfileManager();
    },
    
    //@TODO: CR: Function description block missing
    getEventMessageObj: function() {
        return this._serviceManager.getSSOEventManager();
    },
    
    //@TODO: CR: Function description block missing
    getAppMgmtObj: function() {
        return this._serviceManager.getApplicationManagement();
    },
    
   /**
    * Returns the sysInfo object
    * @function getSysInfoObj
    * @return{obj} returns the sys info object ssoSysInfoObj
    */    
    getSysInfoObj: function() {
        return this._serviceManager.getSysInfo();
    },
    
    /**
    * Returns the phone language
    * @function getPhoneLang
    * @return{var} returns the phone language
    */
    getPhoneLang: function() {
        try {
            //Gets the phone language from the sysinfo service provider
            var lang = this.getSysInfoObj().getPhoneLang();
            
			//Get the lang code for the phone language
			return SSOLanguageCode.getLangCode(lang);		
            
         }catch(ex) {
		 	//@TODO: CR: Capture using ovi.error
           ovi.debug("Exception in SSOApplicationController.js" +  ex + "  -  " + ex.message);
         }
    },
    
    subscribers: {
        // Global events to subscribe to
        // eventName: function
    }
    
	//@TODO: CR: deActivate method is missing with super call
} );

//@TODO: CR: This class (function) is redundant to ssoui.js
/**
* Connection detail 
*/
function ConnectionDetail(aBaseurl) {   
	//Proxy settings
	this.proxyType = 1;
	//Time oout given as 1 min
	this.timeout = 60000;
	this.baseUrl = aBaseurl;    	
};