/**
 *
 * Description : A class that extends SSOWizardViewController
 *               Maintains the wizard for the signin usecase 
 * <p>
 * Filename    : SSOForgotPasswordWizardController.js
 * <p>
 * Part of     : Controllers
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   11.1.3 %
 * @class SSOForgotPasswordWizardController
 * @name SSOForgotPasswordWizardController 
 */
 
 //@TODO: CR: MEDIUM: File header description block is not talking about PR
 ovi.provide('ssoui.controllers.SSOForgotPasswordWizardController');
 ovi.require('ssoui.controllers.SSOWizardController');
 ovi.require('ssoui.ui.SSOUIHelper');
 ovi.require('ssoui.ui.SSOError');
 ovi.require('ovi.ConsoleLogger');
 ovi.declare('ssoui.controllers.SSOForgotPasswordWizardController', {

   /**
	* SSOForgotPasswordWizardController extends the SSOWizardController class.
  	* @extends ssoui.controllers.SSOWizardController
  	*/
	Extends: ssoui.controllers.SSOWizardController,
  
  	/**
	 * Creates the objects needed for this controller
	 * Calls the base class init function which initiliazes the noa objects needed
	 * @function initialize
	 */
  	initialize: function() {
	 	this._super();    
  	},
  
    /**
     * Activate the view	 
     * @function activate
     */
    activate: function() {
	  	this.model = this.getModel('SSOForgotPassword');    
	  	var _signupModel = this.getModel("SSOSignUp");           
	  	this.isCaptachRequired = _signupModel.isCaptchaRequired();
	  	
	  	//clear all steps before adding the steps.
	  	this.clearAllSteps();
	  	
	  	//add forgot password wizard steps
	  	this.addStep("SSOForgotPassword");
	    if(this.isCaptachRequired) {
	    	ovi.debug("Adding captcha screen support");
	        this.addStep("SSOConfirmation");
	    }        
	    this.addStep(this.sendResetMessage);
	    this.addStep("SSOPasswordSuccess");
	    
        //Start the wizard
        this.start();
    },
  
   
    /**
     * Send the reset code to user
     * @ function sendResetMessage
     * @param {object} aCallback Structure that contains error information     
     * @param {object} aContext context from which original API was called 
    */     
    sendResetMessage: function(aModel, aContext) {

    		aContext.view.showSpinner();
    	
		var _ssoPR = aContext.getModel("SSOForgotPassword");
		//Request for the reset code is sent to the model
		_ssoPR.sendResetMessage(aContext._sendResetMessageComplete, aContext);		
    },
    
    
    /**
      * Request complete Callback function for the reset code in password recovery
      * @function  _sendResetMessageComplete
      * @param {var} aError error code of the request
      * @param {var} aType type of the request
      * @param {var} aRequestId request id of the request sent
      */
    _sendResetMessageComplete: function(aError, aType, aRequestId, aContext) {
        ovi.debug("SSOForgotPasswordController - SendResetMessageComplete with error code" + aError);	
        //Hide the progress bar as the request has been completed
        aContext.view.hideProgress();
        //Enable the LSK
        aContext.view.enableLSK();
        //Enable the RSK
        aContext.view.enableRSK();     
        //Check if the type of request is requestResetMessage and error is none
        if( aType == RequestType.requestResetMessage && aError == ErrorCode.errorNone ) {
        	aContext.gotoNextStep();
        } else {
        	aContext.gotoPreviousStep();
            var _errorMsg = SSOError.getErrorMessage(aError);
            SSOUIHelper.showError(_errorMsg);
        } 
    },
        
    /**
     * 
     * @function onWizardFinish
     */
    onWizardFinish: function() {
    	//this._super().apply(this, arguments);
    	this.applicationController.activate("SSOSignUp");
    },
     
    /**
     * 
     * @function onWizardCancel
     */
    onWizardCancel: function() {
    	this.applicationController.activate("SSOSignUp");
    },
      
    /**
     * Destroys the view when deactivate is called
     * @function closeApplication	 
     */
    deactivate: function() {   				
    	// Destroy the view
    	if(this.view._renderer) {
    		this.view.destroy();
    	}
    }	
 });
 
