/**
 *
 * Description : A Controller to manage the launch of Dialog on 
 *              launching of application & post successful signin.
 * <p>
 * Filename    : SSOLaunchDialogController.js
 * <p>
 * Part of     : Controllers
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOLaunchDialogController
 * @name SSOLaunchDialogController 
 * @version %version:  %
 */

ovi.provide( 'ssoui.controllers.SSOLaunchDialogController' );
ovi.require( 'ssoui.controllers.SSOViewController' );
ovi.require( 'ssoui.ui.SSOUIHelper' );
ovi.require('ssoui.utils.SSOConstant',false);
ovi.declare( 'ssoui.controllers.SSOLaunchDialogController' ,{
    
    /**
     * SSOSignUpController extends the ovi.sisu.Controller class.
     * @extends ovi.sisu.Controller
     */
    Extends: ssoui.controllers.SSOViewController,
	
    /**
     * Creates the objects needed for this controller
     * Calls the base class init function which initiliazes the noa objects needed
     * @function initialize
     */
    initialize: function() {
        //console.log("Inside SSOSignUpController init");
        this._super();
        //Get the view to be displayed
        this.view  = this.getView(); 
        //Get the signin model to get and store the data
        //this.model = this.getModel();
		
        var self = this;
        
        ovi.orientation.addEventHandler(ovi.orientation.CHANGE_EVENT, function(ev) {
            if(self.view._renderer)
            {
                ovi.warn("view.cacheViewData() to be implemented for orientation");
                self.view.cacheViewData();
                self.view.destroy();
                self.activate();
            }     
        });		
    },
    
   /**
     * Activate the view
     * @function activate
     */
    activate: function() {
		var state = this.applicationController.settings.get('ssoServiceState');
		if (state == 'Launching')
		{
			// display loading dialog
			ovi.debug("SSOLaunchDialogController: Activate:Launching");
			
		}else if (state == 'SignInDone')
		{
			// display logged in dialog
		}
        ovi.debug("SSOLaunchDialogController: Activate:Render view");
		
        this.view.render();
    },
    
    /**
     * Destroys the view when deactivate is called
     * @function closeApplication    
     */
    deactivate: function() {
        //console.log("inside signupcontroller deactivate");
        // This patch is done because, this._domNode is the property which is set when we call/override
        // render function. Now when isauthenticated is true, i.e when we launch 'Sign in' second after
        // a successful sign in, then isauthenticated will be 'true'. In that case we are just calling 
        // Sign in API which in turn calls TOS View if there is an updation of any of the TOS' in the backend.
        // When we do 'activate' of TOS view, it internally calls the 'deactivate' of the current view(SSOSIGNIN view)
        // Since we have not rendered the view, this._domNode is not defined, it will result in a JS error, thus by checking
        // for this._domNode we are making sure, view.destroy() works in all the cases. (for more info, refer htmlview.js in ovi library)
        
        //@TODO: CR: We MUST not use view._renderer property. Protection
        // should be provided within each view for destroy. 
        // SSOBaseView can provide a flag for stating the similar
        ovi.debug("SSOLaunchDialogController: Deactivate view");
        if(this.view._renderer){
    
            this.view.clearCacheData();
          // Destroy the view           
          this.view.destroy();
        }
    },
    
    /**
     * Subscribe for the navigation events - Next/back/Cancel 
     * @function subscribers
     */
    subscribers: {
        "SignInDone" : function(){
			/*
			 * Sign-In is completed & Dialog is done with showing success. 
			 * Close the application. 
			 */
			ovi.debug("SignInDone:subscribed");
            var eventMessageObj= this.applicationController.getEventMessageObj();
            eventMessageObj.post(this.applicationController.settings.get('ssoUIContext'),
			     ssoui.utils.SSOUtil.convertToJSONFormat(SSOConstant.Completed,
				    SSOConstant.SignInCompleted));
            this.closeApplication();
            }
    }
});