/**
 *
 * Description : A class that extends ovi.sisu.Controller & acts as a controller
 * 				 for SSOSignUpView                
 * <p>
 * Filename    : SSOSignUpController.js
 * <p>
 * Part of     : Controllers
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOSignUpController
 * @name SSOSignUpController 
 * @version %version:  %
 */

ovi.provide( 'ssoui.controllers.SSOSignUpController' );
ovi.require( 'ssoui.controllers.SSOViewController' );
ovi.require( 'ssoui.ui.SSOUIHelper' );
ovi.declare( 'ssoui.controllers.SSOSignUpController' ,{
    
    /**
     * SSOSignUpController extends the ovi.sisu.Controller class.
     * @extends ovi.sisu.Controller
     */
    Extends: ssoui.controllers.SSOViewController,
    
    /**
     * Creates the objects needed for this controller
     * Calls the base class init function which initiliazes the noa objects needed
     * @function initialize
     */
    initialize: function() {
		//console.log("Inside SSOSignUpController init");
        this._super();
        //Get the view to be displayed
        this.view  = this.getView(); 
        //Get the signin model to get and store the data
        this.model = this.getModel();
    },
    
   /**
     * Activate the view     
     * @function activate
     */
    activate: function() {
    	 //Check if the password was remememebre or session is active
        var isAuthenticated = (this.isAuthenticated().toString() === 'true')? true:false;             
        //Get the value of forceSignIn set by the client
        var forceSignin = this.settings.get('forceSignIn');  
		//Get the last logged in user id from the model
        var loginId = this.getLastLoggedInUserID();        
        
		// If context is not 'force sign in' and credentials are remembered in
		// secure storage, then we will do a silent sign in 
        if(forceSignin == 'false' && isAuthenticated == true) { 
		
		    this.settings.set('ssoServiceState', 'SignInDone');
            this.applicationController.activate('SSOLaunchDialog');
			 
			ovi.debug("DO a silent sign in");
			//Set the rememember me settings to unchanged i.e 2   
			//@TODO: CR: Read comment in SignInModel              
			this.model.setUsername("");                 
			this.model.setPassword("");  
			this.model.setRememberme("unchanged");   				
			this.signIn(this._signIncallback,this);   
                        
        } else { // forcefully signin  displaying the UI
           //Display the SignIn view
            this.view.render(loginId);
        }    
    },
    
    /**
	 * Destroys the view when deactivate is called
	 * @function closeApplication	 
	 */
    deactivate: function() {
    	//console.log("inside signupcontroller deactivate");
        // This patch is done because, this._domNode is the property which is set when we call/override
        // render function. Now when isauthenticated is true, i.e when we launch 'Sign in' second after
        // a successful sign in, then isauthenticated will be 'true'. In that case we are just calling 
        // Sign in API which in turn calls TOS View if there is an updation of any of the TOS' in the backend.
        // When we do 'activate' of TOS view, it internally calls the 'deactivate' of the current view(SSOSIGNIN view)
        // Since we have not rendered the view, this._domNode is not defined, it will result in a JS error, thus by checking
        // for this._domNode we are making sure, view.destroy() works in all the cases. (for more info, refer htmlview.js in ovi library)
		
		//@TODO: CR: We MUST not use view._renderer property. Protection
		// should be provided within each view for destroy. 
		// SSOBaseView can provide a flag for stating the similar
        if(this.view._renderer){
	
			//this.view.clearCacheData();
          // Destroy the view        	
          this.view.destroy();
        }
    },
    
    /**
     * Subscribe for the navigation events - Next/back/Cancel 
     * @function subscribers
     */
    subscribers: {
    	"onSignInClick" : function(){
			//console.log("onLSKClick event subscribered");    		
			this.doSignIn();          
	    },
    
	    "onCancelClick" : function(){
	    	//console.log("onRSKClick event subscribered");
	        //Cancel has been trigerred. Close the application
	        //As the RSK for the signin usecase is always Cancel
	        //post the event to clients so that they can know the status of signin, if they are intrested.
	        var eventMessageObj= this.applicationController.getEventMessageObj();
	        eventMessageObj.post(this.applicationController.settings.get('ssoUIContext'),ssoui.utils.SSOUtil.convertToJSONFormat(SSOConstant.Error,SSOConstant.Cancelled));
	        this.closeApplication();
			}
    },
    
	//@TODO: CR: why is return required? 
	//@TODO: CR: As this is local method & only called from one place & has 
	// a single line code. Better move it to the callee place itself as inline.
    /**
     * Calls the signin API of the signin model
     * @function doSignIn
     */
    doSignIn: function() {
    	var _isParentSignUp = this.settings.get("isParentSignUp");
    	if(_isParentSignUp) {
    		//@todo need to clean-up model & come out the design to share the common data points.
    		var _parentModel = this.getModel("SSOParentSignUp");
    		var _signInModel = this.getModel("SSOSignIn");
    		_parentModel.setUsername(_signInModel.getUsername());
    		_parentModel.setPassword(_signInModel.getPassword());
    		this.doParentSignIn(this._parentSignIncallback, this);
    	} else {
    		this.signIn(this._signIncallback, this);
    	}
    }
});