/**
 *
 * Description : A class that extends SSOViewController
 *               Maintains the wizard for the signin usecase 
 * <p>
 * Filename    : SSOTOSController.js
 * <p>
 * Part of     : Controllers
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOTOSController
 * @name SSOTOSController 
 */
 
 ovi.provide('ssoui.controllers.SSOTOSController');
 ovi.require('ssoui.controllers.SSOViewController');
 ovi.require( 'ssoui.utils.SSOConstant',false );
 ovi.require( 'ssoui.utils.SSOUtil', false);
 ovi.declare('ssoui.controllers.SSOTOSController', {
 
  /**
  * TOSController extends the SSOViewController class.
  * @extends ssoui.controllers.SSOViewController
  */
  Extends: ssoui.controllers.SSOViewController,
  
  /**
  * Creates the objects needed for this controller
  * Calls the base class init function which initiliazes the noa objects needed
  * @function initialize
  */
  initialize: function() {
    this._super();
    //Get the view to be displayed
    this.view  = this.getView(); 
    //Get the signin model to get and store the data
    this.model = this.getModel();
  },
  
  /**
  * Activate the view	 
  * @function activate
  */
  activate: function() {    
    // Dispaly the Terms of Services view with the status values
    this.view.render();
  },
  
  /**
  * Subscribe for the navigation events - Next/back/Cancel 
  * @function subscribers
  */
  subscribers: {
    "updatetermsstatus" : function() {
	  //Clear the error message if displayed
	  SSOUIHelper.hideMessage();
      // If you click on "Accept" then update the terms of acceptance      
      this.model.updateTermsOfService(this._updateTOSComplete,this);
    },
    
    "closewidget" : function() {        
        try {
		// Sign out from user if user rejects the TOS
		this.signOut(); 
		// user had not accepted the TOS so cancel the usecase        
		// post the events as SignIn cancelled
		var eventMessageObj= this.applicationController.getEventMessageObj();
		eventMessageObj.post(this.applicationController.settings.get('ssoUIContext'),SSOUtil.convertToJSONFormat(SSOConstant.Error,SSOConstant.Cancelled));
		//Close the widget here as the user has rejected the TOS
		this.closeApplication();
	}catch(ex){		
		ovi.error("Exception in TOSController - closewidget " +  ex + "  -  " + ex.message);
		//There is an exception. Display the error.
		SSOUIHelper.showError(sso_msg_0020);
	}
    }	
  },
  
  
   	/**
	 * Callback function when the YOS updtation is completed	 	 
	 * @function _updateTOSComplete
     * @param {int} aResult - result success/failure
	 * @param {int} aErrorCode - errorcode returned by the enbaler
	 * @param {object} aContext - SSOSignInController pointer returned 
	 */  
   _updateTOSComplete : function(aResult,aErrorCode,aContext) {
	  	aContext.view.hideProgress();
		aContext.view.enableRSK();
		aContext.view.enableLSK();
        if(aResult == SSOConstant.Success) {  
            //If the context is account management,launch the account management controller here as the
            //sign is completed
            //Get the context from the settings            
            var context = aContext.applicationController.settings.get('ssoUIContext');
            if( aContext.settings.get('isParentalConsent') == true)
            {              
               
	        	aContext.deactivate();
                var _accWizard = aContext.applicationController.getController("SSOAccCreateWizard");               
                //@TODO accessing private variable, due to limitation in wizard controller , will be replaced later with Activate();
                aContext.applicationController._activeControllerName = "SSOAccCreateWizard";                
                _accWizard.addStep("SSOParentalConsent", 2, false);                
	        	_accWizard.gotoStep(2);
            }
            else if( context == SSOConstant.AccountManagement) {
                aContext.applicationController.activate('SSOAccountManagement');
            } else {
            
                var eventMessageObj= aContext.applicationController.getEventMessageObj();                    
                eventMessageObj.post(context,ssoui.utils.SSOUtil.convertToJSONFormat(SSOConstant.Completed,SSOConstant.SignInCompleted));      
            
                //There is no update in the TOS. Close the widget as the signin is completed
                 aContext.closeApplication();
            }          
		} else {
             //Get the app error message from the error code
             var _errorMsg = SSOError.getErrorMessage(aErrorCode);
             SSOUIHelper.showError(_errorMsg);
        }
  
  },
  
  /**
  * Destroys the view when deactivate is called
  * @function deactivate	 
  */
  deactivate: function() {   				
    // Destroy the view
    this.view.destroy();
  }	
 });
 
