/**
 *
 * Description : A class that extends controller class
 *               Maintains the wizard for the usecase given and calls the enabler 
 *               the opertaion. 
 * <p>
 * Filename    : SSOViewController.js
 * <p>
 * Part of     : Controllers
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOViewController
 * @name SSOViewController
 * @version %version:  10.1.4 %
 */
 
ovi.provide( 'ssoui.controllers.SSOViewController' ); 
ovi.require( 'ovi.sisu.Controller' );
ovi.require( 'ovi.orientation' );
ovi.require( 'ssoui.ui.SSOUIHelper' );
ovi.require( 'ssoui.ui.SSOError' );
ovi.declare( 'ssoui.controllers.SSOViewController' , {

	/**
	 * SSOViewController extends the Controller class.
	 * @extends ovi.sisu.Controller
	 */
	Extends: ovi.sisu.Controller,

	/**
	 * @TODO: Comments
	 */
	initialize : function() {
		this._super();		
		// initialize All the Enabler objects here
		// Based on the 'settings' object value
		
		var self = this;
		
		ovi.orientation.addEventHandler(ovi.orientation.CHANGE_EVENT, function(ev) {
			if(self.view._renderer) {
                ovi.warn("view.cacheViewData() to be implemented for orientation");     
                if(self.view.onOrientationChange) {
                	self.view.onOrientationChange();
                }
			}     
		});  
	   
	},
  
  	//@TODO: CR: aCallback is not used. 
	/**
	 * Calls the enabler signin authentication
	 * @param {function} aCallback - callback function to be called when the signin request is completed
	 * @param {objetc} aContext - object of the calling class. We need this to provide the object to the calling
	 *                            class as this pointer is not accessible	 
	 */
	signIn: function(aCallback,aContext) {
		ovi.debug("Inside SSOViewController signIn");
        
        this.settings.set('ssoServiceState', 'SignInDone');
        aContext.applicationController.activate('SSOLaunchDialog');
		
        var _model = this.getModel("SSOSignIn");
        _model.signIn(this._signIncallback, aContext);		
	},
	
  
	/**
	 * @private
	 * 
	 * Callback function when the signin is completed	 	 
	 * @function signIncallback
	 * @param {int} aErrorCode - errorcode returned by the enbaler
	 * @param {object} aContext - SSOSignInController pointer returned 
	 */
	_signIncallback: function(aResult,aErrorCode,aContext) {
		ovi.debug('SigninController -_signIncallback: Entry ');
		ovi.debug('Signin completed with error code' + aErrorCode);		
               
        //If the sign in was successfull
		if(aResult == SSOConstant.Success) {
			
			// Fetch the TOS status boolen values on successful retrieval
	        var statusinfo = aContext.getTOSStatus();
	        	        
	        // Save the boolean values in settings object so that
	        // TOSController makes use of this
	        aContext.settings.set("HasAcceptedTos",                 statusinfo["HasAcceptedTos"]);
	        aContext.settings.set("HasAcceptedServiceSpecificTos",  statusinfo["HasAcceptedServiceSpecificTos"]);
	        aContext.settings.set("HasAcceptedPrivacyPolicy",       statusinfo["HasAcceptedPrivacyPolicy"]);
	        
	        // if all the Terms have been accepted then fire the sign in complete event
	        if(statusinfo["HasAcceptedTos"] == true && statusinfo["HasAcceptedServiceSpecificTos"] == true &&  
	        		statusinfo["HasAcceptedPrivacyPolicy"] == true) {
	           
	        	ovi.debug("User had already accepted TOS");
	             
	        	var preAccountID =aContext.applicationController.settings.get('preaccountid');	   
				//@TODO: CR: Use !==     	
                if(preAccountID != undefined) {
					//@TODO: CR: Do we really need context_this?
					//		Should we clean up preAccountID,as DB is updated?
                    var context_this = aContext;                
                    var name = context_this.model.getUsername();
                    var regObject = context_this.applicationController.getRegObj();
					//@TODO: Below line of code must be in try-catch block
                    regObject.updateDeviceInfo(context_this._updateDeviceInfoComplete, name, context_this);
                } else {
		            //If the context is account management,launch the account management controller here as the
		            //sign is completed
		            //Get the context from the settings            
		            var context = aContext.applicationController.settings.get('ssoUIContext');
		            if( context == SSOConstant.AccountManagement) {
		            	ovi.debug("Activating account management");
		                aContext.applicationController.activate('SSOAccountManagement');
		            } else {
		                var eventMessageObj= aContext.applicationController.getEventMessageObj();                    
		                eventMessageObj.post(context, ssoui.utils.SSOUtil.convertToJSONFormat(SSOConstant.Completed,SSOConstant.SignInCompleted));
		                
		                //There is no update in the TOS. Close the widget as the signin is completed
		                aContext.closeApplication();
		            }
                }
	        } else {
                // Either one or more of the terms have been updated in the backend
                // this TOS view is for updation of tos after sign in is completed. 
                // So there must be TOS update string displayed in screen.
                aContext.settings.set("signintosupdate",true);               
	            aContext.applicationController.activate('SSOTOS');
	        }
		} else {
			 //Adding this here because when the signin is succesfull there is a call to fetch TOS status
 			 // so the progressbar should be shown on the UI
			 //If the view was displayed then hide the progressbar and the softkeys
			 //@TODO: CR: Why do we need try-catch block below?
			 
			//DALI: Move back to previous screen
			ovi.debug("_signIncallback: Error. Navigate back");
			this.applicationController.back();
			// As we are going to the previous screen, we do not need to 
			// re-enable it. It will be part of the screen render itself
						
			
            //If the error is an general error then the unabel to signin message has to be displayed
            //So cheking for the error code and displaying the appropriate error
			//@TODO: CR: Can use switch case for multiple error codes. 
			//@TODO: CR: Avoid msg_xxx magical numbers. Provide readable english
            if( aErrorCode == ErrorCode.errorGeneralError ) {
                SSOUIHelper.showError(sso_msg_0008);
            } else if( aErrorCode == ErrorCode.errorNotAuthorized ) {
            	SSOUIHelper.showError(sso_msg_signin_loginfail);
			} else {
                //Get the app error message from the error code
                var _errorMsg = SSOError.getErrorMessage(aErrorCode);
                SSOUIHelper.showError(_errorMsg);
            }    
                
		}
		ovi.debug('SigninController -_signIncallback: Exit');
	},	
	
	/**
	 * Callback function when the update device info request is completed	 	 
	 * @function _updateDeviceInfoComplete
	 * @param {int} aErrorCode - errorcode returned by the enbaler
	 * @param {object} aContext - SSOSignInController pointer returned 
	 */
    _updateDeviceInfoComplete: function(aError, aType, aRequestId, aContext) {
		//@TODO: check if the update device info complete is succesfull or failed.
		//If failed -- ???
		//If the context is account management,launch the account management controller here as the
        //sign is completed
        //Get the context from the settings            
        var context = aContext.applicationController.settings.get('ssoUIContext');
        if( context == SSOConstant.AccountManagement) {
        	ovi.debug("Activating account management");
            aContext.applicationController.activate('SSOAccountManagement');
        } else {	            
            var eventMessageObj= aContext.applicationController.getEventMessageObj();                    
            eventMessageObj.post(context,ssoui.utils.SSOUtil.convertToJSONFormat(SSOConstant.Completed,SSOConstant.SignInCompleted));      
        
            //There is no update in the TOS. Close the widget as the signin is completed
            aContext.closeApplication();
        } 
    },
    
  //@TODO: CR: Function description / name is confusing. Let us have
	// local variables names representing the type of information fetched & returned.
	//@TODO: CR: Rename function with prefix "_" for private
	  /**
	   * @private
	   * Fetch the TOS status Array
	   * @function getTOSStatus
	   */
	  getTOSStatus: function() {
	    var statusinfo = new Array();
	    var _tosModel = this.getModel("SSOTOS");
	    statusinfo = _tosModel.getTOSStatusInfo();    
	    return statusinfo;
	  },
	  
    /**
     * 
     * @function doParentSignIn
     */
    doParentSignIn: function() {
		//Hide the progress bar 
		this.view.showSpinner();
				
        //@TODO: CR: CRITICAL: Try-catch should be handled in Model & not
		//controller - as Model is interacting with Enablers.
		try {   
	    	var _model = this.getModel("SSOParentSignUp");
	    	_model.signInAsGuardian(this._parentSignIncallback, this);
    	} catch(ex) {
    		ovi.debug("Exception in doParentSignIn method " +  ex + "  -  " + ex.message);
    	}    	
    },
    
    //@TODO: CR: MEDIUM : Update aResult in documentation
	/**
	 * @private:
	 * Callback function when the signin is completed	 	 
	 * @function signIncallback
	 * @param (int) aResult -
	 * @param {int} aErrorCode - errorcode returned by the enbaler
	 * @param {object} aContext - SSOSignInController pointer returned 
	 */
    _parentSignIncallback: function(aResult, aErrorCode, aContext) {
    	ovi.debug("_parentSignIncallback aErrorcode: "+ aErrorCode);
	    //If the sign in was successfull
		if(aResult == SSOConstant.Success) {
	        
			//Request has been completed
			//Enable the softkey and hide the progress bar display here
			if(aContext.view._renderer) {   
				//Hide the progress bar 
				aContext.view.hideSpinner();
				//Enable the LSK
				aContext.view.enableLSK();
				//Enable the RSK
				aContext.view.enableRSK();
			}
			
        	aContext.settings.set('isParentSignUp', false);
        	aContext.settings.set('isParentalConsent', true);	        	
            // Either one or more of the terms have been updated in the backend
            // this TOS view is for updation of tos after sign in is completed. 
            // So there must be TOS update string displayed in screen.
           
        	// Fetch the TOS status boolen values on successful retrieval
	        statusinfo = aContext.getParentTOSStatus();
	        
	        // Save the boolean values in settings object so that
	        // TOSController makes use of this
	        aContext.settings.set("HasAcceptedTos",                 statusinfo["HasAcceptedTos"]);
	        aContext.settings.set("HasAcceptedServiceSpecificTos",  statusinfo["HasAcceptedServiceSpecificTos"]);
	        aContext.settings.set("HasAcceptedPrivacyPolicy",       statusinfo["HasAcceptedPrivacyPolicy"]);	        
	        // if all the Terms have been accepted then fire the sign in complete event
	        if(statusinfo["HasAcceptedTos"] == true && statusinfo["HasAcceptedServiceSpecificTos"] == true &&  
	        		statusinfo["HasAcceptedPrivacyPolicy"] == true) {	           
                ovi.debug("User had already accepted TOS");	             
                aContext.deactivate();
                
	            var _accWizard = aContext.applicationController.getController("SSOAccCreateWizard");
                //@TODO: CR: HIGH accessing private variable, due to limitation in wizard controller , will be replaced later with Activate();
                aContext.applicationController._activeControllerName = "SSOAccCreateWizard";                   
	        	_accWizard.addStep("SSOParentalConsent", 2, false);
	        	_accWizard.gotoStep(2);
                
	        } else {
                // Either one or more of the terms have been updated in the backend
                // this TOS view is for updation of tos after sign in is completed. 
                // So there must be TOS update string displayed in screen.
                aContext.settings.set("signintosupdate",true);               
                aContext.applicationController.activate('SSOTOS');
	        }
	        
		} else {
			//@TODO: CR: CRITICAL: Use !== instead of !=. 
			//   No need to use 'typeof'
	         if(typeof aContext.view != "undefined") {
	    		 aContext.view.hideSpinner();
	    		 aContext.view.enableLSK();
	             aContext.view.enableRSK();
	    	 }
	         
			if(aErrorCode == ErrorCode.errorTooYoung) {
				aContext.applicationController.activate("SSOAccFailed");
			} 
			//If the error is an general error then the unable to signin message has to be displayed
            //So checking for the error code and displaying the appropriate error
			//@TODO: CR: HIGH: Use switch case below.
            else if( aErrorCode == ErrorCode.errorGeneralError ) {
                SSOUIHelper.showError(sso_msg_0008);
            } else if( aErrorCode == ErrorCode.errorNotAuthorized ) {
            	SSOUIHelper.showError(sso_msg_0001);
			} else {
                //Get the app error message from the error code
                var _errorMsg = SSOError.getErrorMessage(aErrorCode);
                SSOUIHelper.showError(_errorMsg);
            }  
		}
	},
	
	//@TODO: CR: HIGH: Below method is private. Use Prefix "_:
    /**	 
     * @private
	 * Function which initiates the terms acceptance status retrieval
	 * @function getParentTOSStatus
	 */  
	 getParentTOSStatus: function(aContext){
		var _tosModel = this.getModel("SSOTOS");
		return _tosModel.getParentTOSStatusInfo();
	 },
  
  	/**
     * Checks if the user profile is rememembred or authenticated
     * @return (boolean) true - if authenticated / false - if not
	 */
	isAuthenticated: function() {
		var _signInModel = this.getModel("SSOSignIn");
		return _signInModel.isAuthenticated();	
	},
    
    /**
     * Returns the username stored in the cache
     * @ function getUserName
     * @return {var} username stored
	 */
    getUserName: function() {
		var _signInModel = this.getModel("SSOSignIn");
        return _signInModel.getUserName();
    },
    
    /**
     * Initiate the change password API call to enabler
     * @ function changePassword
     * @param {object} aCallback callback to fired upon completion
     * @param {object} aContext context of the calling instance     
     */  
    changePassword: function( aCallback, aContext ) {        
        var _acctMngt = this.getModel("SSOAcctMngtChangePassword");     
        _acctMngt.changePassword( aCallback, aContext );
    },
	
      /**
     * Initiate the update security question API call to enabler
     * @ function updateSecurityQue
     * @param {object} aCallback callback to fired upon completion
     * @param {object} aContext context of the calling instance     
     */  
    updateSecurityQue: function( aCallback, aContext ){
    	var _acctMngt = this.getModel("SSOAcctMngtChangeSecQue");     
    	_acctMngt.updateSecQue( aCallback, aContext );
    },
    
    /**
     * Sign out the user
     * @ function signOut
     */  
    signOut: function() {
      var _signInModel = this.getModel("SSOSignIn");
      _signInModel.signOut();
    },

    
    /**
     * Get the logged In user id from authentication object
     * @ function getLastLoggedInUserID
     */  
    getLastLoggedInUserID: function() {   		
    	var loginId;
    	var _signInModel = this.getModel("SSOSignIn");
    	loginId = _signInModel.getLastLoggedInID();      
    	return loginId;
    },

    
    /**
     * Close the widget
     * @function closeApplication     
     */
    closeApplication: function() {
    //@TODO: CR: HIGH: Do we need try-catch block here?
    	try {
	    	if(this.view._renderer){
	    		this.view.destroy();
	    	}
    	} catch(ex) { }
    	//@TODO: CR: Catch exception in logs using ovi.error
    	window.close();    	
    },    
	
	/**
     * Close the widget
     * @function getToken
     * @returns {string} token     
     */
	getToken: function() {
		var _signInModel = this.getModel("SSOSignIn");
        return _signInModel.getToken();
	}
});