/**
 *
 * Description : A class that extends ovi.sisu.Controller
 *               Maintains the wizard for the controllers who extends this class. 
 * <p>
 * Filename    : SSOWizardController.js
 * <p>
 * Part of     : Controllers
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   15.1.2 %
 * @class SSOWizardController
 * @name SSOWizardController 
 */

ovi.provide( 'ssoui.controllers.SSOWizardController' );
ovi.require( 'ovi.sisu.ApplicationController' );
ovi.require( 'ovi.sisu.Controller' );
ovi.require( 'ovi.orientation' );
ovi.require( 'ssoui.utils.SSOConstant' ,false );
ovi.require( 'ssoui.utils.SSOUtil' ,false);
ovi.require( 'ssoui.ui.SSOUIHelper' );
ovi.declare( 'ssoui.controllers.SSOWizardController', {
    
    /**
     * SSOWizardController extends the ovi.sisu.Controller class.
     * @extends ovi.sisu.Controller
     */
    Extends: ovi.sisu.Controller,    
    
    /**
     * Creates the objects needed for this controller
     * Calls the base class init function which initiliazes the noa objects needed
     * @function initialize
     */
    initialize: function() {
        this._super();
        
        this._steps = [];
        this._currentStep = null;
		
		//@TODO: CR: SEVERITY: LOW: Remove dead code
        //Get the view to be displayed
        //this.view  = this.getView(); 
        //Get the signin model to get and store the data
        //this.model = this.getModel();    
        var self = this;
        
        ovi.orientation.addEventHandler(ovi.orientation.CHANGE_EVENT, function(ev) {
            if(self.view._renderer)
            {
                ovi.warn("view.cacheViewData() to be implemented for orientation");
                //self.view.cacheViewData();
                //self.view.destroy();
                //self.activate(true);
                if(self.view.onOrientationChange) {
                	self.view.onOrientationChange();
                }
            }     
        });  
    },
    
    activate: function() {
    	this._currentStep = null;
    },	
    
    /**
     * Subscribe for the navigation events - Next/back/Cancel 
     * @function subscribers
     */
    subscribers: {
    	"onLSKClick" : function(){
			//console.log("onLSKClick event subscribered");			
			this.gotoNextStep();          
	    },
	    
	    "onRSKClick" : function(){
	    	//console.log("onRSKClick event subscribered");
	    	this.gotoPreviousStep();
	    },
	    
	    "cancelWizard" : function() {
	    	this.onWizardCancel();
	    },
	    
	    "finishWizard" : function() {
	    	//console.log("finish event subscribered");
	    	this.onWizardFinish();
	    },
	    
	    "cancelParentConsent" : function() {
	    	if(this.showAccFailedView) {
	    		this.showAccFailedView();
	    	}
	    },
		
		"initiateEmailAccountCreation" : function() {
			// 'SSOAccDetails' is added again since 
			// we are using the same screen for initiating email account creation
		  	this.addStep('SSOAccDetails', 1, false);
			this.gotoStep(1);
		},
		
		"removeEmailAccountCreationStep" : function() {
			// Replacing the Email account creation screen with About you screen
			this.addStep('SSOAboutYou', 1, true);
		}
    },
    
    addStep: function(aStep, aIndex, aReplace) {
    	//console.log("inside addStep: "+ aStep);
    	var _index = 0;
    	if(parseInt(aIndex) >= 0){
			if(aReplace == true) {
				this._steps[aIndex] = aStep;
			} else {
				this._steps.splice(aIndex,0,aStep);
			}
			_index = aIndex;
		} else {
			_index = this._steps.length;
			this._steps[this._steps.length] = aStep;
		}
    	return _index;
    },
    
    /**
     * clears all the wizard steps
     * @function clearAllSteps
     */
    clearAllSteps: function() {
    	this._steps = [];
    	this._currentStep = null;
    },
    
    /**
     * function to trigger the next step.
     * @function getNextStep
     */
    getNextStep: function() {
    	var _step = null;
    	if(this._currentStep === null) {
    		this._currentStep = 0;
    		_step = this._steps[this._currentStep];
    	} else {
    		if(this._currentStep < (this._steps.length-1)) {
    			this._currentStep++;
    			_step = this._steps[this._currentStep];
    		}
    	}    	
    	return _step;
    },
    
    getPreviousStep: function() {
    	var _step = null;
    	if(this._currentStep !== null && this._currentStep > 0) {
    		this._currentStep--;
    		_step = this._steps[this._currentStep];
    	}
    	return _step;
    },
    
    getCurrentStep: function() {
    	//console.log("inside getCurrentStep");
    	return this._steps[this._currentStep];
    },
    
    getStep: function(aIndex) {
    	return this._steps[aIndex];
    },
    
    start: function() {
    	//console.log("inside start: "+ this._currentStep);
    	this._currentStep = 0;
    	var _step = this.getStep(0);
    	this.executeStep(_step);
    	//console.log("end start: "+ this._currentStep);
    },
    
    gotoStep: function(aIndex) {
    	this._currentStep = aIndex;
    	var _step = this.getStep(aIndex);
    	this.executeStep(_step);
    },
    
    /**
     * 
     * @function gotoNextStep
     */
    gotoNextStep: function() {
    	var _step = this.getNextStep();
    	if(_step !== null) {
    		this.executeStep(_step);
    	} else {    		
    		//call wizard finish when there is not other step to go forward.
    		this.onWizardFinish();
    	}
    },
    
    gotoPreviousStep: function() {    	
    	var _step = this.getPreviousStep();
    	if(_step !== null) {
    		this.executeStep(_step);
    	} else {
    		
    		//call wizard cancel when there is no step to go backward.
    		this.onWizardCancel();
    	}
    },
    
    /**
     * Function to execute the wizard steps.
     * @function executeStep
     */
    executeStep: function(aStep) {
    	if(typeof aStep == 'function') {
    		var _self = this;
    		aStep(_self.model, _self);    		
    	} else {    		
    		if(typeof this.view !== 'undefined') {
    			if(typeof this.view._renderer != 'undefined') {    				
    				try {
    					this.view.destroy();
    				} catch(ex) {
    					ovi.error("Exception occured while destroying the existing view in SSOWizardController - executeStep: "+ ex.message);
    				}
    			}
    		}
    		this.view = this.getView(aStep);    		
    		this.view.render(this.model);
    	}
    },
	
    /**
     * 
     * @function onWizardFinish.
     */
    onWizardFinish: function() {
    	ovi.debug("Inside onWizardFinish");
    	var _finishValue = this.settings.get("onWizardFinish");
        if  (_finishValue == "SSOAccountManagement" ) {
    		this.applicationController.activate(_finishValue);
        } else {            
    		var eventMessageObj= this.applicationController.getEventMessageObj();
            eventMessageObj.post(this.applicationController.settings.get('ssoUIContext'), ssoui.utils.SSOUtil.convertToJSONFormat(SSOConstant.Completed,SSOConstant.SignUpCompleted));
    		window.close();
        }
    },
    
    /**
     * Cancels the wizard
     * @function cancel
     */
    onWizardCancel: function() {
    	/**
    	 * When user cancels any operation in account creation, sent a cancel event to  
    	 * clients.
    	 */
    	var _cancelValue = this.settings.get("onWizardCancel");
    	if(typeof _cancelValue !== "undefined" && _cancelValue == "CLOSEAPP") {
    		var eventMessageObj= this.applicationController.getEventMessageObj();
        	eventMessageObj.post(this.applicationController.settings.get('ssoUIContext'), ssoui.utils.SSOUtil.convertToJSONFormat(SSOConstant.Error,SSOConstant.Cancelled));
    		window.close();
    	} else {                 
    		this.settings.set("onWizardCancel", "CLOSEAPP");
    		this.applicationController.activate(_cancelValue);
    	}    	
    }
});