/**
 *
 * Description : A class that extends ovi.sisu.Model
 *               Maintains the model wizard for the Account management - Change password usecase 
 * <p>
 * Filename    : SSOAcctMngtChangePasswordModel.js
 * <p>
 * Part of     : Model
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   5 %
 * @class SSOAcctMngtChangePasswordModel
 * @name  SSOAcctMngtChangePasswordModel 
 */
 
 
ovi.provide( 'ssoui.models.SSOAcctMngtChangePasswordModel' );
ovi.require( 'ovi.sisu.Model' );
ovi.require( 'ssoui.utils.SSOConstant',false )
ovi.declare( 'ssoui.models.SSOAcctMngtChangePasswordModel', {
    
    /**
     * SSOAcctMngtChangePasswordModel extends the Model class.
     * @extends ovi.sisu.Model
     */
    Extends: ovi.sisu.Model,
    
    /**     
     * Init the base class
     * @function initialize
     */
    initialize: function() {
        this._super(); 
        //Get the password manager object from the application controller.    
        this._pswdObj = this.applicationController.getPswdObj();  
    },
    
    /**     
     * Store the new password 
     * @function setNewPswd
     * @param {string} aNewPassword - new password entered by the user
     */
    setNewPswd: function(aNewPassword) {
        //Store the new passoword
        this._newPswd = aNewPassword;
    },
    
    /**     
     * Store the old password 
     * @function setOldPswd
     * @param {string} aCurrentPassword - current password entered by the user
     */
    setCurrentPswd: function(aCurrentPassword) {
        //Store the current passoword
        this._currPswd = aCurrentPassword;
    },
    
    /**     
     * Calls the enabler API to change the passowrd
     * @function changePassword
     * @param {string} aCallback - Callback API to be triggerred when change pswd is completed
     * @param {context} aContext - this pointer of the calling function
     */
    changePassword: function( aCallback, aContext) {         
        //Store the callback API to be called
        this._callback = aCallback;        
        //Store the context of the account management change password controller.
        this._context = aContext;
        //@TODO: CR: CRITICAL: Needs to be in try-catch block
		//@TODO: CR: HIGH: Below code can be written using anonymous inline function
        //calls the enabler API to change the password
        this._pswdObj.changePassword( this._changePswrdComplete, this._currPswd, this._newPswd, this );
    },
    
   /**
     * function to show password strength
     * @function passwordStrength
     */
    passwordStrength : function(aPassword) {    
    	this._regobj = this.applicationController.getRegObj();
		//@TODO: CR: CRITICAL: Needs to be in try-catch block
    	return this._regobj.passwordStrength(aPassword);    	
    },
    /**     
     * Callback API when the password change is completed
     * @function _changePswrdComplete
     * @param {var} aError - error code of the request
     * @param {var} aType - request type
     * @param {var} aRequestId - request id
     * @param {object} aContext - this pointer
     */
    _changePswrdComplete: function( aError, aType, aRequestId, aContext ){
        //Check the request type and the error code returned
        if( aType == RequestType.requestChangePassword && ( aError == ErrorCode.errorNone )) {
            //Send the request as success 
            aContext._callback(SSOConstant.Success,aError,aContext._context);
        } else {       
            //Send the request has failed
            aContext._callback(SSOConstant.Failure,aError,aContext._context);
        } 
    
    }
});