/**
 *
 * Description : A class that extends ovi.sisu.Model is used for reset password usecase.
 *  
 * <p>
 * Filename    : SSOForgotPasswordModel.js
 * <p>
 * Part of     : Model
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   6.1.1 %
 * @class SSOForgotPasswordModel
 * @name SSOForgotPasswordModel 
 */
 
ovi.provide( 'ssoui.models.SSOForgotPasswordModel' );
ovi.require( 'ovi.sisu.Model' );
ovi.declare( 'ssoui.models.SSOForgotPasswordModel', {
  
  /**
  * SSOForgotPasswordModel extends the ovi.sisu.Model class.
  * @extends ovi.sisu.Model
  */
  Extends: ovi.sisu.Model,

  /**	 
  * Constructor, the profilemanager and registration objects 
  * @function initialize
  */
  initialize: function() {
    // Base class constructor is called here
    this._super();
    this._emailId = "";
    this._countryCode = "";
    this._mobileNumber = "";
    this._captchaText = "";
  },
  
  /**	 
  * Setter method for email
  * @function setEmail
  */
  setEmail: function(aEmail){
	  this._emailId =  aEmail;
  },
  
  /**
   * Getter method for email
   * @function getEmail
   */
  getEmail: function() {
	  return this._emailId;
  },
  
  /**	 
   * Setter method for country code
   * @param {String} aCountryCode country code of the mobile number
   * @function setCountryCode   
   */
   setCountryCode: function(aCountryCode){
 	  this._countryCode =  aCountryCode;
   },
   
   /**
    * Getter method for country code
    * @function getCountryCode
    * @returns (String) country code of the mobile number
    */
   getCountryCode: function() {
 	  return this._countryCode;
   },
  
  /**	 
   * Setter method for mobile number
   * @function setMobileNumber
   */
   setMobileNumber: function(aMobileNumber){
	  this._mobileNumber =  aMobileNumber;
   },
   
   /**
    * Getter method for mobile number
    * @function getMobileNumber
    */
   getMobileNumber: function() {
	   return this._mobileNumber;
   },
  
  
 /**	 
  * Setter method to store Captcha text in the model
  * @function setCaptcha
  */
  setCaptcha: function(aCapchaText) {
    this._captchatext =  aCapchaText
  },
  
  /**	 
  * Getter method, which returns captcha text 
  * @function initialize
  * @returns {string} The captach text
  */
  getCaptcha: function() {
    return this._captchatext; 
  },
  
  /**
   * Checks whether captcha is required or not
   * @function  isCaptchaRequired
   * @returns true on success false on failure   
   */
  isCaptchaRequired: function() {        
	try{
		var _registrationobject = this.applicationController.getRegObj();
		return _registrationobject.isCaptchaRequired();
	} catch(ex) {			
		ovi.debug("Exception in SSOPRModel in isCaptcha required " +  ex + "  -  " + ex.message);
		return false;
	}
  },
  
  /**
   * Initiate the retrieval of captcha  	 
   * @function retrieveCaptchaImage
   * @param {object} aCallback callback to be fired upon completion
   * @param {object} aContext Context from which this function was called      
   */
  retrieveCaptchaImage: function(aCallback, aContext) {
  	//@TODO: CR: HIGH: Use CSS file instead of hard-coding
    var captchawidth = 200;
    var captchaheight = 80;
    //@TODO: CR: CRITICAL: Use try-catch below
    var _passwordmgrobject = this.applicationController.getPswdObj();
    _passwordmgrobject.retrieveCaptchaImage(aCallback, captchawidth, captchaheight, aContext);

    //@TODO: CR: MEDIUM: Remove dead code
    //Store the request id so that we can use this to cancel the request
    //var requestId = this._passwordmgrobject._connectId;    
    
    //Checks if the request has failed, then Fire the event!        
    //this.checkRequestStatus(status, RequestType.PasswordManager, requestId);
    
  },
  
  /**	 
  * Constructor, the profilemanager object is fetched from application
  * controller here
  * @function initialize
  */
  captchaImage: function() {
  	//@TODO: CR: CRITICAL: Use try-catch block below
	var _passwordmgrobject = this.applicationController.getPswdObj();  
    return _passwordmgrobject.captchaImage();
  },
  
  /**
  * Initates the send reset message query. The reset code will be sent via
  * email or message
  * @function  sendResetMessage
  * @param {object} aCallback function to be called when request completes       
  * @param {object} aContext Context from which this function was called      
  */
  sendResetMessage: function(aCallback, aContext) {  
    //Send the request for the reset code
    // The 4th parameter is the sent as "true" wihch means we are requesting 
    // The Enabler to send the "Password reset link", if we send as false a
    // Password reset request code will be sent. We always require as link
    // since users can click on link which will direct them to appropriate screen.
    // NOTE: we HAVE to use true or false NOT 1 or 0 		
	try {
		var _emailormobilenumber = this.getMobileNumber().length > 0 ? this.getCountryCode()+""+this.getMobileNumber() :  this.getEmail();   
		var _passwordmgrobject = this.applicationController.getPswdObj();
		_passwordmgrobject.sendResetMessage(aCallback, this.getCaptcha(), _emailormobilenumber, true, aContext);
	} catch(ex) {
		ovi.error("Error while calling sendResetMessage: "+ ex.message);
		aCallback(ErrorCode.errorGeneralError, RequestType.requestResetMessage, 0, aContext);
	}
  }
  
});