/**
 *
 * Description : A class that extends ovi.sisu.Model
 *               Maintains the wizard for the signin usecase 
 * <p>
 * Filename    : SSOSignInModel.js
 * <p>
 * Part of     : Model
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * Version     : %version:  11 %
 * @class SSOSignInController
 * @name SSOSignInController 
 */
 
 
ovi.provide( 'ssoui.models.SSOSignInModel' );
ovi.require( 'ovi.sisu.Model' );
ovi.require( 'ssoui.utils.SSOConstant',false )
ovi.declare( 'ssoui.models.SSOSignInModel', {
    
    /**
     * SSOSignInModel extends the SSOSignInModel class.
     * @extends ovi.sisu.SSOSignInModel
     */
    Extends: ovi.sisu.Model,
    
    /**     
     * Init the base class
     * @function initialize
     */
    initialize: function() {
        this._super();
		//@TODO: CR: Initialize variables (Username, password, etc) to default 
		//See similar comment in SignUPModel.js       
    },
    
    /**     
     * Store the given username 
     * @function setUsername
     * @param {string} aUsername - username entered by the user
     */   
    setUsername: function(aUsername) {
        this.userName = aUsername;
    },
    
    /**     
     * Store the given password 
     * @function setPassword
     * @param {string} aPassword - password entered by the user
     */   
    setPassword: function(aPassword) {
        this.pswrd = aPassword;
    },
    
	//@TODO: CR: Passing "unchanged" is not an integer. Set local default 
	//value to 2(Better use enumeration) & avoid resetting from SignInController.js
	// OR if requierd, provide a new method to say resetRememberMe, which sets
	// rmbrme to 2 (use equivalent enumeration)
    /**     
     * Store the remember me settings
     * @function setRmbrMe
     * @param {int} aRmbrme - remember me settings entered by the user
     */
    setRmbrMe: function(aRmbrme) {
        if(aRmbrme == true) {        
            this.rmbrme = 1;
        } else if(aRmbrme == false) {
            this.rmbrme = 0;
        } else if(aRmbrme == "unchanged"){
            this.rmbrme = 2;
        }           
    },
    
    /**     
     * Returns the username stored
     * @function getUsername
     * @return {string} userName  
     */
    getUsername: function() {
        return this.userName;
    },
    
    /**     
     * Returns the password stored
     * @function getPassword
     * @return {string} password  
     */
    getPassword: function() {
        return this.pswrd;
    },
    
	//@TODO: CR: MEDIUM We should be returning bool.
    /**     
     * Returns the remember me settings stored
     * @function getRmbrMe
     * @return {int} rmbr me  
     */
    getRmbrMe: function() {
        return this.rmbrme;
    },
    
    /**     
     * Returns true/false if session is active/pswd remembered
     * @function isAuthenticated
     * @return {bool} isAuthenticated
     */
    isAuthenticated: function() {
	//Get the authentication object from the application controller
	var authObj = this.applicationController.getAuthObj();		
        try {
            return authObj.isAuthenticated();	
	} catch(ex){			
	    ovi.error("Exception in SignInModel - isAuthenticated " +  ex + "  -  " + ex.message);
	    //There is an exception from the DE API. Return false by default			
	    return false;			
	}                
    },
	
	 /**     
     * Returns token, if the user has signed in and session is active and widget
     * not closed
     * @function getToken
     * @return {srting} token
     */
    getToken: function() {
    //Get the authentication object from the application controller
    var authObj = this.applicationController.getAuthObj();      
        try {
            return authObj.token();   
    } catch(ex){            
        ovi.error("Exception in SignInModel - token() " +  ex + "  -  " + ex.message);
        //There is an exception from the DE API. Return false by default            
        return false;           
    }                
    },
    
    /**     
     * Returns true/false if password was remembered
     * @function isPasswordRmbrd
     * @return {bool} isPasswordRmbrd
     */
    isPasswordRmbrd: function() {
        //@TODO: CR: No need to use this._authobj. van directly
        // assign to local var
        this._authobj = this.applicationController.getAuthObj();  
	try {
	    return this._authobj.isPasswordRemembered();	
	}catch(ex){
	    ovi.error("Exception in SignInModel - isPasswordRmbrd " +  ex + "  -  " + ex.message);
	    //There is an exception from the DE API. Return false by default			
	    return false;
	}
    },
    
    /**     
     * Calls the enabler SignIn API
     * @function signIn
     * @param {function} aCallback - callback API to be called when the signin is completed
     * @param {object} aContext - this pointer
     */
    signIn: function(aCallback,aContext) {    
        //@TODO: CR: HIGH We do not really need to store this._callback & this._context.
        // we can write an anonymous function within this function & use local variables. 
        // can avoid one private method.
		//@TODO: CR: Can directly use var instead of this._authobj
        this._callback = aCallback;
        this._context = aContext;
        this._authobj = this.applicationController.getAuthObj();
		//@TODO: CR: Below code is not under try-catch block            
        this._authobj.signIn( this._signInCompleted,this.pswrd,this.userName,this.rmbrme,this );
    },
    
	//@TODO: CR: Below code will go in above method
    /**     
     * Callback API when the signin is completed
     * Enabler object calls this API when the signin request is completed
     * @param {var} aError - error code of the request
     * @param {var} aType - request type
     * @param {var} aRequestId - request id
     * @param {object} aContext - this pointer
     */
    _signInCompleted: function(aError, aType, aRequestId, aContext) {    
        if( aType == RequestType.requestSignIn && ( aError == ErrorCode.errorNone || aError == ErrorCode.errorAccountNotActivated ) ) {             
            //Send the request as success 
            aContext._callback(SSOConstant.Success,aError,aContext._context);
        } else {                
            aContext._callback(SSOConstant.Failure,aError,aContext._context);
        } 
    },
    
    /**     
     * Remove the user credentials stored in the cache
     * @function removeCachedData
     */
    removeCachedData: function() {   
        //Get the authentictaion object 
        //TODO: CR: We can have local var instead of this._authobj
        this._authobj = this.applicationController.getAuthObj();
        //Remove the usercredentials stored.This is a synch call
	//we need not have a try catch here as the accmgmnt controller and the
	//rmbr view handles the error cases and displays the error		        
        this._authobj.removeCachedAccount();
    },
    
	
    /**     
     * Returns the login Id string - email/username that was previously used
	 * to login
     * @function getLastLoggedInID
     * @return {var} lastloginId
     */
    getLastLoggedInID: function() {
        //TODO: CR: We can have local var instead of this._authobj
        this._authobj = this.applicationController.getAuthObj();
	try {		
	    return this._authobj.lastLoggedInIdentifier();
		
	}catch(ex){
	    ovi.error("Exception in SignInModel - getLastLoggedInID " +  ex + "  -  " + ex.message);
	    //There is an exception from the DE API. Return empty loginId by default
	    var loginId = "";	
	    return loginId;
		}
    },
    
    /**
     * Sign out the user
     * @function signOut
     */ 
    signOut: function(){
        //TODO: CR: We can have local var instead of this._authobj
        this._authobj = this.applicationController.getAuthObj();
        //we need not have a try catch here as the TOS controller
	//handles the error cases and displays the error on the view	
        this._authobj.signOut();
    }
});