/**
 *
 * Description : A class that extends ovi.sisu.Model
 *               Maintains the wizard for the signin usecase 
 * <p>
 * Filename    : SSOSignInModel.js
 * <p>
 * Part of     : Model
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 *  Version     : %version: 19.1.2 %
 * @class SSOSignInController
 * @name SSOSignInController 
 */
 
//@TODO: CR: Add space before closing parenthesis. 
ovi.provide('ssoui.models.SSOSignUpModel');
ovi.require('ovi.sisu.Model');
ovi.require('ssoui.utils.SSOConstant',false);
ovi.require( 'ssoui.SSOBuildConfigure',false );
ovi.require( 'ssoui.services.SSOCountryName', false );
ovi.declare('ssoui.models.SSOSignUpModel', {
    
    /**
     * SSOSignInModel extends the SSOSignInModel class.
     * @extends ovi.sisu.Model
     */
    Extends: ovi.sisu.Model,
    
    /**     
     * Init the base class
     * @function initialize
     */
    initialize: function() {
        this._super();
		//@TODO: CR: Use all local variables with '_' prefix & hungarian notation
        this.registerationInfo = null;
		//@TODO: CR: CRITICAL Default initialization of username &password should be empty string ""
        this.username = ""; 
        this.password = "";
		//@TODO: CR: Below variable (rememberme) is  not used anywhere (methods seems using them seems to be depricated)
        this.rememberme = "";
        this.mobilenumber = "";
        this.emailid = "";
        this.country = "";
        this.language = "";
        this.dob = "";
        this.captchcode = "";
        
        this.gurdiantoken = "";
		
		// TODO: We need to decide on the default value for this
		this.consentvalue = ConsentQueryVariant.QueryVariantImplicit;
    },
    
    /**     
     * Store the given username 
     * @function setUsername
     * @param {string} aUsername - username entered by the user
     */   
    setUsername: function(aUsername) {
        this.username = aUsername;
    },
    
    /**     
     * Returns the username stored
     * @function getUsername
     * @return {string} userName  
     */
    getUsername: function() {
        return this.username;
    },
    
    
    /**     
     * Store the given password 
     * @function setPassword
     * @param {string} aPassword - password entered by the user
     */   
    setPassword: function(aPassword) {
        this.password = aPassword;
    },
    
    /**     
     * Returns the password stored
     * @function getPassword
     * @return {string} password  
     */
    getPassword: function() {
        return this.password;
    },
    
	//@TODO: CR: Below function is no longer used. 
	// Signup view is using method from signIn Model. 
    /**     
     * Store the remember me settings
     * @function setRememberme
     * @param {int} aRmbrme - remember me settings entered by the user
     */
    setRememberme: function(aRmbrme) {
        if(aRmbrme == true) {        
            this.rememberme = 1;
        } else if(aRmbrme == false) {
            this.rememberme = 0;
        } else if(aRmbrme == "unchanged"){
            this.rememberme = 2;
        }           
    },
    
    //@TODO: CR: Below function is no longer used. 
    /**     
     * Returns the remember me settings stored
     * @function getRmbrMe
     * @return {int} rmbr me  
     */
    getRememberme: function() {
        return this.rememberme;
    },
    
	//@TODO: CR: Invalid function description block
    /**     
     * Store the given password 
     * @function setPassword
     * @param {string} aPassword - password entered by the user
     */   
    setMobilenumber: function(aMobilenumber) {
        this.mobilenumber = aMobilenumber;
    },
    
    //@TODO: CR: Invalid function description block
    /**     
     * Returns the password stored
     * @function getPassword
     * @return {string} password  
     */
    getMobilenumber: function() {
        return this.mobilenumber;
    },
    
    //@TODO: CR: Invalid function description block
    /**     
     * Store the given password 
     * @function setPassword
     * @param {string} aPassword - password entered by the user
     */   
    setEmailid: function(aEmailid) {
        this.emailid = aEmailid;
    },
    
    //@TODO: CR: Invalid function description block
    /**     
     * Returns the password stored
     * @function getPassword
     * @return {string} password  
     */
    getEmailid: function() {
        return this.emailid;
    },
	
	/**     
     * Store the ovi Email id
     * @function setOviEmailid
     * @param {string} aEmailid - email id entered by the user
     */   
    setOviEmailid: function(aEmailid) {
        this.oviemailid = aEmailid;
    },
	
	/**     
     * Store the ovi password 
     * @function setOviEmailPassword
     * @param {string} aPassword - password entered by the user
     */   
    setOviEmailPassword: function(aOviEmailPassword) {
        this.oviemailpassword = aOviEmailPassword;
    },
	
	/**     
     * Fetch the ovi Email id
     * @function getOviEmailid
     * @returns {string} this.oviemailid - email id entered by the user
     */   
    getOviEmailid: function() {
		
		if(typeof this.oviemailid !== 'undefined') {
			return this.oviemailid;
		}
		else {
			return "";
		}
    },
    
    /**     
     * Fetch the ovi password 
     * @function getOviEmailPassword
     * @returns {string} this.oviemailpassword - password entered by the user
     */   
    getOviEmailPassword: function() {
        return this.oviemailpassword;
    },
	
    
    //@TODO: CR: Invalid function description block
    /**     
     * Store the given password 
     * @function setPassword
     * @param {string} aPassword - password entered by the user
     */   
    setCountry: function(aCountry) {
        this.country = aCountry;
    },
    
    //@TODO: CR: Invalid function description block
    /**     
     * Returns the password stored
     * @function getPassword
     * @return {string} password  
     */
    getCountry: function() {
        return this.country;
    },
    
    //@TODO: CR: Invalid function description block
    /**     
     * Store the given password 
     * @function setPassword
     * @param {string} aPassword - password entered by the user
     */   
    setDOB: function(aDOB) {
        this.dob = aDOB;
    },
    
    //@TODO: CR: Invalid function description block
    /**     
     * Returns the password stored
     * @function getPassword
     * @return {string} password  
     */
    getDOB: function() {
        return this.dob;
    },
   
    /**     
     * Store the given captcha Code 
     * @function setPassword
     * @param {String} aCaptchaCode - code entered by the user
     */   
    setCaptchcode: function(aCaptchaCode) {
        this.captchcode = aCaptchaCode;
    },
    
    /**     
     * Returns the captcha code stored
     * @function getCaptchcode
     * @return {String} captchaCode. "" if not set.  
     */
    getCaptchcode: function() {
        return this.captchcode;
    }, 
    
    //@TODO: CR: Invalid function description block
    /**     
     * Store the given password 
     * @function setPassword
     * @param {string} aPassword - password entered by the user
     */   
    setLanguage: function(aLanguage) {
    	this.language = aLanguage;
    },
    
    //@TODO: CR: Invalid function description block
    /**     
     * Returns the password stored
     * @function getPassword
     * @return {string} password  
     */
    getLanguage: function() {
        return this.language;
    },
	
	 /**     
     * Store the marketing consent value 
     * @function setConsentValue
     * @param {string} aConsentValue - Marketing consent given by the user
     */   
    setConsentValue: function(aConsentValue) {
        this.consentvalue = aConsentValue;
    },
    
    /**     
     * Returns the Marketing consent value
     * @function getConsentValue
     * @return {string} consentvalue  
     */
    getConsentValue: function() {
        return this.consentvalue;
    },
    
    //@TODO: CR: Invalid function description block
	/**     
	 * Store the given username 
	 * @function setUsername
	 * @param {string} aUsername - username entered by the user
	 */   
	setGurdiantoken: function(aGurdiantoken) {
	    this.gurdiantoken = aGurdiantoken;
	},
	
    //@TODO: CR: Invalid function description block
	/**     
	 * Returns the username stored
	 * @function getUsername
	 * @return {string} userName  
	 */
	getGurdiantoken: function() {
	    return this.gurdiantoken;
	},
	

    /**     
     * Returns true/false if session is active/pswd remembered
     * @function isAuthenticated
     * @return {boolean} isAuthenticated
     */
    isAuthenticated: function() {
        var _authobj = this.applicationController.getAuthObj();		
		try {
			return _authobj.isAuthenticated();    
		} catch(exception) {
			ovi.error("Exception in  isAuthenticated SignUpModel " +  exception + "  -  " + exception.message);
			return false;
		}
    },
    
    /**     
     * Returns the username that was stored
     * @function getUserName
     * @return {var} username
     */
    getPredetectUserName: function() {
		var _authobj = this.applicationController.getAuthObj();		
		try {
			return this._authobj.userName();  
		} catch(exception) {
			ovi.error("Exception in  passwordStrength SignUpModel " +  exception + "  -  " + exception.message);
			return "";
		}
    },
    
    //@TODO: CR: Function description is missing
    /**
     * @function detectPreAccount
     */
    detectPreAccount: function(aCallback, aContext){
        //@TODO: CR: HIGH We do not really need to store this._callback & this._context.
        // we can write an anonymous function within this function & use local variables. 
        // can avoid one private method.        
    	this._callback = aCallback;
    	this._context = aContext;
	    try {
	        //TODO: CR: We can have local var instead of this._regobj
	    	this._regobj = this.applicationController.getRegObj();
	    	this._regobj.detectPreAccount(this._detectPreAccountComplete, this);
	    } catch(ex) {
	    	ovi.debug(" detect pre account " + ex + "  -  " + ex.message);	    	
	    	this._callback(SSOConstant.Failure, ErrorCode.errorOperationFailed, aContext);
	    }
    },
    
    //@TODO: CR: Function description is missing
    /**
     * 
     * @function 
     */
    _detectPreAccountComplete: function(aError, aType, aRequestId, aContext) {
    	if(aError == ErrorCode.errorNone || aError == ErrorCode.errorAccountNotActivated) { 
    		aContext._callback(SSOConstant.Success, aError, aContext._context);
        } else {
        	aContext._callback(SSOConstant.Failure, aError, aContext._context);        	
        }
    },
    
    //@TODO: CR: Function description is missing
	//@TODO: CR: Should preAccountInfo be populated only when username or id is available?
    /**
     * @function getPreAccount
     */
    getPreAccount: function() {
        var _regobj = this.applicationController.getRegObj();
		try {
			var _preAcc = _regobj.preAccount();
				    	
	    	var preAccountInfo = new Object();
	    	preAccountInfo.username = _preAcc["UserName"];
	    	preAccountInfo.preaccountid = _preAcc["PreAccountId"];
			//Get the mobile number from the preaccount Info		
			this.mobilenumber = _preAcc["Mobile"];	
			//Get the country code from the preaccountinfo				
			var countrycode = _preAcc["Country"];
			this.country = this.getCountryName(countrycode);		
	    	return preAccountInfo;
	    } catch(exception) {
	    	ovi.error("Exception in  passwordStrength SignUpModel " +  exception + "  -  " + exception.message);
			return;
		}
    },
	
	/**
	 * Gets the country name from the country code
	 * @function getCountryName
	 * @param{string} aCountryCode
	 * @return{string} aCountryName
	 */
	 getCountryName: function(aCountrycode) {
		return SSOCountryName.getCountryNameFromCode(aCountrycode);
	 },
	
	//@TODO: CR: In case of error, nothing is returned?
    /**
     * 
     * @function isCaptchaRequired
     */
    isCaptchaRequired: function() {
    	try {
    		var _regobj = this.applicationController.getRegObj();
    		//return _regobj.isCaptchaRequired();
    		return true;
    	} catch(ex) {
            ovi.error("Exception in SSOSignUpModel.js - isCaptchaRequired " +  ex + "  -  " + ex.message);
			return false;
    	}
    },
    
    //@TODO: CR: Function description & return not explained
    /**
     * 
     * @function getRegsiterationInfo
     */
    getRegsiterationInfo: function() {
    	try {
    		this.registerationInfo = new Object();
            var isemailaccountcreation = this.settings.get('isEmailAccountCreationInitiated');                                                                                                                                                                                                              
            if(isemailaccountcreation == true) {
            	this.registerationInfo.password = this.getOviEmailPassword();                                                                                                                          
            	this.registerationInfo.emailAddress = this.getOviEmailid();
        	} else {
        		this.registerationInfo.password = this.getPassword();                                                                                                                                  
                this.registerationInfo.emailAddress = this.getEmailid();                                                                                                                               
            }
            
	    	this.registerationInfo.captchaText = this.getCaptchcode();
	    	this.registerationInfo.mobilePhoneNumber = this.getCountry()+""+this.getMobilenumber();
		
	    	var _tempArray = this.getDOB().split('-');
	    	this.registerationInfo.dob=this.getDOB();
	    	this.registerationInfo.dateOfBirth = new Date(_tempArray[2]*1, _tempArray[0]*1-1, _tempArray[1]*1);
            this.registerationInfo.languagestring =  "en";//this.applicationController.getPhoneLang();
            //retrive the contry name from model
            //@todo country drop down tumber is integrated this part of the check is not required.
	    	var countryName = SSOCountryName.getCntryCodeFrmMobileCountryCode(this.getCountry());
	    	if(countryName === "undefined") {
	    		countryName = "IN";
	    	}
	    	//this.registerationInfo.country = countryName;
	    	this.registerationInfo.countrystring = countryName;
	    	
	    	//Note: This is used for storing the country code entered by the user
	    	//to prepopulate in parent consent. 
	    	this.registerationInfo.countryCode = this.getCountry();
	    	this.registerationInfo.mobileNumber = this.getMobilenumber();
	    		
	    	return this.registerationInfo;
    	} catch(ex) {
    		ovi.debug("Exception in SSOSignUpModel.js - getRegsiterationInfo  " +  ex + "  -  " + ex.message);
    	}
    },
        
    //@TODO: CR: Function description block missing
    /**
     * 
     * @function  
     */
    registerAccount: function(aCallback, aContext) {
    	ovi.debug('Inside SSOSignupModel - registerAccount');
        //@TODO: CR: HIGH We do not really need to store this._callback & this._context.
        // we can write an anonymous function within this function & use local variables. 
        // can avoid one private method.		
    	this._callback = aCallback;
    	this._context = aContext;
    	
		try {
			//TODO: CR: We can have local var instead of this._regobj
            this._regobj = aContext.applicationController.getRegObj();
			var registerationInfo = this.getRegsiterationInfo();
			
			
	    	var _preAccountId = aContext.settings.get("preaccountid"); 
			//@TODO: CR: CRITICAL use '!=='. No reason to have typeof
			//@TODO: CR: Add comment on the business logic of why preaccount reg	    	
	    	if(typeof _preAccountId != "undefined") {
	    		ovi.debug('SSOSignupModel - calling registerPreAccount');
	    		this._regobj.registerPreAccount(this._registerAccountComplete, registerationInfo, _preAccountId, this.gurdiantoken, this);
	    	} else {
	    		ovi.debug('SSOSignupModel - calling registerAccount');
	    		this._regobj.registerAccount(this._registerAccountComplete, registerationInfo, this.gurdiantoken, this);
	    	}	    	
	    } catch(exception) {
	    	ovi.error("Exception in SSOSignUpModel.js registerAccount " +  exception + "  -  " + exception.message);	    	
			this._callback(SSOConstant.Failure, ErrorCode.errorGeneralError, this._context);	
		}	
    },
    
    //@TODO: CR: Function description block missing
    //@TODO: CR: Read my comment in registerAccount 
    /**
     * 
     * @function
     */
    _registerAccountComplete: function(aError, aType, aRequestId, aContext) {
    	if((aType == RequestType.requestRegisterAccount || aType == RequestType.requestRegisterPreAccount) && (aError == ErrorCode.errorNone || aError == ErrorCode.errorAccountNotActivated)) {
    		aContext._callback(SSOConstant.Success, aError, aContext._context);
    	} else {
    		aContext._callback(SSOConstant.Failure, aError, aContext._context);
    	}
    },


    /**
     * function to show password strength
     * @function passwordStrength
     * @return (int)
     */
    passwordStrength : function(aPassword) {
    	var _regobj = this.applicationController.getRegObj();
		try {
			return _regobj.passwordStrength(aPassword);
		} catch(exception) {
			ovi.error("Exception in  passwordStrength SignUpModel " +  exception + "  -  " + exception.message);
			return 0;
		}
    },
    
    /**
     * clears all the stored values
     * @function _clear
     */
    _clear: function() {
    	this.registerationInfo = null;
        //@TODO: CR: CRITICAL Default initialization of username &password should be empty string ""
        this.username = null;
        this.password = null;
        this.rememberme = null;
        this.mobilenumber = null;
        this.emailid = null;
        this.country = null;
        this.language = null;
        this.dob = null;
        this.captchcode = "";        
        this.gurdiantoken = null;
    },
    
    //@TODO: CR: Function description block missing
    retrieveUsernameAvailability: function(aCallback, aUsername, aContext) {
		//@TODO: CR: HIGH We do not really need to store this._callback & this._context.
		// we can write an anonymous function within this function & use local variables. 
		// can avoid one private method.
      this._callback = aCallback;
      this._context = aContext;
      
      // This has to  be used only once in the constructor, we are repeating this line in every method.
        //TODO: CR: We can have local var instead of this._regobj
      this._regobj = this.applicationController.getRegObj();
      try {
        this._regobj.retrieveUserNameAvailability(this._retrieveUsernamesComplete, aUsername, this);
      }
      catch(ex) {
        ovi.debug("Exception in  SSOSignUpModel.js - retrieveUsernameAvailability " +  ex + "  -  " + ex.message);
        this._callback(ErrorCode.errorOperationFailed, RequestType.requestRetrieveUserNameAvaiability, 0, this);
      }
    },
    
    //@TODO: CR: Function description block missing
    fetchAvailableUserNames: function() {
      	var _regobj = this.applicationController.getRegObj();      
       	try {
        	return _regobj.availableUserNames();
      	} catch(ex) {	  	
        	ovi.error("Exception in  fetchAvailableUserNames SignUpModel " +  ex + "  -  " + ex.message);
        	//return empty array in case of exception. This doesnt effect the user registeration process, 
        	//the username availability check wll be done by the server before registering the user.
        	return new Array();
      	}
    },
    
    //@TODO: CR: Function description block missing
	//@TODO: CR: Read my comment in retrieveUsernameAvailability 
    _retrieveUsernamesComplete: function(aError, aType, aRequestId, aContext) {
       //@TODO: CR: CRITICAL. Below code should be 
       //    aContext._callback(aError, aType, aRequestId, aContext._context);
       aContext._callback(aError, aType, aRequestId, aContext);
    },
	
	/**
	 * Wrapper that makes call to getConsentQueryVariant API
     * @function getConsentQueryVariant
     * @param {object} aCallback Callback to be fired on completion
     * @param {object} aContext This string contains the request type
     */       
	getConsentQueryVariant: function(aCallback, aContext) {
		
		//@TODO: CR: HIGH We do not really need to store 
		// this._callback & this._context. we can write an anonymous function 
		// within this function & use local variables. 
		// can avoid one private method.
		this._callback = aCallback;
		this._context = aContext;
		
		// This has to  be used only once in the constructor, 
		// we are repeating this line in every method.
		//TODO: CR: We can have local var instead of this._regobj
		this._regobj = this.applicationController.getRegObj();
		try {
		this._regobj.getConsentQueryVariant(this._getConsentQueryVariantComplete, this);
		}
		catch(ex) {
			ovi.error("Exception in  SSOSignUpModel.js - getConsentQueryVariant " +  ex + "  -  " + ex.message);
			this._callback(ErrorCode.errorOperationFailed, RequestType.requestNone, 0, aContext);
		}
	},
	
	/**
     * The callback which is fired on completion of aynchronous 
     * getConsentQueryVariant call
     * @function _getConsentQueryVariantComplete
     * @param {object} aError This object contains the error info
     * @param {string} aType This string contains the request type
     * @param {number} aRequestId This number has the request id
     * @param {object} aContext The calling context, this is the context
     *                          from which the original async API was called
     */
    _getConsentQueryVariantComplete: function(aError, aType, aRequestId, aContext) {
       // @TODO: CR: CRITICAL. Below code should be 
       // aContext._callback(aError, aType, aRequestId, aContext._context);
       aContext._callback(aError, aType, aRequestId, aContext);
    },
	
	/**
     * Synchronous call to retrieve consent type
     * @function getConsent
     * @returns {number} consent type
     */
	getConsent: function() {
		
		var _regobj = this.applicationController.getRegObj();      
        try {
            return _regobj.getConsent();
        } catch(ex) {       
            ovi.error("Exception in  getConsent SignUpModel " +  ex + "  -  " + ex.message);
            return  ConsentQueryVariant.QueryVariantImplicit;
        }
		
	}

});