/**
 *
 * Description : A class that extends ovi.sisu.Model
 *               Maintains the wizard for the signin usecase 
 * <p>
 * Filename    : SSOTOSModel.js
 * <p>
 * Part of     : Model
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOTOSModel
 * @name SSOTOSModel
 */
 
 
ovi.provide( 'ssoui.models.SSOTOSModel' );
ovi.require( 'ovi.sisu.Model' );
ovi.require( 'ssoui.utils.SSOConstant',false )
ovi.require( 'ssoui.utils.SSOUtil', false);

ovi.declare( 'ssoui.models.SSOTOSModel', {
    
  /**
  * TOSModel extends the SSOSignInModel class.
  * @extends ovi.sisu.SSOSignInModel
  */
  Extends: ovi.sisu.Model,

  /**	 
  * Constructor, the profilemanager object is fetched from application
  * controller here
  * @function initialize
  */
  initialize: function() {
    // Base class constructor is called here
    this._super();
    
  },
  
  /**	 
  * Retrieve the TOS values, this is an asynchronous call done to enabler
  * to initiate the TOS values population  
  * @function retrieveTermsOfService
  * @param {function} aCallback - callback function to be called when the signin request is completed
	* @param {object}  aContext - object of the calling class. We need this to provide the object to the calling
	*                            class as this pointer is not accessible	  
  */
  retrieveTermsAcceptance: function(aCallback, aContext) {
   try {
         var _profilemanagerobject = this.applicationController.getProfObj();
         // initiate the retrieval in enabler with this API
         _profilemanagerobject.retrieveTermsAcceptance(aCallback, aContext);
    } 
    catch(ex) {
        ovi.debug("Exception in  SSOTOSModel.js " +  ex + "  -  " + ex.message);
        aCallback(ErrorCode.errorOperationFailed, RequestType.requestRetrieveTermsAcceptance, 0, aContext);
    }
  },

  
  /**	 
  * This functions returns the array of boolen values of the terms to be accepted
  * @function getTOSStatusInfo
  */
  getTOSStatusInfo: function() {
      var _authobject = this.applicationController.getAuthObj();
      // Retrieve all the status values in a boolean array  
	  //@TODO: CR: Add below code to try-catch block for error handling
      var info = _authobject.termsAcceptance();
      return info;
  },
  
  /**	 
   * This functions returns the array of boolen values of the terms to be accepted by parent
   * @function getParentTOSStatusInfo
   */
   getParentTOSStatusInfo: function() {
       var _regobject = this.applicationController.getRegObj();
       // Retrieve all the status values in a boolean array  
      //@TODO: CR: CRITICAL Add below code to try-catch block for error handling
       var info = _regobject.termsAcceptance();
       return info;
   },

  /**	 
  * This function updates the Terms of services values
  * @function updateTermsOfService
  */     
  updateTermsOfService: function(aCallback,aContext) {
    ovi.debug("SSOTOSModel:updateTermsOfService : Entry");
     //Store the callback and the context here.
     //When the request is completed
     this._callback = aCallback;
     this._context = aContext;
  
    var tos =  new TermsAcceptanceData();
    
    // Fill up the tos strucure with these values
    // the three values correspond to the three 
    // hyper links in TOS screen
    tos.HasAcceptedTos                =  true;
    tos.HasAcceptedServiceSpecificTos =  true;
    tos.HasAcceptedPrivacyPolicy      = true;
                
    try{
        var _profilemanagerobject = this.applicationController.getProfObj();
        // Calling enabler API for updating TOS
        requestId = _profilemanagerobject.updateTermsAcceptance(this._updateTermsCallBack, tos, this);
    } 
    catch(ex){
        ovi.debug("Exception in  SSOTOSModel.js " +  ex + "  -  " + ex.message);
        aCallback(SSOConstant.Failure,ErrorCode.errorOperationFailed,aContext);    
    }
  },
  
  /**	 
  * Callback that will be fired by the enabler on completion of the
  * updation of TOS values  
  * @function _updateTermsCallBack
  */      
  _updateTermsCallBack: function (aError, aType, aRequestId, aContext) {
     //Check if the update request is succesfull.
    if(aType == RequestType.requestUpdateTermsAcceptance && aError == ErrorCode.errorNone) {
        //Provide the callback to the controller as the controller
        //will close the widget 
        aContext._callback(SSOConstant.Success,aError,aContext._context);        
    }
    else{
        aContext._callback(SSOConstant.Failure,aError,aContext._context);       
    }
  },
  
  /**
   * Gets the country and the language and then initiates the retrieveTOS API
   * @ function retrieveTermsOfService
   * @param {object} aCallback callback to fired upon completion
   * @param {object} aContext context of the calling instance     
   */  
  retrieveTermsOfService: function(aCallback, aContext) {
	ovi.debug("SSOTOSModel::retrieveTermsOfService - Entry");
    try {	        
		this._tosCallback = aCallback;
	    this._aContext = aContext;
		this._getCountryLangDetails();       
    }  catch(ex) {
        ovi.debug("Exception in  retrieveTermsOfService " +  ex + "  -  " + ex.message);
        aCallback(ErrorCode.errorOperationFailed, RequestType.requestRetrieveTermsOfService, 0, aContext);
    }
	ovi.debug("SSOTOSModel::retrieveTermsOfService - Exit");	
  },
  
  /**
   * Initiate the retrieval of terms of service
   * @ function retrieveTOS
   * @param {object} aCallback callback to fired upon completion
   * @param {object} aContext context of the calling instance     
   */ 
  retrieveTOS: function(aCallback, aContext) {
	ovi.debug("SSOTOSModel::retrieveTOS - Entry");
    try {	    
        var serviceSpecificUrl  =  aContext.applicationController.settings.get('ssoServiceId');
        var _registrationobject = aContext.applicationController.getRegObj();	
        _registrationobject.retrieveTermsOfService(aCallback, serviceSpecificUrl,aContext._lang,aContext._countrycode,2, aContext);                
    }
    catch(ex) {
        ovi.debug("Exception in  retrieveTermsOfService " +  ex + "  -  " + ex.message);
        aCallback(ErrorCode.errorOperationFailed, RequestType.requestRetrieveTermsOfService, 0, aContext);
    }
	ovi.debug("SSOTOSModel::retrieveTOS - Exit");		  
  },
  
  /**
   * Get the country and the lang details
   * from the signup model if the usecase is signup and then from the profilemanager if the use case
   * is signin
   * @ function _getCountryLangDetails   
   */
  _getCountryLangDetails: function() {
	ovi.debug("_getCountryLangDetails - Entry");
	try {
		//Get the country and the lang from the signup mode.
		//The value shall be available if the use case is signup
		var model = this.getModel("SSOSignUp");	
		//The use case is signup
		if( model == null || model == "null") {
			ovi.debug("The usecase is signin. Get the country and the lang from the profile manager")	
		   this._profilemanagerobject = this.applicationController.getProfObj();
		   this._profilemanagerobject.downloadProfile(this._downloadProfileComplete,this)
		} else {		
		    ovi.debug("Use case is unknown");
			if( model.getCountry() != null ) {
				ovi.debug("The usecase is signup.country data is available")	
				var countryName = model.getCountry();
		        this._countrycode = SSOCountryName.getCountryCodeFromName(countryName);
				this._lang = this.applicationController.getPhoneLang();		  
				this.retrieveTOS(this._tosCallback,this._aContext);	
			} else {
				ovi.debug("The usecase is signin. The model is available but the country data is not available")	
				this._profilemanagerobject = this.applicationController.getProfObj();
				this._profilemanagerobject.downloadProfile(this._downloadProfileComplete,this)
			}
		 
		} 
	} catch(ex) {
		ovi.debug("Exception in  _getCountryLangDetails " +  ex + "  -  " + ex.message);
        this._tosCallback(ErrorCode.errorOperationFailed, RequestType.requestRetrieveTermsOfService, 0, this._aContext);
	}
    ovi.debug("_getCountryLangDetails - Exit");
  },
  
  /**
   * Downloaded the profile API callback   
   * @ function _downloadProfileComplete  
   * @param {int} aError - error code retruned from the enabler
   * @param {int} aRequestId - request type
   * @param {int} aContext - this object
   */
  _downloadProfileComplete: function(aError, aType, aRequestId, aContext) {
	ovi.debug("_downloadProfileComplete - Entry");
	if( aType == RequestType.requestDownload &&  aError == ErrorCode.errorNone  ) {		
		var info = aContext._profilemanagerobject.profile();
		aContext._countrycode = info["countrystring"];		
		aContext._lang = info["languagestring"];			
		aContext.retrieveTOS(aContext._tosCallback,aContext._aContext);		
	} else {
		ovi.debug("Exception in  _downloadProfileComplete " +  ex + "  -  " + ex.message);
        aContext._tosCallback(ErrorCode.errorOperationFailed, RequestType.requestRetrieveTermsOfService, 0, aContext._aContext);
	}	
  },
  
  
  /**
   * Fetch the 3 TOS links from registration object
   * @ function getTOSLinks
   * @param {object} aError Structure that contains error information
   * @param {object} aType Request type  	 
   * @param {object} aRequestId Request Id
   * @param {object} aContext context from which original API was called 
  */           
  getTOSLinks: function(aError, aType, aRequestId, aContext) {
    
    var tosurls = new Object();
    
    if(aType == RequestType.requestRetrieveTOS && (aError == ErrorCode.errorNone || aError == 12 )) {
        var _registrationobject = this.applicationController.getRegObj();
        tosurls.tosgeneralurl   = _registrationobject.termsOfService(0);
        tosurls.servicespecificurl = _registrationobject.termsOfService(1); 
        tosurls.privacypoilicyurl  = _registrationobject.termsOfService(2);
      
        return tosurls;
    }
    else {      
      return null;
    }
  }     
});

