/**
 *
 * Description : A static class (Javascript object) that maintains 
 *               the list of country name and the code and returns 
 *               the countryname for the given code
 * <p>
 * Filename    : SSOCountryName.js
 * <p>
 * Part of     : 
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:  6 %
 *
 */

/**
 *  @class SSOCountryName
 *  @name  SSOCountryName
 */  

//@TODO: CR: CRITICAL: Please verify 
//  (1) All codes are in sync 
//  (2) All 2 digit codes are used 
//  (3) All country names are read correct English
//  (4) Generic: Feature like this should be available via CP. 
//          Move it to backlog item for CP

//  (5) Below way of 3 isolated arrays are risky. Find a way 
//          to integrate into an array of objects having 3 properties & 
//          alowing search on either of them
//  REF URL:
//        http://en.wikipedia.org/wiki/ISO_3166-1_alpha-2 [2 digit country code]
//        http://en.wikipedia.org/wiki/List_of_mobile_country_codes [mcc-country]
		
var SSOCountryName = /**
 * This is an API that can be mixed into other objects
 * @lends SSOCountryName#
 */{

        //@TODO: CR: MEDIUM: Below method should be made private & 
		//    be called internally from getCntryCodeFrmMobileCountryCode

		prepareCountryNameList: function() {
       
			this._mobilecountrycode = [];					
			this._mobilecountrycode["+93"] = "AF";
			this._mobilecountrycode["+355"] = "AL";
			this._mobilecountrycode["+213"] = "DZ";
			this._mobilecountrycode["+1684"] = "AS";
			this._mobilecountrycode["+376"] = "AD";
			this._mobilecountrycode["+244"] = "AO";
			this._mobilecountrycode["+1264"] = "AI";
			this._mobilecountrycode["+1268"] = "AG";
			this._mobilecountrycode["+54"] = "AR";
			this._mobilecountrycode["+374"] = "AM";
			this._mobilecountrycode["+297"] = "AW";
			this._mobilecountrycode["+61"] = "AU";
			this._mobilecountrycode["+43"] = "AT";
			this._mobilecountrycode["+994"] = "AZ";
			this._mobilecountrycode["+1242"] = "BS";
			this._mobilecountrycode["+973"] = "BH";
			this._mobilecountrycode["+880"] = "BD";
			this._mobilecountrycode["+1246"] = "BB";
			this._mobilecountrycode["+375"] = "BY";
			this._mobilecountrycode["+32"] = "BE";
			this._mobilecountrycode["+501"] = "BZ";
			this._mobilecountrycode["+229"] = "BJ";
			this._mobilecountrycode["+1441"] = "BM";
			this._mobilecountrycode["+975"] = "BT";
			this._mobilecountrycode["+591"] = "BO";
			this._mobilecountrycode["+387"] = "BA";
			this._mobilecountrycode["+267"] = "BW";
			this._mobilecountrycode["+55"] = "BR";
			this._mobilecountrycode["+1284"] = "British Virgin Islands (UK)";
			this._mobilecountrycode["+673"] = "BN";
			this._mobilecountrycode["+359"] = "BG";
			this._mobilecountrycode["+226"] = "BF";
			this._mobilecountrycode["+257"] = "BI";
			this._mobilecountrycode["+855"] = "KH";
			this._mobilecountrycode["+237"] = "CM";
			this._mobilecountrycode["+1"] = "CA";
			this._mobilecountrycode["+238"] = "CV";
			this._mobilecountrycode["+1345"] = "KY";
			this._mobilecountrycode["+236"] = "CF";
			this._mobilecountrycode["+235"] = "TD";
			this._mobilecountrycode["+56"] = "CL";		
			this._mobilecountrycode["+86"] = "CN";
			this._mobilecountrycode["+57"] = "CO";
			this._mobilecountrycode["+269"] = "KM";
			this._mobilecountrycode["+629"] = "CG";
			this._mobilecountrycode["+682"] = "CK";
			this._mobilecountrycode["+506"] = "CR"; 
			this._mobilecountrycode["+612"] = "CI ";
			this._mobilecountrycode["+219"] = "HR";
			this._mobilecountrycode["+53"] = "CU";
			this._mobilecountrycode["+357"] = "CY";
			this._mobilecountrycode["+420"] = "CZ";
			this._mobilecountrycode["+243"] = "Democratic Republic of the Congo";
			this._mobilecountrycode["+45"] = "DK";
			this._mobilecountrycode["+253"] = "DJ";
			this._mobilecountrycode["+1767"] = "DM";
			this._mobilecountrycode["+1809"] = "DO";
			this._mobilecountrycode["+514"] = "East Timor";
			this._mobilecountrycode["+593"] = "EC";
			this._mobilecountrycode["+20"] = "EG"; 
			this._mobilecountrycode["+503"] = "SV"; 
			this._mobilecountrycode["+240"] = "GQ"; 
			this._mobilecountrycode["+291"] = "ER"; 
			this._mobilecountrycode["+372"] = "EE"; 
			this._mobilecountrycode["+251"] = "ET"; 
			this._mobilecountrycode["+500"] = "FK"; 
			this._mobilecountrycode["+298"] = "FO"; 
			this._mobilecountrycode["+679"] = "FJ"; 
			this._mobilecountrycode["+358"] = "FI"; 
			this._mobilecountrycode["+33"] = "FR"; 
			this._mobilecountrycode["+742"] = "GF"; 
			this._mobilecountrycode["+689"] = "PF"; 
			this._mobilecountrycode["+241"] = "GA"; 
			this._mobilecountrycode["+220"] = "GM"; 
			this._mobilecountrycode["+995"] = "GE"; 
			this._mobilecountrycode["+49"] = "DE"; 
			this._mobilecountrycode["+233"] = "GH"; 
			this._mobilecountrycode["+350"] = "GI"; 
			this._mobilecountrycode["+30"] = "GR"; 
			this._mobilecountrycode["+299"] = "GL"; 
			this._mobilecountrycode["+1473"] = "GD"; 
			this._mobilecountrycode["+340"] = "GP"; 
			this._mobilecountrycode["+1671"] = "GU"; 
			this._mobilecountrycode["+502"] = "GT"; 
			this._mobilecountrycode["+224"] = "GN"; 
			this._mobilecountrycode["+245"] = "GW"; 
			this._mobilecountrycode["+592"] = "GY"; 
			this._mobilecountrycode["+509"] = "HT"; 
			this._mobilecountrycode["+504"] = "HN"; 
			this._mobilecountrycode["+852"] = "HK"; 
			this._mobilecountrycode["+36"] = "HU"; 
			this._mobilecountrycode["+354"] = "IS"; 
			this._mobilecountrycode["+91"] = "IN";
			this._mobilecountrycode["+62"] = "ID"; 
			this._mobilecountrycode["+98"] = "IR"; 
			this._mobilecountrycode["+98"] = "IQ"; 
			this._mobilecountrycode["+353"] = "IE"; 
			this._mobilecountrycode["+972"] = "IL"; 
			this._mobilecountrycode["+39"] = "IT"; 
			this._mobilecountrycode["+1876"] = "JM"; 
			this._mobilecountrycode["+81"] = "JP";
			this._mobilecountrycode["+962"] = "JO"; 
			this._mobilecountrycode["+7"] = "KZ"; 
			this._mobilecountrycode["+254"] = "KE"; 
			this._mobilecountrycode["+686"] = "KI"; 
			this._mobilecountrycode["+467"] = "Korea, North"; 
			this._mobilecountrycode["+450"] = "Korea, South"; 
			this._mobilecountrycode["+965"] = "KW"; 
			this._mobilecountrycode["+996"] = "KG"; 
			this._mobilecountrycode["+856"] = "LA"; 
			this._mobilecountrycode["+371"] = "LV"; 
			this._mobilecountrycode["+961"] = "LB"; 
			this._mobilecountrycode["+266"] = "LS"; 
			this._mobilecountrycode["+231"] = "LR"; 
			this._mobilecountrycode["+218"] = "LY"; 
			this._mobilecountrycode["+423"] = "LI"; 
			this._mobilecountrycode["+370"] = "LT"; 
			this._mobilecountrycode["+352"] = "LU"; 
			this._mobilecountrycode["+853"] = "MO"; 
			this._mobilecountrycode["+389"] = "MK"; 
			this._mobilecountrycode["+261"] = "MG"; 
			this._mobilecountrycode["+265"] = "MW"; 
			this._mobilecountrycode["+60"] = "MY"; 
			this._mobilecountrycode["+960"] = "MV"; 
			this._mobilecountrycode["+223"] = "ML"; 
			this._mobilecountrycode["+356"] = "MT"; 
			this._mobilecountrycode["+692"] = "MH"; 
			this._mobilecountrycode["+340"] = "MQ"; 
			this._mobilecountrycode["+222"] = "MR"; 
			this._mobilecountrycode["+230"] = "MU"; 
			this._mobilecountrycode["+52"] = "MX"; 
			this._mobilecountrycode["+691"] = "FM"; 
			this._mobilecountrycode["+373"] = "MD"; 
			this._mobilecountrycode["+377"] = "MC"; 
			this._mobilecountrycode["+976"] = "MN"; 
			this._mobilecountrycode["+382"] = "ME"; 
			this._mobilecountrycode["+1664"] = "MS"; 
			this._mobilecountrycode["+212"] = "MA"; 
			this._mobilecountrycode["+258"] = "MZ"; 
			this._mobilecountrycode["+414"] = "MM"; 
			this._mobilecountrycode["+264"] = "NA"; 
			this._mobilecountrycode["+674"] = "NR";
			this._mobilecountrycode["+977"] = "NP"; 
			this._mobilecountrycode["+31"] = "NL"; 
			this._mobilecountrycode["+599"] = "AN"; 
			this._mobilecountrycode["+687"] = "NC"; 
			this._mobilecountrycode["+64"] = "NZ"; 
			this._mobilecountrycode["+505"] = "NI"; 
			this._mobilecountrycode["+227"] = "NE"; 
			this._mobilecountrycode["+234"] = "NG"; 
			this._mobilecountrycode["+1670"] = "MP"; 
			this._mobilecountrycode["+47"] = "NO"; 
			this._mobilecountrycode["+968"] = "OM"; 
			this._mobilecountrycode["+92"] = "PK"; 
			this._mobilecountrycode["+680"] = "PW"; 
			this._mobilecountrycode["+423"] = "PS"; 
			this._mobilecountrycode["+507"] = "PA"; 
			this._mobilecountrycode["+675"] = "PG"; 
			this._mobilecountrycode["+595"] = "PY"; 
			this._mobilecountrycode["+51"] = "PE";
			this._mobilecountrycode["+63"] = "PH"; 
			this._mobilecountrycode["+48"] = "PL"; 
			this._mobilecountrycode["+351"] = "PT"; 
			this._mobilecountrycode["+1"] = "PR"; 
			this._mobilecountrycode["+974"] = "QA"; 
			this._mobilecountrycode["+627"] = "RE";
			this._mobilecountrycode["+40"] = "RO"; 
			this._mobilecountrycode["+7"] = "RU"; 
			this._mobilecountrycode["+250"] = "RW"; 
			this._mobilecountrycode["+1869"] = "KN"; 
			this._mobilecountrycode["+1758"] = "LC"; 
			this._mobilecountrycode["+508"] = "PM";
			this._mobilecountrycode["+44"] = "GB"; 
			this._mobilecountrycode["+1"] = "US";
			this._mobilecountrycode["+748"] = "UY"; 
			this._mobilecountrycode["+434"] = "UZ";
			this._mobilecountrycode["+541"] = "VU"; 
			this._mobilecountrycode["+225"] = "Vatican City State"; 
			this._mobilecountrycode["+734"] = "VE"; 
			this._mobilecountrycode["+452"] = "VN"; 
			this._mobilecountrycode["+543"] = "WF"; 
			this._mobilecountrycode["+421"] = "YE"; 
			this._mobilecountrycode["+645"] = "ZM"; 
			this._mobilecountrycode["+648"] = "ZW"; 			
		},
		
		//@TODO: CR: UPdate method to state, return "undefined" if no match found
		/**
		 * get the country name by passing country code as parameter.
		 * @function getCountryCode
		 * @param {String} country code
		 * @return {String} country name
		 */
		getCntryCodeFrmMobileCountryCode: function(aCountrycode) {
			this.prepareCountryNameList();
		      //@TODO: CR: CRITICAL. If below country code finds corresponding
			  // mobileCountryCode, return it, else return undefined.		
			return this._mobilecountrycode[aCountrycode];	            
		},
              
	   //@TODO: CR: MEDIUM: Make below method private
        /**
		 * Array of the Country Name
		 * @function prepareCountryNameArray		
		 */		
		prepareCountryNameArray: function() {           
			this._countryNameList = new Array("Afghanistan","Albania","Algeria","Andorra","Angola","Antigua And Barbuda",
				"Argentina","Armenia","Aruba","Australia","Austria","Azerbaijan",

				"Bahamas","Bahrain","Bangladesh","Barbados","Belarus","Belgium","Belize","Benin",
				"Bermuda","Bolivia","Bosnia And Herzegovina","Botswana",
				"Brazil","Bulgaria","Burkina Faso","Burundi",

				"Cambodia","Cameroon","Canada","Cape Verde","Cayman Islands","Central African Republic",
				"Chad","Chile","China","Colombia","Comoros","Congo","Congo, The Democratic Republic Of The","Costa Rica",
				"Croatia","Cyprus","Czech Republic","Cote D'lvoire",

				"Denmark","Djibouti","Dominican Republic",

				"Ecuador","Egypt","El Salvador","Equatorial Guinea","Eritrea","Estonia","Ethiopia",

				"Finland","France","French Polynesia",

				"Gabon","Gambia","Georgia","Germany","Ghana","Greece","Grenada","Guadeloupe","Guam",
				"Guatemala","Guinea","Guinea-Bissau","Guyana",

				"Haiti","Honduras","Hong Kong","Hungary",

				"Iceland","India","Indonesia","Iraq","Ireland","Israel","Italy",

				"Jamaica","Japan","Jordan",

				"Kazakhstan","Kenya", "Korea, Republic Of","Kuwait","Kyrgyzstan",

				"Lao People'S Democratic Republic","Latvia","Lebanon","Lesotho","Liberia","Libyan Arab Jamahiriya",
				"Liechtenstein","Lithuania","Luxembourg",

				"Macedonia, the former Yugoslav Republic Of","Madagascar","Malawi","Malaysia","Maldives","Mali",
				"Malta","Mauritania","Mauritius","Mayotte","Mexico","Moldova, Republic Of","Monaco","Mongolia",
				"Montenegro","Morocco","Mozambique","Myanmar",

				"Namibia","Nepal","Netherlands","Netherlands Antilles","New Zealand","Nicaragua","Niger","Nigeria",
				"Norway",
				"Oman",									   
				"Pakistan","Palestinian Territories","Panama","Papua New Guinea",
				"Paraguay","Peru","Philippines","Poland","Portugal","Puerto Rico",
				"Qatar",
				"Reunion","Romania","Russian Federation","Rwanda",
				"Saint Kitts And Nevis","Saint Lucia","Saint Vincent And The Grenadines","Sao Tome And Principe",
				"Saudi Arabia","Senegal","Serbia","Seychelles","Sierra Leone","Singapore","Slovakia",
				"Slovenia","Somalia","South Africa","Spain","Sri Lanka","Suriname","Swaziland","Sweden","Switzerland",

				"Taiwan","Tajikistan","Tanzania, United Republic Of","Thailand","Togo","Trinidad And Tobago","Tunisia","Turkey","Turkmenistan","Turks And Caicos Islands",
				"Uganda","Ukraine","United Arab Emirates","United Kingdom","United States","Uruguay","Uzbekistan",
				"Venezuela","Viet Nam","Virgin Islands, British","Yemen","Zambia","Zimbabwe");                                               
			
            //@TODO: CR: MEDIUM: Return is not being used. Ignore return         
			return this._countryNameList;                             
		},
	
       //@TODO: CR: MEDIUM: Make below method private
		/**
		 * Array of the Country Code
		 * @function prepareCountryCodeArray		
		 */	
		prepareCountryCodeArray: function() {
			//@TODO: CR: MEDIUM: Optimize. If this_countryCodeList is undefined then only 
			//       create an array. 
		    this._countryCodeList = new Array("AF","AL", "DZ","AD","AO","AG",
				"AR","AM","AW","AU","AT","AZ",

				"BS","BH","BD","BB","BY","BE","BZ","BJ",
				"BM","BO","BA","BW",
				"BR","BG","BF","BI",


				"KH","CM","CA","CV","KY","CF","TD","CL","CN","CO","KM","CG","CD","CR","HR","CY","CZ","CI",
				"DK","DJ","DO",
				"EC","EG","SV","GQ","ER","EE","ET",			
				"FI","FR","PF",
				"GA","GM","GE","DE","GH","GR","GD","GP","GU","GT","GN","GW","GY",	
				"HT","HN","HK","HU",
				"IS","IN","ID","IQ","IE","IL","IT",			
				"JM","JP","JO",
				"KZ","KE","KR","KW","KG",
				"LA","LV","LB","LS","LR","LY","LI","LT","LU",
				"MK","MG","MW","MY","MV","ML","MT","MR","MU","YT","MX","MD","MC","MN","ME","MA","MZ","MM",			
				"NA", "NP","NL","AN","NZ","NI", "NE","NG","NO",
				"OM","PK","PS","PA", "PG",  "PY",  "PE", "PH",  "PL", "PT", "PR", "QA",
				"RE","RO","RU", "RW", 
				"KN","LC","VC", "ST", "SA","SN","CS","SC", "SL","SG","SK","SI", "SO","ZA", "ES", "LK",            
				"SR", "SZ", "SE",  "CH", "TW", "TJ", "TZ",  "TH",  "TG", "TT", "TN", "TR","TM", "TC", 
				"UG", "UA",  "AE",   "GB",  "US",   "UY", "UZ", "VE", "VN","VG","YE", "ZM", "ZW");   
			//@TODO: CR: MEDIUM: Return is not being used. Ignore return         
			return this._countryCodeList;
		},
	
        //@TODO: CR: UPdate method to state, return "undefined" if no match found
		/**
		 * Gets the index of the given country name from the array
		 * and provides the countryname with the same index
		 * @function getCountryCodeFromName
		 * @param{var} aCountryName - name of the country
		 * @param{var} country code
		 */	
		getCountryCodeFromName : function(aCountryName) {
			this.prepareCountryCodeArray();
			this.prepareCountryNameArray();
			//Get the index of the country code
			var index = this._countryNameList.indexOf(aCountryName);		
              //@TODO: CR: CRITICAL. If index is (-1)ie. not found
			  //     return undefined
			return this._countryCodeList[index];		       
		},
	
        //@TODO: CR: UPdate method to state, return "undefined" if no match found
		/**
		 * Gets the index of the given country code from the array
		 * and provides the countryname with the same index
		 * @function getCountryCodeFromName
		 * @param{var} aCountryCode - coutrycode
		 * @param{var} country name
		 */	
		getCountryNameFromCode: function(aCountryCode) {
			this.prepareCountryCodeArray();
			this.prepareCountryNameArray();
			//Get the index of the country code
			var index = this._countryCodeList.indexOf(aCountryCode);		
              //@TODO: CR: CRITICAL. If index is (-1)ie. not found
              //     return undefined
            return this._countryNameList[index];
		}
	}

