/**
 *
 * Description : A class that will post the events using CP Event & Message Service provider. 
 * <p>
 * Filename    : SSOEventManager.js
 * <p>
 * Part of     : services 
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOEventManager
 * @name SSOEventManager 
 */

ovi.provide( 'ssoui.services.SSOEventManager' );
ovi.require( 'ovi.service.EventMessage', false );
ovi.declare( 'ssoui.services.SSOEventManager',{
    
	/**
	 * Creates the objects needed for this controller
	 * Calls the base class init function which initiliazes E & M service provider
	 * @function initialize
	 */
    initialize: function() {
        this._isInitialised=false;
        //Load the Event & message Service provider.
        try{
            // asynchronous initialization
            this.eventMessageObj = new ovi.service.Event(this, this.initSerivceCallback);
		    
    	} catch(ex) {
    	}
    },
    
    /** 
     * Callback function when loading of E & M service provider is completed
     * @function initSerivceCallback
     * @param {object} statusCode - return code from service provider.
     */   
    initSerivceCallback: function (statusCode) {
        // if status code is not zero( there is some error while loading )
        if (statusCode.code!=0) {
        
            this._isInitialised=false;           
        }
        else {
        
            this._isInitialised=true;
        }
    },
    
    /**     
     * function to post the event with value
     * @function post
     * @param {string } aEventType - Event type to be posted to.
     * @param { JSON string } aEventValue - value to be posted to the.
     */   
    post: function ( aEventType, aEventValue) {    
        try {
            // post the event  to service provider 
            // while posting the data to window.post, we had the limitation to send only one parameter, so here we are combining 
            // eventtype and eventvalue in one single JSON string later in ssoui.js file we will again devide it in two parts
            // so that clients ( whether iframe or Qt both receive the parameter in form of ( EventType / Event value ) .
            // which is standard way of posting message in CP framework.
            var eventValues= new Array(2);
            eventValues[0]= aEventType;
            eventValues[1]= aEventValue;
            //var statusMessage = "eventType:" + aEventType + aEventValue;            
            // post the message using ifram's window.postmessage api 
            window.parent.postMessage(eventValues, "*");
            // post the message using E&M service provider 
            if(this._isInitialised==true) {
            this.eventMessageObj.post(aEventType, aEventValue);
            }
    	}catch(ex) {            
    	}
    } 
   
});