/**
 *
 * Description : A static class (Javascript object) that maintains 
 *               the list of langauages supported from the backend and returns 
 *               the lang code suported by the backend for the given lang code
 * <p>
 * Filename    : SSOLanguageCode.js
 * <p>
 * Part of     : 
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:  1 %
 *
 */
 
 /**
 *  @class SSOLanguageCode
 *  @name  SSOLanguageCode
 */  
ovi.require('ovi.ConsoleLogger')
 
var SSOLanguageCode = /**
 * This is an API that can be mixed into other objects
 * @lends SSOLanguageCode#
 */{
	//This is the array which maps the 4 char phone lang to the lang code in the backend
	/**
	 * Array of the phone langauage code which has 4 chars
	 * @function prepareLangCodeList
	 */	
	prepareLangCodeList: function() {
		ovi.debug('prepareLangCodeList - Entry');
		this._langCode = [];
		this._langCode["en-GB"] = "en";
		this._langCode["en-UK"] = "en";
		this._langCode["en-US"] = "en-US";
		
		this._langCode["es-LA"] = "es-419";
		this._langCode["es-LAM"] = "es-419";
		this._langCode["es-AG"] = "es-419";
		this._langCode["es-AI"] = "es-419";
		this._langCode["es-AN"] = "es-419";
		this._langCode["es-AR"] = "es-419";
		this._langCode["es-AW"] = "es-419";
		this._langCode["es-BBes-BL"] = "es-419";
		this._langCode["es-BM"] = "es-419";
		this._langCode["es-BO"] = "es-419";
		this._langCode["es-BR"] = "es-419";
		this._langCode["es-BS"] = "es-419";
		this._langCode["es-BZ"] = "es-419";
		this._langCode["es-CA"] = "es-419";
		this._langCode["es-CLes-CO"] = "es-419";
		this._langCode["es-CR"] = "es-419";
		this._langCode["es-CU"] = "es-419";
		this._langCode["es-DM"] = "es-419";
		this._langCode["es-DO"] = "es-419";
		this._langCode["es-EC"] = "es-419";
		this._langCode["es-FK"] = "es-419";
		this._langCode["es-GDes-GF"] = "es-419";
		this._langCode["es-GL"] = "es-419";
		this._langCode["es-GP"] = "es-419";
		this._langCode["es-GT"] = "es-419";
		this._langCode["es-GY"] = "es-419";
		this._langCode["es-HN"] = "es-419";
		this._langCode["es-HT"] = "es-419";		
		this._langCode["es-JM"] = "es-419";
		this._langCode["es-KN"] = "es-419";
		this._langCode["es-KY"] = "es-419";
		this._langCode["es-LC"] = "es-419";
		this._langCode["es-MF"] = "es-419";
		this._langCode["es-MQ"] = "es-419";
		this._langCode["es-MS"] = "es-419";
		this._langCode["es-MX"] = "es-419";
		this._langCode["es-NI"] = "es-419";
		this._langCode["es-PA"] = "es-419";
		this._langCode["es-PE"] = "es-419";
		this._langCode["es-PM"] = "es-419";
		this._langCode["es-PR"] = "es-419";
		this._langCode["es-PY"] = "es-419";
		this._langCode["es-SR"] = "es-419";
		this._langCode["es-SV"] = "es-419";
		this._langCode["es-TC"] = "es-419";
		this._langCode["es-TT"] = "es-419";
		this._langCode["es-US"] = "es-419";
		this._langCode["es-UY"] = "es-419";
		this._langCode["es-VC"] = "es-419";
		this._langCode["es-VE"] = "es-419";
		this._langCode["es-VG"] = "es-419";
		this._langCode["es-VI"] = "es-419";
		
		this._langCode["fr-CA"] = "fr-CA";
		
		this._langCode["pt-BR"] = "pt-BR";
		
		this._langCode["zh-HK"] = "zh-HK";
		
		this._langCode["zh-TW"] = "zh-TW";
		ovi.debug('prepareLangCodeList - Exit');
		},
	
	/**
	 * Array of the phone langauage code which has 2 chars
	 * @function prepare2charLangCodeList
	 */				
	prepare2charLangCodeList: function() {
		this._2LangCode = [];
		this._2LangCode["af"] = "af";
		this._2LangCode["am"] = "am";
		this._2LangCode["ar"] = "ar";
		this._2LangCode["as"] = "as";
		this._2LangCode["az"] = "az";
		
		this._2LangCode["be"] = "be";
		this._2LangCode["bg"] = "bg";
		this._2LangCode["bn"] = "bn";			
		this._2LangCode["bs"] = "bs";
		
		this._2LangCode["ca"] = "ca";
		this._2LangCode["cs"] = "cs";
		
		this._2LangCode["da"] = "da";
		this._2LangCode["de"] = "de";
		
		this._2LangCode["el"] = "el";
		this._2LangCode["es"] = "es";			
		this._2LangCode["et"] = "et";			
		this._2LangCode["eu"] = "eu";
		
		this._2LangCode["fi"] = "fi";
		this._2LangCode["fr"] = "fr";
		
		this._2LangCode["gl"] = "gl";
		this._2LangCode["gu"] = "gu";
		
		this._2LangCode["ha"] = "ha";
		this._2LangCode["he"] = "he";
		this._2LangCode["iw"] = "he";
		this._2LangCode["hi"] = "hi";
		this._2LangCode["hr"] = "hr";
		this._2LangCode["hu"] = "hu";
		this._2LangCode["hy"] = "hy";
		
		this._2LangCode["ig"] = "ig";
		this._2LangCode["id"] = "id";
		this._2LangCode["is"] = "is";
		this._2LangCode["it"] = "it";
		
		this._2LangCode["ja"] = "ja";
		
		this._2LangCode["ka"] = "ka";
		
		this._2LangCode["ka"] = "ka";
		this._2LangCode["kk"] = "kk";
		this._2LangCode["km"] = "km";
		this._2LangCode["kn"] = "kn";
		this._2LangCode["ko"] = "ko";
		this._2LangCode["ks"] = "ks";
		this._2LangCode["ky"] = "ky";
		
		this._2LangCode["ln"] = "ln";
		this._2LangCode["lt"] = "lt";
		this._2LangCode["lv"] = "lv";
		
		this._2LangCode["mk"] = "mk";
		this._2LangCode["ml"] = "ml";
		this._2LangCode["mn"] = "mn";
		this._2LangCode["mr"] = "mr";
		this._2LangCode["ms"] = "ms";
		
		this._2LangCode["nl"] = "nl";
		this._2LangCode["no"] = "no";
		
		this._2LangCode["or"] = "or";
		
		this._2LangCode["pa"] = "pa";			
		this._2LangCode["pl"] = "pl";
		this._2LangCode["ps"] = "ps";
		
		this._2LangCode["ro"] = "ro";
		this._2LangCode["ru"] = "ru";
		
		this._2LangCode["si"] = "si";			
		this._2LangCode["sk"] = "sk";
		this._2LangCode["sl"] = "sl";
		this._2LangCode["sq"] = "sq";
		this._2LangCode["sr"] = "sr";
		this._2LangCode["st"] = "st";
		this._2LangCode["sv"] = "sv";
		this._2LangCode["sw"] = "sw";
		
		this._2LangCode["ta"] = "ta";
		this._2LangCode["te"] = "te";
		this._2LangCode["tg"] = "tg";
		this._2LangCode["th"] = "th";
		this._2LangCode["tk"] = "tk";
		this._2LangCode["tl"] = "tl";
		this._2LangCode["tr"] = "tr";
		
		this._2LangCode["uk"] = "uk";
		this._2LangCode["ur"] = "ur";
		this._2LangCode["uz"] = "uz";
		
		this._2LangCode["vi"] = "vi";
		this._2LangCode["xh"] = "xh";
		this._2LangCode["yo"] = "yo";
		this._2LangCode["zh"] = "zh";
		this._2LangCode["zu"] = "zu";		
			
	},	
	
	/**
	 * Gets the 4 char lang code for the given phone langauge
	 * @function _get4CharLangCode
	 */		
	 _get4CharLangCode: function(aPhoneLang) {
		ovi.debug("_get4CharLangCode - Entry" + aPhoneLang);
		this.prepareLangCodeList();
		return 	this._langCode[aPhoneLang];			
	},
		
	/**
	 * Gets the 2 char lang code for the given phone langauge
	 * @function _get2CharLangCode
	 */		
	_get2CharLangCode: function(aPhoneLang) {	
		ovi.debug("_get2CharLangCode - Entry" + aPhoneLang);		
		this.prepare2charLangCodeList();
		return this._2LangCode[aPhoneLang];
	},
	
	/**
	 * Gets the lang code for the given phone langauge
	 * @function getLangCode
	 */	
	getLangCode: function(aPhoneLang) {	
		ovi.debug('getLangCode - Entry' + aPhoneLang);
		console.log("Lan is" + aPhoneLang);
		//Check if the 4char lang code is available for the given phone lang
		var langcode = this._get4CharLangCode(aPhoneLang);		
		ovi.debug("4 char lang code is" + langcode);		
		//If there is no maping for the lang code in that array check the second array
		//As the backend takes 2 char as the phone lang for few of them
		if(!langcode) {				
			ovi.debug("4 char lang code is not present");		
			var lang = aPhoneLang.substring(0,2);			
			langcode = this._get2CharLangCode(lang);
			ovi.debug("2 char lang code is" + langcode);		
			//If there is no lang code default the lang code to english
			if(!langcode) {
				ovi.debug("No supported lang code from backend");
				langcode = "en";				
			}
		}
		ovi.debug("The lang code returned is" + langcode);		
		return langcode;
	}
 
 }