/**
 *
 * Description : A class that will load the sysinfo plugin and gets the phone language
 *               and country code. 
 * <p>
 * Filename    : SSOSysInfo.js
 * <p>
 * Part of     : services 
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOSysInfo
 * @name SSOSysInfo 
 */

ovi.provide( 'ssoui.services.SSOSysInfo' );
 //For sysinfo
ovi.require( 'nokia.device.platformservices', false ); 
 ovi.require( 'ovi.ConsoleLogger');
ovi.require( 'ssoui.services.SSOCountryName', false );
ovi.declare( 'ssoui.services.SSOSysInfo', {
    
    /**
     * Loads the sysinfo plugin     
     * @function initialize
     */
    initialize: function() {        
        //Load the sysinfo Service provider.     
        this.sysInfoObj = nokia.device.load( 'sysinfo' );        
    },

    /**
     * Gets the phone language from the sysinfo     
     * @function getPhoneLang
     * @return {String} phone language
     */
    getPhoneLang: function() {    
        //Get the phone language from the sysinfo 
        var phoneLang = this.sysInfoObj.getChannel("PhoneLanguage");        
        //Return the phone language    
        return phoneLang.phoneLanguage;
     },
       
    /**
     * Gets the network Information from the sysinfo - the info is retrieved from the SIM
     * if the phone is in offline mode reads the data from the phone settings.
     * @function getCountryInfo
     * @param {Object} aCallback function - function to be called when the retrieval is complete
     */ 
     getCountryInfo: function(aCallback,aContext) {
		
		ovi.debug("SSOSysInfo - getCountryInfo - Entry");	
		
        //Store the object to the variable as this.sysInfoObj is not accessible
        // inside the aCallback function.
        var sysInfo = this.sysInfoObj;
        
        //Success and failure aCallback are added her as the this pointer is not accesible inside the
        //aCallback function. And the sysinfo API doesnt return the context with the callbakc function
        
        //Sucess aCallback for the network info        
        function networkInfoObtained( data ) {    
		      //@TODO: CR: MEDIUM. Caputre log as data.mobileCountryCode
			ovi.debug("SSOSysInfo - networkInfoObtained " + data);		
            //Creates an array for the countryname and code
            SSOCountryName.prepareCountryNameList();    
            //Get the country name for the given code
            var countrycode = SSOCountryName.getCntryCodeFrmMobileCountryCode(data.mobileCountryCode);     
			ovi.debug("SSOSysInfo - networkInfoObtained with countrycode" + countrycode);		
            //Provide the callback to the caller with the countrycode obtained
            aCallback(countrycode,aContext);   
        }
            
        //Failure callback   for the network info
        function networkInfoFailed( deviceError ) {
			ovi.debug("SSOSysInfo - networkInfoFailed " + deviceError);		
            //Network Info has failed. So get the country code
            //from the phone settings.
            //Get the country name from the phone settings. Its a sync call
            var countrycode = sysInfo.getChannel("CountryName");
			ovi.debug("SSOSysInfo - networkInfoObtained with countryName" + countrycode);
            //Provide the callback to the caller with the countryname
            aCallback(countrycode.countryName,aContext);   
        }        
        
        //Get the country code, its an async call
        try {   
		 ovi.debug("SSOSysInfo - getChannel Network ");		
         var retval = this.sysInfoObj.getChannel("Network", networkInfoObtained,networkInfoFailed);          
        }
        catch ( ex ){
			//@TODO: CR: MEDIUM: Use ovi.error
			// Trigger networkInfoFailed
			ovi.debug("SSOSysInfo - getChannel Network - Failed ");		           
        }      
			
		ovi.debug("SSOSysInfo - getCountryInfo - Exit");	
		
     }    
	 
	 
   
});