/*
 * Copyright (C) 2009, Nokia gate5 GmbH Berlin
 *
 * These coded instructions, statements, and computer programs contain
 * unpublished proprietary information of Nokia gate5 GmbH, and are
 * copy protected by law. They may not be disclosed to third parties
 * or copied or duplicated in any form, in whole or in part, without
 * the specific, prior written permission of Nokia gate5 GmbH.
 */

ovi.provide('ssoui.ui.SSODateControl');

ovi.require('ovi.dom');
ovi.require('ovi.ui.Control');
ovi.require('ovi.ui.TextInput');

/**
 * CheckButton UI Control. A check button is a clickable entity with a text label. Its width grows with the length of
 * the label. The check button raises an action, if it is clicked. The check button can have 2 states - checked and
 * unchecked.
 *
 * @publish
 * @class
 * @name ssoui.ui.SSODateControl
 * @extends ovi.ui.Control
 *
 * @param {Object} [aProperties={}] The properties object that will be used to configure input component on
 *         initialization. Can contain following fields:
 * @param {string} [aProperties.value=""] The initial value of the component.
 * @param {string} [aProperties.label=undefined] The label displayed next to check box input.
 * @param {string} [aProperties.disabled=false] The property indicating whether control is enabled or not.
 * @param {boolean} [aProperties.checked=false] The initial state of check box input field.
 * @param {Node} [aPlacement] The DOM node element where the component will be placed.
 * @param {string} [aPosition="last"] Relative position to the reference node {@link ovi.ui.Snippet#place}.
 */

/**
 * Fires "selected" event if CheckButton is clicked while not disabled.
 *
 * @event
 * @name ssoui.ui.CheckButton#fireEvent:selected
 * @see ovi.EventSource
 */
ssoui.ui.SSODateControl = new ovi.Class({
	
    Extends: ovi.ui.Control,

    /**
     * Default template for the check button, will be used to create DOM nodes
     */
    template: '<div class="sso_date"></div>',
    
    initialize : function(aProperties, value, maxSize, watermark) {		
		this._super(aProperties, value, maxSize, watermark);
		
        // EYYU-83E5PR Fix: Reformatting the Dob fields to accommodate year placeholder
        // Why link in Aboutyou screen has alredy been moved to next line.
        // <--LeftMargin--> <  mm  > <margin> <  dd  > <margin> < yyyy  > <--RightMargin-->
        // <--   30px  ---> < 65px > < 15px > < 65px > < 15px > < 110px > <--   30px    -->
		this._mm = new ovi.ui.TextInput({},this._root);
		this._mm.setProperty('maxLength',"2");
        //this._mm.setProperty('placeholder',sso_signup_textfield_entermonth);
        this._mm._root.type = "number";
        this._mm._root.style.marginRight = "15px";
        this._mm._root.style.width = "75px";
        this._mm._root.style.textAlign = "center";
        this._mm.addEventHandler("blurred",this.verifyMonthEntry, this);

        
		this._dd = new ovi.ui.TextInput({},this._root);
        this._dd.setProperty('maxLength',"2");
        //this._dd.setProperty('placeholder',sso_signup_textfield_enterday);
        this._dd._root.type = "number";
        this._dd._root.style.marginRight = "15px";
        this._dd._root.style.width = "75px";
        this._dd._root.style.textAlign = "center";
        this._dd.addEventHandler("blurred", this.verifyDayEntry, this);
        
		this._yyyy = new ovi.ui.TextInput({},this._root);
        this._yyyy.setProperty('maxLength',"4");
        //this._yyyy.setProperty('placeholder',sso_signup_textfield_enteryear);
        this._yyyy._root.type = "number";
        this._yyyy._root.style.width = "110px";
        this._yyyy._root.style.textAlign = "center";
        this._yyyy.addEventHandler("blurred", this.verifyYearEntry, this);
	},
	
	getValue : function() {
		return this._mm.getProperty("value")+"-"+this._dd.getProperty("value")+"-"+this._yyyy.getProperty("value")
	},
	
	setValue : function(aValue) {
        if( aValue == null ||  aValue == "" ) {
            // do nothing.. just return
            return;
        }
        var dob = aValue.split('-');
		this._mm.setProperty("value",dob[0]);
        this._dd.setProperty("value",dob[1]);
        this._yyyy.setProperty("value",dob[2]);
	},
    
    getDay: function() {
        return this._dd.getProperty("value");
    },
    
    getMonth : function() {
        return this._mm.getProperty("value");
    },
    
    getYear: function() {
        return this._yyyy.getProperty("value");
    },

    /**
     * Set the day
     * @function setDay
     * @param {string} aValue The Day to be set
     */
    setDay : function(aValue) {		
        this._dd.setProperty("value",aValue);        
    },

    /**
     * Set the month
     * @function setMonth
     * @param {string} aValue The month to be set
     */
    setMonth : function(aValue) {        
		this._mm.setProperty("value",aValue);              
    },

    /**
     * Set the year
     * @function setYear
     * @param {string} aValue The year to be set
     */
    setYear : function(aValue) {        
		this._yyyy.setProperty("value",aValue);              
    },

    /**
     * Checks whether user has entered a valid year
     * @function validYearEntered
     */
    validYearEntered: function() {
        if ( isNaN(parseInt(this.getYear(), 10)) ) {
            return false;
        }
        return true;
    },

    /**
     * Checks whether user has entered a valid month
     * @function validMonthEntered
     */
    validMonthEntered: function() {
        if ( isNaN(parseInt(this.getMonth(), 10)) ) {
            return false;
        }
        return true;
    },

    /**
     * Checks whether user has entered a valid date
     * @function validDateEntered
     */
    validDateEntered: function() {
        if ( isNaN(parseInt(this.getDay(), 10)) ) {
            return false;
        }
        return true;
    },

    /**
     * Validatidate month entry and correct it if error
     * and prefix it with zero if required
     * @function verifyMonthEntry
     */
    verifyMonthEntry : function() {		
        var month = parseInt(this.getMonth(), 10);
        if ( isNaN(month) ) {
            return;
        }
        // month cannot be less than 1 (January)
        if ( month < 1 ) {
            this.setMonth("01");
        }
        // Month value cannot be greater than 12(December)
        if ( month > 12 ) {
            this.setMonth("12");
        }
        // take care of prefixing zero for single digit entries
        if ( ( month < 10 ) && ( month > 0 ) ) {
            this.setMonth( "0" + month );
        }

        // Update the day entry as per month
        this.updateDaysForMonth();
    },

    /**
     * Verify Day Entry as per the month and 
     * sometimes as per year for leap year 
     * @function updateDaysForMonth
     */
    updateDaysForMonth : function() {        
        // filter out the error cases
        if ( !this.validDateEntered() || !this.validMonthEntered() ) {
            return;
        }        
        
        // get month
        month = parseInt(this.getMonth(), 10); 
        // get day
        day = parseInt(this.getDay(), 10); 
        
        //If the month is april,june,Sep,Nov then the number of days is 30
        if ( ( month == 4 || month == 6 || month == 9 || month == 11 ) && day > 30 ) {
            this.setDay("30");
            return;
        }

        // special handling for month february
        if ( month == 2 ) {
            if( day > 29 ) {
                this.setDay("29");
            }
            if ( this.validYearEntered() ) {
                this.updateDaysInFebForYear();                
            }            
        }
    },

    /**
     * Validatidate day entry and correct it if error 
     * and prefix it with zero if required
     * @function verifyMonthEntry
     */
    verifyDayEntry : function() {
        var day = parseInt(this.getDay(), 10);
        if ( isNaN(day) ) {
            return;
        }   
        // day cannot be less than 1
        if ( day < 1 ) {
            this.setDay("01");
        }
        // maximum value for day is 31
        if ( day > 31 ) {
            this.setDay("31");
        }
        // Prefix zero for single digit entries
        if ( ( day < 10 ) && ( day > 0 ) ) {
            this.setDay( "0" + day );
        }
        this.updateDaysForMonth();
    },

    /**
     * Validate year entry and prefix with zeros if required
     * @function verifyMonthEntry
     */
    verifyYearEntry : function() {
        var yearEntry = this.getYear();
        var year = parseInt(yearEntry, 10);
        if ( isNaN(year) ) {
            return;
        }	
	
	if(year <= 1900) {
	   yearEntry = "1900";	
	} 
        this.setYear(yearEntry); 

        // Updated the year.
        // But depending on the year and month the date might get modified.        
        this.updateDaysInFebForYear();    
    },

    /**
     * update the date in february
     * @function updateDaysInFebForYear
     */
    updateDaysInFebForYear : function() {
        // filter out the error cases
        if ( !this.validMonthEntered() || !this.validDateEntered() ) {
            return;
        }
        var month = this.getMonth();
        // Date updation is necessary only if it is a leap year
        if ( month != 2 ) {
            return;
        }
        var year = this.getYear();

        if ( !this.isLeapYear(year) && ( parseInt(this.getDay(), 10) > 28 )) {
            this.setDay("28");
        }
    },

    /**
     * Checks if year is a leap year
     * @function isLeapYear
     * @param {string} aYear The year to be validated
     */
    isLeapYear : function(aYear) {
        return (((aYear % 4 == 0) && ( (!(aYear % 100 == 0)) || (aYear % 400 == 0))) ? true : false );
    }
    
});
