/**
 *
 * Description : A static class (Javascript object) that returns the error string based on the
 *               error code
 * <p>
 * Filename    : SSOError.js
 * <p>
 * Part of     : UI Framework
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:  6 %
 * 
 * @memberOf ovi.serviceui.ssoui.ssoui.ui.SSOError
 */
 
ovi.provide('ssoui.ui.SSOError');


var SSOError = {	

	/**
	 * Returns the error string based on the corresponding error codes 
	 * @function getErrorMessage
     * @param{int} aErrorCode - error code 
     * @return{string} errormessage - error message to be displayed.
	 */	
     getErrorMessage : function(aErrorCode){
          var errMsg ="";
         switch(aErrorCode) {
            case ErrorCode.errorInvalidCredentails: //Invalid username password               
                errMsg = sso_msg_0001;
                break;            
            case ErrorCode.errorTimeout: //Network time out   
                errMsg = sso_msg_0023;
                break;                                
            case ErrorCode.errorDateOfbirthNotFound: //date of birth is not valid
                errMsg = sso_msg_0034;
                break;
            case ErrorCode.errorCaptchaError: //Confirmation failed
                errMsg = sso_msg_securitycheck_wrongcpatcha;
                break;        
            case ErrorCode.errorInvalidEmailAddress: //Error invalid email address     
                errMsg = sso_msg_0009;
                break;        
            case ErrorCode.errorInvalidPhoneNumber: //Error invalid phone numbesso_msg_0020r 
                errMsg = sso_msg_0010;
                break;        
            case ErrorCode.errorPasswordMismatch: //Error password mismatch 
                errMsg = sso_msg_0011;
                break; 
            case ErrorCode.errorInvalidCountry: 
                errMsg = sso_msg_0027;
                break;
            case ErrorCode.errorInvalidLanguage: //key in valid email and mobile number
                errMsg = sso_msg_0028;
                break;    
            case ErrorCode.errorUsernameReserved:  // username is already taken
                errMsg=sso_msg_0024;
                break;
            //case ErrorCode.errorInvalidLanguage: //Invalid Language
              //  errMsg = sso_msg_0011;
               // break; 
            case ErrorCode.errorConnectionRefused:   
            case ErrorCode.errorRemoteHostClosed:   
            case ErrorCode.errorHostNotFound:   
            case ErrorCode.errorSslHandShakeFailed:
            case ErrorCode.errorProxyConnectionRefused:
            case ErrorCode.errorProxyConnectionClosed:
            case ErrorCode.errorProxyNotFound:
            case ErrorCode.errorProxyAuthenticationRequired:
            case ErrorCode.errorUnknownNetworkError:
            case ErrorCode.errorUnknownProxyError:
                errMsg = sso_msg_0035;
                break;
            case ErrorCode.errorAttributeSyntaxError:
            case ErrorCode.errorOperationFailed:
            case ErrorCode.errorResourceNotFound:
	    //This error pops up when the server is down and when the comsumer key is wrong.
	    case ErrorCode.errorNotAuthorized:     //Not Authorozed
            case ErrorCode.errorGeneralError:
                errMsg = sso_msg_0020;
                break; 
            default : //Default error code. Unable to perform opertaion
                errMsg = sso_msg_0020;
                break;        
        }
        return errMsg;
     }
	
};