/**
 *
 * Description : A class that extends control
 *               Displays an image and when clicked on the image
 *               an event is triggered.
 * <p>
 * Filename    : SSOImageLink.js
 * <p>
 * Part of     : ui
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOImageLink
 * @name SSOImageLink 
 * @version %version:   17.2.3 %
 */

ovi.provide("ssoui.ui.SSOImageLink");

ovi.require('ovi.dom');
ovi.require('ovi.ui.Control');
ovi.require('ovi.ui.Spinner');
ovi.require('ovi.ui.Image');

/**
 * Image UI Control.
 *
 * @publish
 * @class
 * @name ovi.ui.SSOImageLink
 * @extends ovi.ui.Control
 * @param {Object} properties A hash with properties for the snippet.
 * @param {String} properties.text The button's text.
 * @param {Node} [placement] Placement node that defines the place for snippet.
 * @param {String} [position] Relative position of the snippet to the placement node.
 */

/**
 * Fires "selected" event if button is clicked while not disabled.
 *
 * @event
 * @name ovi.ui.SSOImageLink#fireEvent:selected
 * @see ovi.EventSource
 */
ovi.ui.SSOImageLink = new ovi.Class({

    Extends: ovi.ui.Control,

    /**
     * Default template for the button, will be used to create the DOM nodes.
     			'<div id="ssojsuiImgDivSpinner">' +
     				'<div data-bind-snippet="ovi.ui.Spinner:spinner" align: centre></div>' +
     			'</div>' +
     */
    template: '<div id="ssojsuiImgDiv" class="sso_imgDiv">' +
    			'<div id="ssojsuiImgDivImage">' +
                  '<b data-bind-event="click:_onClick">' +
                      '<img class="ssoCaptchaImage" data-bind-attr="src:src,alt:alt,width:width,height:height,border:2px,border-color:black" src="" alt=sso_msg_0025/>' +
                  '</b>' +
                 '</div>' +
              '</div>',

    /**
     * The click handler fires the selected event and prevents the passed event to perform the default action.
     *
     * @param {Event} e the fired DOM event
     */
    _onClick: function (e) {          
        if (!this.disabled) {            
            this.fireEvent("selected");
        }
        if (ovi.browser.msie) {
            e.returnValue = false;
        } else {
            e.preventDefault();
        }
    },
        
    /**
     * 
     */
    setLoadingImageSpinner: function()
    {
        this.ssojsuiImgDivImage.setProperty("hidden", true);
    	//this.setProperty('src', ""); 
        this.ssojsuiImgDivSpinner.setProperty("hidden", false);    	
    },
    
    //@TODO: Trying to use spinner when image is getting loaded
    /**
     * Set a specific image to the display
     * @function: setImage
     * @param (img) Imagefile to be displayed
     */
    setImage: function(img){
    	if(img != "")
    	{
    		ovi.debug("hide spinner");
        	this.setProperty('src', img);
        	
        	//ovi.dom.byId('ssojsuiImgDivImage').setProperty("hidden", false);
        	//ovi.dom.byId('ssojsuiImgDivSpinner').setProperty("hidden", true);
            //this.ssojsuiImgDivImage.setProperty("hidden", false);
            //this.ssojsuiImgDivSpinner.setProperty("hidden", true);         	
    	}else{
    		ovi.debug("show spinner");
        	this.setProperty('src', ""); 
        	this.setProperty('alt', sso_msg_0025);
        	
        	//this.captchaImage.setProperty("hidden", true);
            //this.spinner.setProperty("hidden", false);    	
            //this.ssojsuiImgDivImage.setProperty("hidden", true);
            //this.ssojsuiImgDivSpinner.setProperty("hidden", false);
        	//ovi.dom.byId("ssojsuiImgDivImage").setProperty("hidden", true);
        	//ovi.dom.byId("ssojsuiImgDivSpinner").setProperty("hidden", false);
    	}
    }
});
