/*
 * Copyright (C) 2009, Nokia gate5 GmbH Berlin
 *
 * These coded instructions, statements, and computer programs contain
 * unpublished proprietary information of Nokia gate5 GmbH, and are
 * copy protected by law. They may not be disclosed to third parties
 * or copied or duplicated in any form, in whole or in part, without
 * the specific, prior written permission of Nokia gate5 GmbH.
 */

ovi.provide("ssoui.ui.SSOPasswordInput");

ovi.require('ovi.dom');
ovi.require("ovi.Event");
ovi.require("ovi.ui.Snippet");
ovi.require("ovi.ui.PasswordInput");
ovi.require("ovi.ui.CheckBox");

/**
 * Creates a input field component.
 * Optionally containing a watermark, a text that will be displayed when no text was entered and the component is
 * not focused. When a watermark is displayed, a na_Watermarked css class will be added to the input.
 *
 * @publish
 * @class
 * @name ovi.ui.PasswordInput
 * @param {Object} aProperties properties object that will be used to configure input component on initialization.
 * Can contain following fields:
 *      @param {string} value - the initial value of the component
 *      @param {string|null} maxSize - the initial size of the input field, string or null if you want unlimited size
 *      @param {string} watermark - the watermark that will be displayed when there is no text in the text field
 * @param {DOM Node} [aPlacement] the dom node element where the component will be placed
 * @param {string} [aPosition] Relative position to the reference node. One of:
 *      last (default) - places the snippet as the last child of the refNode
 *      first - first child of the refNode
 *      replace - replaces refNode
 *      only - makes the snippet the only child of the refNode
 *      before - inserts the snippet as a sibling before the refNode
 *      after - inserts the snippet as a sibling after the refNode
 */
ssoui.ui.SSOPasswordInput = new ovi.Class({
	
    Extends: ovi.ui.PasswordInput,

    /**
     * Initialize function for SSOPasswordInput Control.
     *
     * @param {Object} aProperties A hash with properties for the snippet.
     * @param {DOMNode} [aPlacement] Placement node that defines the place for snippet.
     * @param {String} [aPosition] Relative position of the snippet to the placement node.     
     */

    initialize : function(aProperties, aPlacement, aPosition) {
		//The label to display the text input description or the label to display 
		//the UI validation error message
        this._textInputLabel = new ovi.ui.Label({ text: "" }, aPlacement);
        this._textInputLabel._root.className = "sso_field_Label";
		
        // Invoke base class initialize function
        this._super.apply(this, arguments);	
		
        //Properties can be fetched only after init the base class
		//Get the label for the text input from the property
		var inputTextlabel = this.getProperty("textlabel");	
		//Set the property to the input label.	
		this._textInputLabel.setProperty("text",inputTextlabel);

        this._showPassword = new ovi.ui.CheckBox({value: sso_signup_checkbox_showpassword,
                                  text: sso_signup_checkbox_showpassword,
                                  hidden: 'true',
                                 checked: false}, aPlacement);
								 
		//If the passoword checkbox is selected the password input will be shown as text
        this._showPassword.addEventHandler("selected", function() {
            if(this._showPassword.getProperty("checked")) {
                this._root.type = "text";
            } else {
                this._root.type = "password";
            }
        }, this);
        
    },

    /**
     * Function to set the message to the password field.
     * @function setMessage
	 * @param {string} msg - Message to be displayed for the password text input as label
     */
	setMessage : function(msg) {
		//Set the message to the text property 
    	this._textInputLabel.setProperty("text",msg);    	
		//set the css class name as error for the UI validation error
		this._textInputLabel._root.className = "sso_error_Label";
    },
	
	/**
     * Function to clear the password field message.
     * @function clearMessage
     */
	 //@TODO : remove this if not needed
    clearMessage : function() {
    	//this._textInputLabel.setProperty("text","");
    	//this._textInputLabel.setProperty("hidden", true);
    },
    
    /**
     * function to hide or show the Show Password checkbox
     * @function displayShowPassword
	 * @param {bool} isVisible - displays the password text if show password checkbox is selected
     */
    displayShowPassword: function(isVisible) {
		//Check if the password has to be shown 
    	if(isVisible == true) {
    		this._showPassword.setProperty('hidden', false);
    	} else {    		
    		this._showPassword.setProperty('hidden', true);
    	}	
    }    
    
});
