/**
 *
 * Description : A class that extends ovi.ui.TextInput
 *               A snippet that is extended for Dali style representation
 *               of TextInput
 * <p>
 * Filename    : SSOPasswordInputNew.js
 * <p>
 * Part of     : Control
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOPasswordInputNew
 * @name  SSOPasswordInputNew 
 * @version %version:   %
 */

ovi.provide("ssoui.ui.SSOPasswordInputNew");

ovi.require('ovi.dom');
ovi.require("ovi.Event");
//ovi.require("ovi.ui.Snippet");
ovi.require("ovi.ui.PasswordInput");
//ovi.require("ovi.ui.Label");
ovi.require("ovi.ui.CheckBox");

/**
 * Creates a input field component.
 * Optionally containing a watermark, a text that will be displayed when no text was entered and the component is
 * not focused. When a watermark is displayed, a na_Watermarked css class will be added to the input.
 *
 * @publish
 * @class
 * @name ovi.ui.PasswordInput
 * @param {Object} aProperties properties object that will be used to configure input component on initialization.
 * Can contain following fields:
 *      @param {string} value - the initial value of the component
 *      @param {string|null} maxSize - the initial size of the input field, string or null if you want unlimited size
 *      @param {string} watermark - the watermark that will be displayed when there is no text in the text field
 * @param {DOM Node} [aPlacement] the dom node element where the component will be placed
 * @param {string} [aPosition] Relative position to the reference node. One of:
 *      last (default) - places the snippet as the last child of the refNode
 *      first - first child of the refNode
 *      replace - replaces refNode
 *      only - makes the snippet the only child of the refNode
 *      before - inserts the snippet as a sibling before the refNode
 *      after - inserts the snippet as a sibling after the refNode
 */
ssoui.ui.SSOPasswordInputNew = new ovi.Class({
	
    Extends: ovi.ui.PasswordInput,

    //@TODO: Add support for checkbox reading as "show password"	
    /**
     * The default template for the dialog.
     *
     * @type String
     * @see ovi.ui.Snippet
     */
    template: 
        '<div class="sso_PassInputNew">' +
                '<div data-bind-snippet="ovi.ui.Label:sso_TextInputHdrLabel" data-bind-prop="text:HdrLabel"></div> ' +
                '<div data-bind-snippet="ovi.ui.Label:sso_TextInputErrLabel" data-bind-prop="text:ErrLabel"></div> ' +
                '<div data-bind-snippet="ovi.ui.PasswordInput:sso_TextInputValue" data-bind-prop="maxLength:maxLength,value:TextValue"></div>' +
                '<div data-bind-snippet="ovi.ui.Label:sso_TextInputInfoLabel" data-bind-prop="text:InfoLabel"></div> ' +
        '</div>',	

    /**
     * Initialize function for SSOTextInputNew Control.
     *
     * @param {Object} aProperties A hash with properties for the snippet.  
	 * @param {DOMNode} [aPlacement] Placement node that defines the place for snippet.     
     */    	
	initialize : function(aProperties, aPlacement) {
        this._super(aProperties, aPlacement);
        this.sso_TextInputHdrLabel.setProperty("extraClass", "sso_field_Label");
        this.sso_TextInputErrLabel.setProperty("extraClass", "sso_error_Label");
        this.sso_TextInputErrLabel.setProperty("hidden", true);
        this.sso_TextInputInfoLabel.setProperty("extraClass", "sso_field_ins_Label");
	},
	
    /**
     * Function to set the header Label 
     */
    setHdrLabelText: function(textValue){
        this.sso_TextInputHdrLabel.setProperty("text" , textValue);
        //this.sso_TextInputHdrLabel.visible = true;
        
    },
    
    /**
     * Function to set the header Label 
     */
    setErrLabelText: function(textValue){
        if (textValue)
        {
            this.sso_TextInputErrLabel.setProperty("text" , textValue);
            this.sso_TextInputErrLabel.setProperty("hidden", false);
            this.sso_TextInputHdrLabel.setProperty("hidden", true);
            //this.sso_TextInputHdrLabel.display = 'none';
            this.sso_TextInputErrLabel._root.className = "sso_error_Label";
        }
    },
    
    /**
     * Function to fetch the Label text in ErrorLabel
     * @return {String} Text value within the ErrorLabel
     */
    getErrLabelText: function(){
        return this.sso_TextInputErrLabel.getProperty("text");
    },
	
    /**
     * Function to set the text for TextInput
     * @param {String} textValue String to be displayed in the textInput
     */
    setInputText: function(textValue){
        if (textValue !== undefined)
        {
            this.sso_TextInputValue.setProperty("value" , textValue);
        }
    },	
    	
    /**
     * Function to get the TextValue(Password) inside the textbox
     * @return {String}
     */
    getInputText: function(){
        return this.sso_TextInputValue.getProperty("value");
    },
    
    /**
     * Function to set the info Label
     */
    setInfoLabelText: function(textValue){
        this.sso_TextInputInfoLabel.setProperty("text" , textValue);
    }, 
    
    /**
     * Function to clear the error
     */
    clearErrorLabel: function(){
        this.sso_TextInputErrLabel.setProperty("text" , "");
        this.sso_TextInputErrLabel.setProperty("hidden", true);
        this.sso_TextInputHdrLabel.setProperty("hidden", false);        
    }
});
