/*
 * Copyright (C) 2009, Nokia gate5 GmbH Berlin
 *
 * These coded instructions, statements, and computer programs contain
 * unpublished proprietary information of Nokia gate5 GmbH, and are
 * copy protected by law. They may not be disclosed to third parties
 * or copied or duplicated in any form, in whole or in part, without
 * the specific, prior written permission of Nokia gate5 GmbH.
 */

ovi.provide("ssoui.ui.SSOProgressBar");

ovi.require('ovi.dom');
ovi.require("ovi.ui.Snippet");
ovi.require("ovi.ui.Control");

/**
 * A progress bar is a control that shows visual progress based on the actual and maximum progress.
 *
 * @publish
 * @class
 * @name ovi.ui.ProgressBar
 * @param {Object} [aProperties={}] The properties object that will be used to configure ProgressBar component on
 *         initialization. Can contain following fields:
 * @param {number} [value=0.0] The initial value of the overall progress.
 * @param {number} [maximum=1.0] The maximum value of the overall progress.
 * @param {DOM Node} [aPlacement] The DOM node element where the component will be placed.
 * @param {string} [aPosition="last"] Relative position to the reference node {@link ovi.ui.Snippet#place}.
 */
ssoui.ui.SSOProgressBar = new ovi.Class({
	
    Extends: ovi.ui.Control,

    /**
     * The default template for the progress bar. Will be used to create the DOM nodes.
     */
    template: '<div><div class="ovi_hidden" data-bind-ref="ssoProgressMask"></div><div class="SSOProgressBar" id="ssoProgressBar"><div data-bind-ref="progress"></div></div></div>',
    
    /**
     * isModal property 
     */
    isModal: false,
    
    /**
     * Provides custom accessors.
     *
     * @type Object
     * @see ovi.ui.Snippet
     */
    accessors: {
		isModal: {
			get: "_getIsModal", set:"_setIsModal"
		}
	},
	
	/**
	 * Private getter method for isModal property.
	 * @function _getIsModal
	 */
	_getIsModal: function() {
		return this.isModal;
	},
	
	/**
	 * Private setter method for isModal
	 * @function _setIsModal
	 */
	_setIsModal: function(aValue) {
		this.isModal = aValue;
		if(aValue == true) {
			this.ssoProgressMask.className = "ovi_modal";
		} else {			
			this.ssoProgressMask.className = "ovi_hidden";
		}
	},

    /**
     * Init function of the progress control.
     * @function initialize
     */
    initialize : function(aProperties, aPlacement) {
		this._super(aProperties, aPlacement);		
		
		this._timerId = -1;        
        this._frameInterval = 100; //in milliseconds.        
        this._frameOffset = 0;
        this.setProperty("hidden", true);
        //ovi.setStyle(this._root, "display", "none");
        this._updateUI();
    },
    
    /**
     * function hide & stop the progress animation
     * @function stop
     */
    stop: function() {        
    	this.setProperty("hidden", true);
    	this._setIsModal(false);
        if (this._timerId > -1) {                    
            clearInterval(this._timerId);
            this._timerId = -1;
        }
    },
    
    /**
     * Pause the animation if it's currently ongoing, or does nothing if it's not 
     * @function pause
     */
    pause: function() {
       if (this._timerId > -1) {                    
            clearInterval(this._timerId);
            this._timerId = -1;
        }
    },
    
    /**
     * Resumes the animation from the current frame 
     * @function resume
     */
    start: function() {    	
    	this.setProperty("hidden", false);
        if (this._timerId > -1) {
            this.pause();
        }
        this._updateUI();
        var self = this;
        this._timerId = setInterval(function() { self._updateUI(); }, this._frameInterval);
    },
    
    /**
     * Updates the progress bar UI by effecting the DOM.
     * @function _updateUI
     */
    _updateUI: function() {
    	var _progress = ovi.dom.byId("ssoProgressBar");
    	if(_progress) {
    		_progress.style.backgroundPosition = "-" + (this._frameOffset) + "px 0px";
    		this._frameOffset = this._frameOffset+2;
    	}
    }
});
