/*
 * Copyright (C) 2009, Nokia gate5 GmbH Berlin
 *
 * These coded instructions, statements, and computer programs contain
 * unpublished proprietary information of Nokia gate5 GmbH, and are
 * copy protected by law. They may not be disclosed to third parties
 * or copied or duplicated in any form, in whole or in part, without
 * the specific, prior written permission of Nokia gate5 GmbH.
 */

ovi.provide("ssoui.ui.SSOScrollBar");

ovi.require('ovi.dom');
ovi.require("ovi.ui.Snippet");
ovi.require("ovi.ui.Control");

/**
 * A progress bar is a control that shows visual progress based on the actual and maximum progress.
 *
 * @publish
 * @class
 * @name ovi.ui.ProgressBar
 * @param {Object} [aProperties={}] The properties object that will be used to configure ProgressBar component on
 *         initialization. Can contain following fields:
 * @param {number} [value=0.0] The initial value of the overall progress.
 * @param {number} [maximum=1.0] The maximum value of the overall progress.
 * @param {DOM Node} [aPlacement] The DOM node element where the component will be placed.
 * @param {string} [aPosition="last"] Relative position to the reference node {@link ovi.ui.Snippet#place}.
 */  

ssoui.ui.SSOScrollBar = new ovi.Class({

    /**
     * The default template for the scroll bar. Will be used to create the DOM nodes.
     */
    template: '<div class="ScrollbarContainer"><div></div></div>',
	
    /**
     * Animation extends from Control class.
     *
     * @extends ovi.serviceui.ssoui.ssoui.wrtkit.Control
     */
    Extends: ovi.ui.Control,

    /**
     * Initialize the control.
     *
     * @function initialize
     * @param {Boolean} if the scroll needs to shown always.
     *  
     */
    initialize : function(aProperties, aPlacement) {
        this._super(aProperties, aPlacement);
        
        //this._root.className = "ScrollbarContainer";
        
        this.scrollbarNeeded = true;
        this.alwaysShowScrollbar = true;
        
        this.scrollElement = document.createElement("div");
        this.scrollElement.className = "Scrollbar";
        this.scrollElement.style.visibility = "hidden";
        this.trackTopElement = document.createElement("div");
        this.trackTopElement.className = "ScrollbarTrackTop";
        this.trackMiddleElement = document.createElement("div");
        this.trackMiddleElement.className = "ScrollbarTrackMiddle";
        this.trackBottomElement = document.createElement("div");
        this.trackBottomElement.className = "ScrollbarTrackBottom";
        this.thumbTopElement = document.createElement("div");
        this.thumbTopElement.className = "ScrollbarThumbTop";
        this.thumbMiddleElement = document.createElement("div");
        this.thumbMiddleElement.className = "ScrollbarThumbMiddle";
        this.thumbBottomElement = document.createElement("div");
        this.thumbBottomElement.className = "ScrollbarThumbBottom";
        this.scrollElement.appendChild(this.trackTopElement);
        this.scrollElement.appendChild(this.trackMiddleElement);
        this.scrollElement.appendChild(this.trackBottomElement);
        this.scrollElement.appendChild(this.thumbTopElement);
        this.scrollElement.appendChild(this.thumbMiddleElement);
        this.scrollElement.appendChild(this.thumbBottomElement);
        this._root.appendChild(this.scrollElement);
        this.update(0, 100, 100);
        
        this._onUpdateStyle();
    },
    
    /**
     * Updates the scroll bar control, this will be tiggered when ever user scrolls the page.
     *  
     * @function update
     * @param {Boolean} 
     * 
     */
    update : function(forceUpdate) {
    	try {
	    	var scrollY = window.scrollY;
		    var viewportHeight = window.innerHeight;
		    var documentHeight = Math.max(document.documentElement.scrollHeight, document.height);
		    
		    if (forceUpdate || this.scrollY != scrollY || this.viewportHeight != viewportHeight || this.documentHeight != documentHeight) {
		    	var scrollbarHeight = this.rootElement.clientHeight;
		        var trackTopHeight = this.trackTopElement.clientHeight;
		        var trackBottomHeight = this.trackBottomElement.clientHeight;
		        var thumbTopHeight = this.thumbTopElement.clientHeight;
		        var thumbBottomHeight = this.thumbBottomElement.clientHeight;
		        var scrollableHeight = documentHeight;
		        var scrollbarNeeded = true;
		        if (!this.alwaysShowScrollbar && (viewportHeight >= documentHeight)) {
		            scrollableHeight = viewportHeight;
		            scrollbarNeeded = false;		            
		        }
		        
		        if (scrollbarNeeded != this.scrollbarNeeded) {
		            this.scrollbarNeeded = scrollbarNeeded;
		            this.rootElement.style.visibility = scrollbarNeeded ? "visible" : "hidden";
		            this.scrollElement.style.visibility = scrollbarNeeded ? "visible" : "hidden";
		        }
		        var thumbTopPct = scrollY / scrollableHeight;
		        var thumbTop = scrollbarHeight * thumbTopPct;
		        var thumbBottomPct = (scrollY + viewportHeight) / scrollableHeight;
		        var thumbBottom = scrollbarHeight * thumbBottomPct;
		        var thumbHeight = thumbBottom - thumbTop;
		        var thumbMinHeight = thumbTopHeight + thumbBottomHeight;
		        if (thumbHeight < thumbMinHeight) {
		            var underflow = thumbMinHeight - thumbHeight;
		            var thumbMid = (scrollbarHeight - underflow) * ((thumbTopPct + thumbBottomPct) / 2) + (underflow / 2);
		            thumbTop = thumbMid - (thumbMinHeight / 2);
		            thumbBottom = thumbTop + thumbMinHeight;
		            thumbHeight = thumbBottom - thumbTop;
		        }
		        this.trackTopElement.style.top = "0px";
		        this.trackMiddleElement.style.top = Math.round(trackTopHeight) + "px";
		        this.trackMiddleElement.style.height = Math.round(scrollbarHeight - trackTopHeight - trackBottomHeight + 1) + "px";
		        this.trackBottomElement.style.top = Math.round(scrollbarHeight - trackTopHeight) + "px";
		        this.thumbTopElement.style.top = Math.round(thumbTop) + "px";
		        this.thumbMiddleElement.style.top = Math.round(thumbTop + thumbTopHeight) + "px";
		        this.thumbMiddleElement.style.height = Math.round(thumbHeight - thumbTopHeight - thumbBottomHeight + 1) + "px";
		        this.thumbBottomElement.style.top = Math.round(thumbBottom - thumbBottomHeight) + "px";	        
		    } 
    	} catch (ex) {
	    	//@do nothing..
	    }
    },
        
    /**
     * This method is called either by _updateStyle to take care of style
     * changes in this view or by the control itself to update the current
     * look of the control.
     *
     * @function _onUpdateStyle
     */
    _onUpdateStyle: function() {
        //var cssState = this._getCssState();
        //this.rootElement.className = "ScrollbarContainer";
    }
    
});