/**
 *
 * Description : A class that extends ovi.ui.TextInput
 *               A snippet that is extended for Dali style representation
 *               of TextInput
 * <p>
 * Filename    : SSOTextInput.js
 * <p>
 * Part of     : Control
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOTextInput
 * @name  SSOTextInput 
 * @version %version:   %
 */


ovi.provide("ssoui.ui.SSOTextInput");
ovi.require("ovi.ui.TextInput");

/**
 * Creates a input field component.
 * Optionally containing a watermark, a text that will be displayed when no text was entered and the component is
 * not focused. When a watermark is displayed, a na_Watermarked css class will be added to the input.
 *
 * @publish
 * @class
 * @name ovi.ui.TextInput
 * @param {Object} aProperties properties object that will be used to configure input component on initialization.
 * Can contain following fields:
 *      @param {string} value - the initial value of the component
 *      @param {string|null} maxSize - the initial size of the input field, string or null if you want unlimited size
 *      @param {string} watermark - the watermark that will be displayed when there is no text in the text field
 * @param {DOM Node} [aPlacement] the dom node element where the component will be placed
 * @param {string} [aPosition] Relative position to the reference node. One of:
 *      last (default) - places the snippet as the last child of the refNode
 *      first - first child of the refNode
 *      replace - replaces refNode
 *      only - makes the snippet the only child of the refNode
 *      before - inserts the snippet as a sibling before the refNode
 *      after - inserts the snippet as a sibling after the refNode
 */
ssoui.ui.SSOTextInput = new ovi.Class({
    
	Extends: ovi.ui.TextInput,
	
	/**
     * Initialize function for SSOTextInput Control.
     *
     * @param {Object} aProperties A hash with properties for the snippet.  
	 * @param {DOMNode} [aPlacement] Placement node that defines the place for snippet.     
     */
	initialize : function(aProperties, aPlacement) {	
		//The label to display the text input description or the label to display 
		//the UI validation error message
		this._textInputLabel = new ovi.ui.Label({ text: "" }, aPlacement);		
		//Set the class name as the field label.	
		this._textInputLabel._root.className = "sso_field_Label";						
		this._super(aProperties, aPlacement);		
		//Properties can be fetched only after init the base class
		//Get the label for the text input from the property
		var inputTextlabel = this.getProperty("textlabel");					
		//Set the property to the input label.	
		this._textInputLabel.setProperty("text",inputTextlabel);
    },
    
    /**
     * Function set the error message 
     * @function setMessage
	 * @ para{string} msg - The message to set for the text input
     */
	setMessage : function(msg) {
		//Set the message to the text input label
    	this._textInputLabel.setProperty("text",msg);    	
		//set the css class name as error for the UI validation error
		this._textInputLabel._root.className = "sso_error_Label";
    },
	
	/**
     * Function to clear the error message
     * @clearMessage
     */
	 //@TODO : remove this if not needed
    clearMessage : function() {
    	//this._textInputLabel.setProperty("text","");
    	//this._textInputLabel.setProperty("hidden", true);
    }    
});
