/**
 *
 * Description : A static class (Javascript object) that maintains a set of
 * functions to display messages in the view.
 * <p>
 * Filename    : SSOUIHelper.js
 * <p>
 * Part of     : UI Framework
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:  5.1.1 %
 * 
 * @memberOf ovi.serviceui.ssoui.ssoui.ui.SSOUIHelper
 */
 
ovi.provide('ssoui.ui.SSOUIHelper');
ovi.require('ssoui.utils.MessageType', false);

var SSOUIHelper = {
	
	_isInit : false,	
		
	init: function() {
		//update/set the page size depending on the screen resolution.
		SSOUIHelper.updatePageSize();
		//ovi.debug("Inside UI helper init");
		if(SSOUIHelper._isInit) {
			ovi.debug("UI Helper is already initialized");
		} else {
			ovi.debug("UI Helper is not initialized");
			SSOUIHelper._isInit = true;
			
			//add a resize event to change the page size, when the device screen is changed from potrait to 
			//landscape or vice versa.
	        window.onresize = function() { SSOUIHelper.updatePageSize(); };
		}
	},
	
	/**
	 * Function to set the page size depending on the screen resolution.
	 * @function updatePageSize
	 */
	updatePageSize: function() {
		ovi.debug("Inside updatePageSize");
		
		//get the height of the screen & minus the title bar & softkey area set the height to the 
		//page container. Width by default will be 100%
		ovi.dom.byId("page").style.height = (window.innerHeight - (40 + 95)) + "px";
	},
	
	/** 
	 * Helper function to display the warning message on the current view.
	 * @param {string} aMessage - the warning message which needs to be displayed.
	 * @function showWarning
	 */	
	showWarning : function(aMessage) {
		SSOUIHelper._showMessage(MessageType.Warning, aMessage);
	},
	
	/**
	 * Helper function to display the error message on the current view.
	 * @param {string} aMessage - the error message which needs to be displayed.
	 * @function showError
	 */
	showError : function(aMessage) {
		var _page = ovi.dom.byId("page");
		if(_page) {
			_page.scrollTop = 0;
		}		
		SSOUIHelper._showMessage(MessageType.Error, aMessage);
	},
	
	/**
	 * Helper function to display the info message on the current view.
	 * @param {string} aMessage - the info message which needs to be displayed. 	 
	 * @function showInfo
	 */
	showInfo : function(aMessage) {
		SSOUIHelper._showMessage(MessageType.Info, aMessage);
	},
	
	/**
	 * Helper funtion which hides all types of error displayed on the current view.
	 * @function hideMessage
	 */
	hideMessage: function() {
		var _msgContainer = ovi.dom.byId("messagecontainer");
		if(_msgContainer) {
			_msgContainer.style.display = "none";
		}
	},
    
	/**
	 * Function to show the system error dialog, this happens when there is a service provider plug-in loading failed.
	 * @function showSystemError
	 */
    showSystemError: function(aAppController,aErrorMessage) {
        ovi.require("ssoui.ui.SSODialog");
        var dialog = new ssoui.ui.SSODialog({ message: aErrorMessage , cancel :sso_popup_button_cancel }, document.body);
        dialog.addEventHandler(ssoui.ui.SSODialog.CLOSE_EVENT, function(e){
            ovi.info(e.data);            
            aAppController.closeApplication();            
        });    
    },
	
	/**
	 * Private internal method to display the info,warn & error messages on the current view.
	 * @param {string} _type - Parameter which identifies the message type.
	 * @param {string} _message - The message which needs to be displayed.
	 * @function _showMessage
	 */
	_showMessage : function(_type, _message) {
		var _msgContainer = ovi.dom.byId("messagecontainer");
		if(_msgContainer) {
			_msgContainer.style.display = "block";
			var _msgLabel = ovi.dom.byId("messagelabel"); 
			//@todo set the css styles depending on the message type
			if(_type == MessageType.Error) {
				_msgLabel.innerHTML = _message;
			} else if(_type == MessageType.Info) {
				_msgLabel.innerHTML = _message;
			} else if(_type == MessageType.Warning) {
				_msgLabel.innerHTML = _message;
			}
		}
	},
	
	
	//@todo remove this...As we have removed the progress view
	/**
	 * Function to hide the progress animation view.
	 * @function hideProgressView
	 */
	hideProgressView: function() {
		var _pview = ovi.dom.byId("ssojsuiProgressDiv");
		_pview.style.display = "none";
	},
	
	//@todo remove this... As we have removed the progress view
	/**
	 * Function to show the progress animation view
	 * @function showProgressView
	 */
	showProgressView: function() {
		var _pview = ovi.dom.byId("ssojsuiProgressDiv");
		_pview.style.display = "block";
	}
};