/*
 * Copyright (C) 2009, Nokia gate5 GmbH Berlin
 *
 * These coded instructions, statements, and computer programs contain
 * unpublished proprietary information of Nokia gate5 GmbH, and are
 * copy protected by law. They may not be disclosed to third parties
 * or copied or duplicated in any form, in whole or in part, without
 * the specific, prior written permission of Nokia gate5 GmbH.
 */

ovi.provide("ssoui.ui.TextLink");

ovi.require('ovi.dom');
ovi.require("ovi.ui.Control");

/**
 * Button UI Control. A button is a clickable entity.
 *
 * @publish
 * @class
 * @name ovi.ui.Button
 * @extends ovi.ui.Control
 * @param {Object} properties A hash with properties for the snippet.
 * @param {String} properties.text The button's text.
 * @param {Node} [placement] Placement node that defines the place for snippet.
 * @param {String} [position] Relative position of the snippet to the placement node.
 */

/**
 * Fires "selected" event if button is clicked while not disabled.
 *
 * @event
 * @name ovi.ui.TextLink#fireEvent:selected
 * @see ovi.EventSource
 */

ovi.ui.TextLink = new ovi.Class({

    Extends: ovi.ui.Control,

    /**
     * Default template for the button, will be used to create the DOM nodes.
     */
    template: '<div class="ovi_TextLink ovi_unselectable">' +
                  '<span data-bind-event="mousedown:_onMouseDown,click:_onClick">' +
                      '<span data-bind-text="text"></span>' +
                  '</span>' +
              '</div>',

    /**
     * The click handler fires the selected event and prevents the passed event to perform the default action.
     *
     * @param {Event} e the fired DOM event
     */
    _onClick: function (e) {  
    
        if (!this.disabled) {
            this.fireEvent("selected");
        }
        if (ovi.browser.msie) {
            e.returnValue = false;
        } else {
            e.preventDefault();
        }
    },

    /**
     * The mouse down handler fixes the mouse and touch behavior for some platforms. It ensures that the click event
     * will be fired even if the platform wouldn't do it per default. Required for a consistent behavior across all
     * platforms.
     *
     * @param {Event} e the fired DOM event
     */
    _onMouseDown: function (e) {
        if (!this.disabled) {
            var that = this, pressedTarget = e.srcElement || e.target, el = this._root.firstChild;

            ovi.addClass(this._root, "ovi_active");

            // FIXME [KH] cross-browser mouseenter/mouseleave in ovi.dom
            function cleanup() {
                pressedTarget = undefined;
                that._removeDOMEventListener(tempMouseLeaveHandler);
                that._removeDOMEventListener(tempMouseUpHandler);
                ovi.removeClass(that._root, "ovi_active");
            }

            var tempMouseLeaveHandler = ovi.browser.msie ?
                    this._addDOMEventListener(el, "mouseleave", cleanup, false) :
                    this._addDOMEventListener(el, "mouseout", function (e) {
                        if (ovi.comparePosition(el, e.relatedTarget) === 10) {
                            cleanup();
                        }
                    }, false);

            var tempMouseUpHandler = this._addDOMEventListener(el, "mouseup", function (e) {
                var releasedTarget = e.srcElement || e.target;
                // For certain touch devices we need to fake a click event if releasing isn't at the
                // same location as where was pressed...
                if (document.createEvent && pressedTarget && pressedTarget !== releasedTarget) {
                    // Create synthetic event and push execution to after "mouseup" via setTimeout.
                    setTimeout(function () {
                        var click = document.createEvent("MouseEvents");
                        click.initMouseEvent("click", true, true, window, 1, e.screenX, e.screenY, e.clientX, e.clientY,
                                e.ctrlKey, e.altKey, e.shiftKey, e.metaKey, 0, null);
                        releasedTarget.dispatchEvent(click);
                    }, 0);
                }
                cleanup();
            });
        }
    }
});
