/**
 *
 * Description : A class that extends ssoui.views.SSOWizardView.
 *              This view will be the first page during A/C creation
 *              wizard
 *    
 * <p>
 * Filename    : SSOAccDetailsView.js
 * <p>
 * Part of     : View
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOAccDetailsView
 * @name  SSOAccDetailsView 
 * @version %version:   %
 */

ovi.provide('ssoui.views.SSOAccDetailsView');
// system includes
ovi.require('ovi.sisu.HTMLView');
ovi.require('ovi.ui.Button');
ovi.require('ovi.ui.Label');
ovi.require('ovi.ui.TextInput');

// local includes
ovi.require('ssoui.views.SSOWizardView');
ovi.require('ssoui.ui.SSOTextInputNew');
ovi.require('ssoui.ui.TextLink');
ovi.require('ssoui.ui.SSOPasswordInputNew'); 
ovi.require('ssoui.utils.SSOUtil',false);
ovi.require('ssoui.ui.SSORadioGroupDialog');

ovi.declare('ssoui.views.SSOAccDetailsView', {
    
    /**
     * SSOAccDetailsView extends the SSOWizardView class.
     * @extends ssoui.views.SSOWizardView
     */
    Extends: ssoui.views.SSOWizardView,
    
    /**
     * Initialization function for SSOAccDetailsView     
     * @function initialize      
     */
    initialize: function() {        
	   ovi.debug("SSOAccDetailsView:Initalized");
        /* Enum values that specify the possible states of user name availability */
		//@TODO: CR: Use states values as constant?
        this._loginIdDetectionStates = {
            StatusInit : 0, /* Initial stage */   
            StatusNameSuggestions: 1, /* User name is not available. Name suggestions are there */
            StatusNameAvailable : 2 /* User name is available */
        };   
		
        /* Enum values that specify the context from which the call back function for user name availiability is invoked */
        this._loginIdCbContext = {
            ContextNone : 0,    /* Invalid context */
            ContextUserNameEdited : 1, /* Call back is invoked when user name is edited */   
            ContextNextButtonPressed: 2 /* Call back is invoked when user pressed the next button */            
        };  

        // Local variable to keep track of loginIdDetection & corresponding
		// call back context & loginIdSuggestions
        this._loginIdDetectionState = this._loginIdDetectionStates.StatusInit;
        this._cbContext = this._loginIdCbContext.ContextNone;
        this._loginIdSuggestions = new Array();

        /* Create and initialize the flags used in different functions */
        this._isValidId     = false;
        this._isValidPasswd = false; 

        /* Create and initialze the error objects used in different functions */  
		//@TODO: CR: Simplify below errorhandler       
//        this.errormessagesUserName = new Object();
//        this.errormessagesUserName.Message = "";
//        this.errormessagesPassword = new Object();
//        this.errormessagesPassword.Message = "";

        // Temporary transient variables for screen change
        this._IdValue   = "";
        this._IdError   = "";
        this._passValue = "";
        this._passError = "";     
		this._showPassChecked = false;          

        /* Initialization pertaining to the screen */
        this._super(sso_signup_title, sso_signup_header_accountdetails, 
		{
            text: sso_button_sk_continue,
            type: "affirmative"
		},
		{
            text: sso_button_sk_back 	
		} ); 
		
		this.ovimail = "@ovi.com";
		
    },

    /**
     * @private
     * Function that remove error messages and popups     
     * @function _hideErrorMessages      
     */
    _hideErrorMessages: function() {
        //clear any error messages displayed inline 
        this._IdError = "";
        this._passError = "";
        this._loginIdField.clearErrorLabel();
		this._passField.clearErrorLabel();

        // Hide Error popup if any
        SSOUIHelper.hideMessage();             	
    },

    /**
     * Function that invokes model function to check availability     
     * @function triggerUserNameAvailabilityCheck      
     */
    triggerUserNameAvailabilityCheck: function() {
        // Disable the Left soft key.
        // It is an important step. as we dont have a
        // synchronization mechanism to sync between the callback and
        // next button event handling.
        // So avoid any chance the Next button event.. :)
        this.disableLSK();	
        // Show a progress bar for better user experience
        this.showProgress();

        // Invoke the model function to check for user availability.	    	
        // Register "_userRetrieveNamesComplete" as the call back and wait.
        this.model.retrieveUsernameAvailability(this._userRetrieveNamesComplete, 
		      this._loginIdField.getInputText(), this);            	
    },

    /**
     * User name blurred event handler    
     * @function _loginIdBlurEvtHandler      
     */
    _loginIdBlurEvtHandler: function(aContext) { 
        try{
			ovi.debug("blur event handled");
            var errMsgLoginId = new Object();
            errMsgLoginId.Message = "";
		
            // set the call back context
            this._cbContext = this._loginIdCbContext.ContextUserNameEdited;
			if (this._loginIdField.getInputText() == this._IdValue)
			{
	            //  if username entered is different
	            //   than what was eariler entered. This will avoid n/w request
	            //   esp. when user sets / resets the focus on user name field
			     return;
			}
            
			this._IdValue = this._loginIdField.getInputText();

            // check validity of user name
            // please note the error received in 'this.errormessagesUserName' will not be used.        
			//@TODO: CR: MEDIUM. Re-org below code to call trigger only in case of success.
            if ( !ssoui.utils.SSOUtil.validateUserName(this._IdValue, errMsgLoginId) ) {
				this._loginIdField.setErrLabelText(errMsgLoginId.Message);
                // Invalid user name
                return;
            }
            // check if the user name is available.
            this.triggerUserNameAvailabilityCheck();
        } catch(ex) {            
			ovi.error("Exception in  blurevent:SSOSignUpModel.js:" + ex.message);
        }
    },

    //@TODO: CR: Below method is private. Use prefix "_"
    /**
     * @private
     * 
     * Checking the validity of user credentials
     * entered.(user name and passwd)    
     * @function _validateCredentials
     * @param {boolean} aIsEmailAccountCreation whether the context is Email
     *                  account creation?     
     * @return: (boolean) true credentials valid, else false 
     */
    _validateCredentials: function( aIsEmailAccountCreation) { 
	    var retValue = true;
		var emailtextinputdata;

        // Read the LoginId & Password value.        
		this._IdValue = this._loginIdField.getInputText();
		
		emailtextinputdata = this._IdValue; 
	    
		// If the context is ovi Email creation then we need to add @ovi.com to
		// the email id, this._IdValue is not updated because, this value is 
		// used for persistance of data.
        if(aIsEmailAccountCreation == true) {
			emailtextinputdata = this._IdValue + this.ovimail;
		}
 
        this._passValue = this._passField.getInputText();

        //Create the error message object for the LoginId & password
        var errMsgLoginId = new Object();
        errMsgLoginId.Message = "";
        var errMsgPassword = new Object();
        errMsgPassword.Message = "";

        // check validity of the current user name and passwd  
        this._isValidId = ssoui.utils.SSOUtil.validateEmailId(emailtextinputdata);
        if(!this._isValidId) {
        	errMsgLoginId.Message = sso_msg_email_invalid;
    	}
        
        this._isValidPasswd = ssoui.utils.SSOUtil.validatePassword(this._passValue, errMsgPassword); 

        this._IdError = errMsgLoginId.Message;
		this._passError = errMsgPassword.Message;
		
		if (this._isValidId == false)
		{
            this._loginIdField.setErrLabelText(errMsgLoginId.Message);
			retValue = false;
		}
		if (this._isValidPasswd == false)
		{
			this._passField.setErrLabelText(errMsgPassword.Message);
			retValue = false;
		}

        return retValue;
    },

    /**
     * Function to move to next screen from call back context.     
     * @function moveToNextStep  
     * @param{obj} aContext - calling class this pointer
     */
    moveToNextStep: function(aContext) {
        // Store the user name and passwd in the model. 
        aContext.model.setUsername(aContext._loginIdField.getInputText());
        aContext.model.setPassword(aContext._passField.getInputText());
		
        /* Publishing the event so that it goes to next screen */
        ovi.publish("onLSKClick");             	
    },

    //@TODO: CR: Below method is private. Prefix with "_" 
    /**
     * @private
     * 
     * Function to display the popup on name suggestions.     
     * @function showUsrNameSuggestionsPopup  
     * @param{obj} aContext - calling class this pointer
     */
    showUsrNameSuggestionsPopup: function(aContext) {
        // create a dialog to display available user names
        var dialog = new ssoui.ui.SSORadioGroupDialog({labels: aContext._loginIdSuggestions, 
                titlemessage: sso_signup_popup_title, 
                headingmessage: sso_signup_unames_label_pickunamefromlist}, 
                aContext.viewContainer);
        // listen to close event, it includes the selected radio as data
        // pass the context also so that class members can be accessed in event handler
        dialog.addEventHandler( ssoui.ui.SSORadioGroupDialog.CLOSE_EVENT, function (e) {
			//@TODO: CR: CRITICAL Use !==
			//@TODO: CR: MEDIUM Rename 'e' with better readable variable
            if ( typeof e.data != 'undefined' ) {
                //update the username field with the selected username                              
				//@TODO: CR: CRITICAL. Use aContext (avoid this), as this func is called
				//      from an async call-back function                             
                this._userNameTextField.setProperty('value', e.data);
                this._loginIdDetectionState = this._loginIdDetectionStates.StatusNameAvailable;                
            } else {
                // user has not selected any value. Value is undefined.
                // reset the user name status to init.
                // Resetting is important because if blurred event does not occur and
                // user edited user name entry, next button will display the same popup
                // Anyway this will again trigger the availability check, but price is lesser 
                // compared to other buggy situations.
                this._loginIdDetectionState = this._loginIdDetectionStates.StatusInit;
            }

        },aContext); 
        ovi.debug("showUsrNameSuggestionsPopup: Exit");
    },

    /**
     * Callback API when the entered user name availablity is checked      
     * @function _userRetrieveNamesComplete
     * @param{int} aError - Error code of the request
     * @param{int} aType - Type of the request
     * @param{int} aRequestId - Request ID of the request
     * @param{obj} aContext - calling class this pointer
     */	
    _userRetrieveNamesComplete: function(aError, aType, aRequestId, aContext) {	  
        try {
            /* Storing the context (issue with model file. it could have passed aContext._context) */
			//@TODO: CR: CRITICAL: Fix correct return of aContext in singupModel
			//   & make necessary changes below
            var currentContext = aContext._context;
            // Hide the progress view as the request has been completed
            currentContext.hideProgress();
            // Enable the softkey here 
            currentContext.enableLSK();

            // Check if the request was retrieve user name availability and the error code is none
            if ( aType == RequestType.requestRetrieveUserNameAvaiability && aError ==  ErrorCode.errorNone ) {
                /* Store the user name suggestions */			
                currentContext._loginIdSuggestions = currentContext.model.fetchAvailableUserNames();

                /* update the status as user name available */
                currentContext._loginIdDetectionState = currentContext._loginIdDetectionStates.StatusNameAvailable;

                /* Check if name suggestions are there */
                if ( currentContext._loginIdSuggestions.length != 0 ) {
                    /* update the status as user name suggestions are there */
                    currentContext._loginIdDetectionState = currentContext._loginIdDetectionStates.StatusNameSuggestions;                
                }

                if ( currentContext._cbContext != currentContext._loginIdCbContext.ContextNextButtonPressed ) {
                    /* User has not yet pressed the next button
                     * Futher actions are spcific to 'next button press' event.
                     * So Go back!!
                     */
                    return;
                }
                // Display name suggestions or go to next screen
                switch( currentContext._loginIdDetectionState ) {
                    case currentContext._loginIdDetectionStates.StatusNameAvailable:
                        /* Go to next step */
                        currentContext.moveToNextStep(currentContext);
                        break;
                    case currentContext._loginIdDetectionStates.StatusNameSuggestions:
                        /* show popup */
                        currentContext.showUsrNameSuggestionsPopup(currentContext);
                        break;
                    default: 
					   //@TODO: CR: MEDIUM: Use ovi.error
                        ovi.debug("SSOAccDetailsView::_userRetrieveNamesComplete: Unexpected user name state");
                        break;
                }

            } else {
                //Request has failed 			
                var _errorMsg = SSOError.getErrorMessage(aError);
                SSOUIHelper.showError(_errorMsg);
            }
        } catch(ex) {
            //@TODO: CR: MEDIUM: Use ovi.error
            ovi.debug("Unexpected error in SSOAccDetailsView::_userRetrieveNamesComplete");
        }
    },
    
    /**
     * Function to create the display of account details screen.     
     * @function render  
     * @param{obj} aModel - model
     */
    render: function(aModel) {
		ovi.debug("SSOAccDetailsView:render");
        this._super();
        var self = this;
		
		// Fetch the isEmailAccountCreationInitiated value from settings
		// This value is true if "No email" is clicked on Account details screen
		// will be false by default
		this._isEmailAccountCreation = 
		  this.settings.get('isEmailAccountCreationInitiated');
		
		//@TODO: CODE: Use new string codes & values

        // Initialize the call context & LoginId Status
		this._cbContext = this._loginIdCbContext.ContextNone;
        this._loginIdDetectionState = this._loginIdDetectionStates.StatusInit;
        
		//the same view is used for parent & regular sign up process,
		//second time, if the same view is rendered, the initialize method will not be called.
		//So setting the header again.
        var _isParentSignup = this.settings.get('isParentSignUp');
        if(_isParentSignup) {
            this.model = this.getModel("SSOParentSignUp");            
        } else {
            this.model = this.getModel("SSOSignUp");
        }   	

        // Retrieve value of loginId & password if not populated 
        // Add view template based on orientation
        /*var layout = ssoui.utils.SSOUtil.createDivFromHTML(this._fetchLayoutTheme());
        ovi.dom.place(layout, this.viewContainer, "last");*/
        
        ovi.debug("Fetched template");
        
		if(this._isEmailAccountCreation == true) {
			// (during orientation change), then load it from model 
			var loginid = this.model.getOviEmailid().toString();
			
			// Remove the @ovi.com and display
			this._IdValue = loginid.substring(0, loginid.indexOf("@"));
			 
			this._passValue = this.model.getOviEmailPassword();
		}
		else { 
			// (during orientation change), then load it from model 
			this._IdValue = this.model.getEmailid();
			this._passValue = this.model.getPassword();
		}
		
        ovi.debug("Fetched values");

        //Creates the TextInput snippet
        //Set Error if any & hide Header Label
        this._loginIdField = new ssoui.ui.SSOTextInputNew(
            {   HdrLabel:sso_signup_label_email,  
                TextValue:this._IdValue }, 
                this.element1 );
        this._loginIdField.setErrLabelText(this._IdError);

  		// If this is email account creation usecase, then 
		if(this._isEmailAccountCreation == true) {
			// Reduce the width of the textinput field and make sure it is on
			// Left of the TD
			
			// TODO: CR: DO NOT USE _root. use ovi.dom.addClass() instead
			this._loginIdField._root.style.width = "72%";
            this._loginIdField._root.style.cssFloat = "left";
			
			// Create the @ovi.com label
			var label = new ovi.ui.Label({
            text: this.ovimail
            }, this.element1);
			
			// Place this on the right side with some padding on top
			// for proper alignment with the textinput
			
			// TODO: CR: DO NOT USE _root. use ovi.dom.addClass() instead
			label._root.style.cssFloat = "right";
			label._root.style.paddingTop = "35px";
			
			// Set the help text for the ovi email textinput field
            this._loginIdField.setInfoLabelText(sso_ovi_email_help_text);
		}
		
		
		this._loginIdField.addEventHandler(ssoui.ui.SSOTextInputNew.BLUR_EVENT, 
            function(){
				//self._loginIdBlurEvtHandler();
			}); 

        this._loginIdField.addEventHandler(ssoui.ui.SSOTextInputNew.KEYUP_EVENT, 
            function(){
                self._handleUserNameKeyUp();
            });
        
		// If the current case is not Email account creation case, only then
		// Disply "No email" label on the screen
		if(this._isEmailAccountCreation != true) {
			this._noEmailField = new ovi.ui.List({}, this.element2);
		    this._noEmailField.add(new ovi.ui.ItemPane(
		    {
		        title: sso_no_email_string,
		        addition:">",
		        extraClass: "sso_item_pane"
		    }));            
		        
		    // Add the selected event for the forgot password button
		    // SSO Password recovery controller is activated 
		    // when the forgot password button is clicked   
		    this._noEmailField.addEventHandler("selected", function() {
		        // Store the value in settings
				// Its ovi email account creation, so a flag is stored in
				// settings
		        self.settings.set('isEmailAccountCreationInitiated', true);
				
				// Clear the cached data so that we dont see anything entered
				// previously in account registration usecase.
				// This is required since we are using same view for ovi email
				// account creation usecase also.
				// this.clearCacheData();
				
			    // We need to add a step in the middle
	            ovi.publish('initiateEmailAccountCreation');
		         
		    }, this);
		} else {
			if(this._noEmailField) {
				this._noEmailField.setProperty("hidden", true);
			}
		}
		
        // Creates the password input snippet.      
        //Set Error if any & hide Header Label
        this._passField = new ssoui.ui.SSOPasswordInputNew(
            {   HdrLabel: sso_signup_label_password,  
                TextValue:this._passValue }, 
                this.element3);
        this._passField.setErrLabelText(this._passError);
        this._passField.setInfoLabelText(sso_signup_ins_password);
        
        //@TODO: CODE: Add event on PassWordInput.KEYUP_EVENT, "blurred" for the above snippet
        //@TODO: CODE: Add handling for ShowPassword value
		this._showPassField = new ovi.ui.CheckBox(
		  {   text: sso_signup_checkbox_showpassword, checked: this._showPassChecked, extraClass: "sso_checkbox"}, 
		  this.element4);
		
		//@todo make this part of the new password input control.
		this._showPassField.addEventHandler("selected", function() {
            if(this._showPassField.getProperty("checked")) {            	
            	this._passField.sso_TextInputValue._root.type = "text";
            } else {
            	this._passField.sso_TextInputValue._root.type = "password";
            }
        }, this);
		
		this.onOrientationChange();
    },
    
    /**
     * function which will be called once the view is destroyed.
     * @function destroy
     */
    destroy: function() {
    	ovi.debug("Inside SSOAccDetailsView destroy");
    	
        this._loginIdField.destroy();
		this._passField.destroy();
		this._showPassField.destroy();
		
        this._super.apply(this, arguments);
    },
    
    /**
     * @private:
     * Function which will be triggered on keyup in user name field.
     * @function _handleUserNameKeyUp
     */
    _handleUserNameKeyUp: function() {
		this._loginIdField.clearErrorLabel();
    },
    
    /**
     * LSK handler for this screen    
     * @function onViewSubmit    
     * @return : True if to proceed further, false to halt on this screen  
     */
    onViewSubmit : function() {
        try {
            //Hide error messages
            this._hideErrorMessages();

            // check the validity of the credentials entered
            if ( !this._validateCredentials(this._isEmailAccountCreation)) {
                /* Either username or password is invalid.
                 * It cannot go forward with an invalid user name or passwd.
                 * Display appropriate error messages and remain in the same view(screen)
                 * Return false so that it remains on the same screen
                 */
                return false;
            }

            /* Valid user name and passwd.
             * Check for the user name status and update the flow
             */
            
            // update the call context
            this._cbContext = this._loginIdCbContext.ContextNextButtonPressed;

            //@todo this is a temp fix to just trigger the status available condition
            this._loginIdDetectionState = this._loginIdDetectionStates.StatusNameAvailable;
            
            switch( this._loginIdDetectionState ) {
                case this._loginIdDetectionStates.StatusInit:
                    // User name status is still in init stage.
                    // It means the 'blurred' event has not occured yet or
                    // user has not edited the user name at all.
                    // But the user name and passwd has been validated already.
                    // Hence do availability check. (Need to wait for the call back before screen transition)                    
                    this.triggerUserNameAvailabilityCheck();
                    break;
                case this._loginIdDetectionStates.StatusNameSuggestions:
                    // there are name suggestions. show popup (No screen transition)
                    // pass the context also as it is a function used from call back also.
                    this.showUsrNameSuggestionsPopup(this);
                    break;
                case this._loginIdDetectionStates.StatusNameAvailable:
				    var emailid = this._loginIdField.getInputText();
					
                    // the user name is available. go to next screen
                    // update the values in model
					
					if(this._isEmailAccountCreation == true) {
						emailid = emailid + this.ovimail;
						
						this.model.setOviEmailid(emailid);
                        this.model.setOviEmailPassword(this._passField.getInputText());
						
					}
					else {
						this.model.setEmailid(emailid);

                        this.model.setPassword(this._passField.getInputText());
					}
			
                    
                    // returns true so that screen transition will happen
                    return true;
                    break;
                default:
				    //@TODO: CR:  MEDIUM: Use ovi.error
                    ovi.debug("SSOAccDetailsView:onViewSubmit: Unexpected case in userName state");
                    // return false to remain in the same screen                   
                    break;
            }
            // By default, user remains on the same screen
            return false;        
        } catch(ex) {
            //@TODO: CR:  MEDIUM: Use ovi.error
            ovi.debug("Unexpected error in SSOAccDetailsView:onViewSubmit");
        }
        // Default behaviour
        return false;
    },
	 
    /**
     * This function is triggered on click of RSK 
     * @function onViewCancel
     */
    onViewCancel : function() {
       if(this._isEmailAccountCreation == true) {
		//this.clearCacheData();
		
		this.settings.set('isEmailAccountCreationInitiated', false);
		ovi.publish('removeEmailAccountCreationStep');
		
	   }
	   
	   return true;
    },
   
    /**
	 * Function, which will be triggered on orientation change
	 * @function onOrientationChange
	 */	
	onOrientationChange: function() {
    	ovi.debug("Inside SSOAccDetailsView onOrientationChange");
    	if (SSOOrientation.Landscape === this.currentOrientation()){
    		if(this._noEmailField) {
    			this._noEmailField.place(this.element3,'first');
    		}
    		this._passField.place(this.element2,'first');
    	} else {
    		if(this._noEmailField) {
    			this._noEmailField.place(this.element2,'first');
    		}
    		this._passField.place(this.element3,'first');
    	}
	}
});