/**
 *
 * Description : A class that extends ssoui.views.SSOBaseView
 *               A page which contains the buttons for Change Password & SignOut.
 * <p>
 * Filename    : SSOAccountManagementView.js
 * <p>
 * Part of     : View
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   11.2.1 %
 * @class SSOAccountManagementView
 * @name  SSOAccountManagementView 
 */

//@TODO: CR: MEDIUM: Update the file header
ovi.provide('ssoui.views.SSOAccountManagementView');
// system includes
ovi.require('ovi.sisu.HTMLView');
ovi.require('ovi.ui.Button');
ovi.require('ovi.ui.Label');
// local includes
ovi.require('ssoui.ui.TextLink'); 
ovi.require('ssoui.utils.SSOUtil', false);
ovi.declare('ssoui.views.SSOAccountManagementView' ,{
    
     /**
     * SSOAccountManagementView extends from ssoui.views.SSOBaseView class.
     * @extends SSOBaseView
     */
    Extends: ssoui.views.SSOBaseView,
    
    /**
     * Calls the init of the base class     
     * @function initialize
     */
    initialize: function() {        
        this._super(sso_acmgmt_title, sso_acmgmt_header_editacsettings, 
		{
			text: sso_button_sk_cancel
		},
		{
			text: ""
		});
        this._contextId = SSOConstant.AccMgtContext;
    },
        
    /**
     * Creates the buttons for the change password, Set/Change Security question
     * and Remember Me. User can perform any of these operations by selecting the 
     * button
     * @function render
     */
    render: function() {
        this._super();
        
        // add change password button 
        this._changepasswordBtn = new ovi.ui.Button({ text: sso_acmgmt_button_changepwd}, this.element1);
        this._changepasswordBtn._root.style.marginTop = "14px";
        this._changepasswordBtn.addEventHandler("selected", function() {
                this._gotoChangePasswordView();
        }, this);
        
        // add security question button
        this._signOutBtn = new ovi.ui.Button({ text: sso_acmgmt_button_signout}, this.element2);
        this._signOutBtn._root.style.marginTop = "14px";
        this._signOutBtn.addEventHandler("selected", function() {
                this._gotoSignOutView();
        }, this);
    },
    
    /**
     * function which will be called once the view is destroyed.
     * @function destroy
     */
    destroy: function() {
    	ovi.debug("Inside SSOAccountManagementView destroy");
    	
    	this._changepasswordBtn.destroy();
    	this._signOutBtn.destroy();
    	
        this._super.apply(this, arguments);
    },
    
    /**
     * Calls the change password controller as the change password 
     * button has been clicked   
     * @function gotoChangePasswordView     
     */
    _gotoChangePasswordView: function () {    
        //Activate the Change password controller
        this.applicationController.activate('SSOAcctMngtChangePassword');        
    },
	
    /**
     * Calls the change/set Security question controller as the Change/Set Security
     * button has been clicked   
     * @function gotosecurityQuestionView      
     */
    _gotoSignOutView: function () {
        //Activate the SignOut controller
        this.applicationController.activate('SSOAcctMngtSignOut');            
    },
       
    /**
     * Cancels the wizard as the user has clicked cancel button
     * @function moveBack
     */
    onLSKClick: function() {
        ovi.publish("movebackaccmgmt");
    }
});