/**
 *
 * Description : A class that extends ovi.sisu.HTMLView
 *               A page which contains the password field to change the current
 *               password 
 * <p>
 * Filename    : SSOAcctMngtChangePasswordView.js
 * <p>
 * Part of     : View
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   10.1.4.2.1 %
 * @class SSOAcctMngtChangePasswordView
 * @name  SSOAcctMngtChangePasswordView 
 */

ovi.provide( 'ssoui.views.SSOAcctMngtChangePasswordView'    );
// system includes

ovi.require( 'ovi.ui.Button'                );
ovi.require( 'ovi.ui.Label'                 );
ovi.require( 'ovi.ui.TextInput'             );

// local includes

ovi.require( 'ssoui.ui.SSOPasswordInput'       ); 
ovi.require( 'ssoui.utils.SSOUtil', false);
ovi.require( 'ssoui.views.SSOBaseView');
ovi.declare( 'ssoui.views.SSOAcctMngtChangePasswordView'    ,{
    
    /**
     * SSOAcctMngtChangePasswordView extends the SSOBaseView class.
     * @extends ovi.sisu.SSOBaseView
     */
      Extends: ssoui.views.SSOBaseView,
    
    /**
     * Calls the init of the base class     
     * @function initialize
     */
    initialize: function() { 
        this._super(sso_acmgmt_title_chagnepwd, sso_acmgmt_header_chagnepwd, 
		{
            text: sso_button_sk_save,
            type: "affirmative"
        },
        {
            text: sso_button_sk_back
        });
        this._contextId = SSOConstant.AccMgtContext;
        
    },
    
    /**
     * Creates two password field for current password and the new password
     * user can save the new password or cancel. 
     * User can activate the view
     * @function render
     */
    render: function() {
          this._super();
        //Get the model to update the data
        this.model = this.getModel();
        //The text label - current password        
        this._currentPasswordTextLabel          = new ovi.ui.Label({ text: sso_acmgmt_label_currentpwd }, this.viewContainer);
        //The text field - current password
		this._currentPasswordTextField          = new ssoui.ui.SSOPasswordInput({value: ""}, this.viewContainer);
		
        
        // adding event handler for clearing error message
        this._currentPasswordTextField.addEventHandler(ovi.ui.PasswordInput.KEYUP_EVENT, function() {            
            // clear the message if any.
			//@TODO: CR: HIGH: Use self instead of this 
            this._currentPasswordTextField.clearMessage();
        },this);
        //The text label - New password 
        this._newPasswordTextLabel              = new ovi.ui.Label({ text: sso_acmgmt_label_newpswd }, this.viewContainer);
        //The text field - New password
		
		this._newPasswordTextField              = new ssoui.ui.SSOPasswordInput({value: ""}, this.viewContainer);        
		
        this._newPasswordTextField.addEventHandler(ovi.ui.PasswordInput.KEYUP_EVENT, function() {
            var _password = this._newPasswordTextField.getProperty("value");
            var _strength = this.model.passwordStrength(_password);        
            //this._newPasswordTextField.setPasswordStrength(_strength);
            // clear the message if any.
            this._newPasswordTextField.clearMessage();
        },this);        
        
        this._newPasswordTextField.displayShowPassword(true);                                        
        //this._newPasswordTextField.displayPasswordStrength(true);
    },
     
    /**
     * function which will be called once the view is destroyed.
     * @function destroy
     */
    destroy: function() {
    	ovi.debug("Inside SSOAcctMngtChangePasswordView destroy");
    	
    	this._currentPasswordTextLabel.destroy();
    	this._currentPasswordTextField.destroy();
    	this._newPasswordTextLabel.destroy();
    	this._newPasswordTextField.destroy();
    	
        this._super.apply(this, arguments);
    },
    
    /**
     * When the LSK - Save button is clicked. 
     * Validates the user entry and calls the controller
     * @function onLSKClick
     */    
    onLSKClick: function() {
        // Hide Error popup if any
        SSOUIHelper.hideMessage();
        //Create the error message object to store the error message
        var errormessagescurrentPassword = new Object();
        errormessagescurrentPassword.Message = "";
        var errormessagesnewPassword = new Object();
        errormessagesnewPassword.Message = "";
        
        //Get the model to update the data
        this.model = this.getModel();
        
        //Get the current password from the text field
        var currPswrd = this._currentPasswordTextField.getProperty('value');
        
        //Get the new password from the text field
        var newPswrd = this._newPasswordTextField.getProperty('value');
        
        //Validate the current and the new password entered        
        var validate_currpassword = ssoui.utils.SSOUtil.validatePassword(currPswrd,errormessagescurrentPassword);
        var validate_newpassword = ssoui.utils.SSOUtil.validatePassword(newPswrd,errormessagesnewPassword);
        
        //If the entry is valid then set the data to the model and call the controller
        // to move next        
         if (validate_currpassword  && validate_newpassword) {
            //Set the entered current password to the model
             this.model.setCurrentPswd(currPswrd);
            //Set the entered new password to the model
             this.model.setNewPswd(newPswrd);
             //Move to the next step
             this.applicationController.getController('SSOAcctMngtChangePassword').movenext();
        } else {
            //The current password is invalid. Display an error message
        	if(!validate_currpassword) {
        		this._currentPasswordTextField.setMessage(errormessagescurrentPassword.Message);
        	} else  {
            this._currentPasswordTextField.setMessage("");
            }
        	//The new password is invalid. Display an error message
        	if(!validate_newpassword) {            
        		this._newPasswordTextField.setMessage(errormessagesnewPassword.Message);
        	} else{
            	this._newPasswordTextField.setMessage("");
        	}
        }
    },
    
    /**
     * When the RSK - Cancel button is clicked. 
     * Cancels the screen and moves to the account management screen
     * @function moveBack
     */   
    onRSKClick: function() {
        //Call the account management controller
        this.applicationController.getController('SSOAcctMngtChangePassword').moveback();       
    }

});