/**
 *
 * Description : A class that extends ssoui.views.SSOWizardView
 *               A page which contains the user details for account creation.
 * <p>
 * Filename    : SSOConfirmationView.js
 * <p>
 * Part of     : View
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   17.2.3 %
 * @class SSOConfirmationView
 * @name  SSOConfirmationView 
 */

ovi.provide('ssoui.views.SSOConfirmationView' );
// system includes
ovi.require('ovi.ui.Button' );
ovi.require('ovi.ui.Label' );

// local includes
ovi.require('ssoui.views.SSOWizardView' );
ovi.require('ssoui.ui.SSOTextInputNew' );
ovi.require('ssoui.ui.SSOImageLink' );

ovi.declare('ssoui.views.SSOConfirmationView', {
    
    /**
     * SSOConfirmationView extends the SSOWizardView class.
     * @extends ssoui.views.SSOWizardView
     */
    Extends: ssoui.views.SSOWizardView,
    
    /**
     * Creates the objects needed for this controller
     * @function initialize
     */
    initialize: function() {        
	 	this._super(sso_security_title_securitycheck, sso_security_header_securitycheck01, 
        {
            text: sso_button_sk_continue,
            type: "affirmative"
        },
        {
            text: sso_button_sk_back
        }); 
	 	
	 	this._imageFetch = "";
	 	this._captchaText = "";
    },
   
    
    /**
     * 
     */
    _showImageLoading: function() {
    	//this._imageFetch ;
    },
    
    /**     
     * Retrieved the Captcha Image from the backend
     * @private
     * @function retCaptchaImage     
     */       
    _retCaptchaImage: function() {        
        // clearing already filled in captcha code
        // clear any error message if already displayed
        //this._captchaTextField.setInputText("");
        this._captchaTextField.clearErrorLabel();
        //Display the progress bar as the request has been sent.
        this.showProgress();
        this._captchaimageLink.setImage(this._imageFetch);
        
        //Disable the LSK & RSK
        this.disableLSK();
        this.disableRSK();
		var _regObj = this.applicationController.getRegObj();

		// Get image of Potrait size. This will be stretched into the 
		// landscape mode
		try {
			// @TODO: width of 418 gives a distorted image.
			//_regObj.retrieveCaptchaImage(this._onCaptchaFinish, 418, 70, this);
			_regObj.retrieveCaptchaImage(this._onCaptchaFinish, 320, 70, this);
		}
		catch(exception) {
			ovi.error("Exception in SSOConfirmationView.js" + 
					exception + "  -  " + exception.message);
			this._onCaptchaFinish(ErrorCode.errorGeneralError, 
					RequestType.requestRetrieveCaptchImage, null, this);
		}
    },
    
    /**     
     * Callback API when the Captcha retrieval is completed
     * @private 
     * @function onCaptchaFinish     
     * @param {aError} - Error code of the API
     * @param {aType} - Request type
     * @param {aRequestId} - the request ID of the API call. [Not used]
     * @param {aContext} - this pointer context of the calling API
     */ 
    _onCaptchaFinish: function(aError, aType, aRequestId, aContext) {
    	ovi.debug("_onCaptchaFinish:Error:" + aError);
        //Hide the progress bar 
        aContext.hideProgress();
        //Enable the LSK
        aContext.enableLSK();
        //Enable the RSK
        aContext.enableRSK();    
        
        aContext._imageFetch = "";
        
        if( aType == RequestType.requestRetrieveCaptchImage && 
        		aError == ErrorCode.errorNone) {        
            try {
                var captchaImagePath = aContext.applicationController.getRegObj().captchaImage(); 	
			}
			catch(exception) {
                ovi.error("Exception in SSOConfirmationView.js" +  
                		exception + "  -  " + exception.message);
				this.showErrorView();
				return;
			}      
			ovi.debug("_onCaptchaFinish:Image:" + captchaImagePath);
	        aContext._imageFetch = captchaImagePath;

            //aContext._captchaimageLink.setProperty('src', aContext._imageFetch); 
	        aContext._captchaTextField.setInputText("");
            aContext._captchaimageLink.setImage(aContext._imageFetch);
        } else {
			this.showErrorView();
        }        
    },
    
   /**
     * Renders the view. Called from Controller.Activate     
     * @function render
     */
    render: function(aModel) {
    	ovi.debug("inside SSOConfirmationView render");
    	
    	this.model = aModel;    	
    	
    	this._super();
    	
    	var self = this;

		// Add view template based on orientation
        /*var layout = ssoui.utils.SSOUtil.createDivFromHTML(this._fetchLayoutTheme());
        ovi.dom.place(layout, this.viewContainer, "last");*/      
		
        this._subTitleTextLabel = new ovi.ui.Label({ 
        	text: sso_security_header_securitycheck02 }, this.elementContainer, "first"); 
        this._subTitleTextLabel._root.className = "sso_header_Label";
        this._subTitleTextLabel._root.style.display = "block";
        this._subTitleTextLabel._root.style.paddingBottom = "15px";
        this._subTitleTextLabel._root.style.paddingTop = "15px";
        
        //Below height & widgth are hard-coded here for (a) requesting appropriate
        // dimension of the image.
		var _imageWidth = 0;
		var _imageHeight = 70;
		
        if (SSOOrientation.Landscape === this.currentOrientation()){
            _imageWidth = 380;
        }else {
            // Potrait
            _imageWidth = 418;
        }
		
        this._captchaimageLink = new ovi.ui.SSOImageLink({
        	width: _imageWidth, height: _imageHeight}, 
        	this.element1);
        this._captchaimageLink.setImage(this._imageFetch);
		
        this._captchaimageLink.addEventHandler("selected", function() {
            //hide error message if any
            //SSOUIHelper.hideMessage();
            self._imageFetch = "";
            self._retCaptchaImage();
        }, this);    
               
         //Label for click image to refresh
        this._imageRefresh = new ovi.ui.Label({ 
        	text: sso_signup_textlink_refreshimage }, 
        	this.element1);
        
        
        this._captchaTextField = new ssoui.ui.SSOTextInputNew(
            {   HdrLabel:sso_security_label_securitycheck,  
                TextValue: this._captchaText }, 
            this.element2);
        this._captchaTextField.setInfoLabelText(".");
        
        // Load captcha image only if it is not loaded. Avoid reload
        // on Orientation change
        if(this._imageFetch == ""){
            this._retCaptchaImage();
        }
        
        this.onOrientationChange();
    },
    
    
    /**
     * function which will be called once the view is destroyed.
     * @function destroy
     */
    destroy: function() {
    	this._subTitleTextLabel.destroy();
    	this._captchaimageLink.destroy();
    	this._imageRefresh.destroy();
    	this._captchaTextField.destroy();
    	
        this._super.apply(this, arguments);
    },
    
    /**
     * Validate if the field is empty of not. 
     * @function: onViewSubmit
     * @return: TRUE: Transition to next screen
     * 			FALSE: stay in the same screen
     */
    onViewSubmit : function() {
		// clear any error message if already displayed
		this._captchaTextField.setErrLabelText("");
		var isFieldEmpty =  ssoui.utils.SSOUtil.isEmpty(this._captchaTextField.getInputText());
		if(isFieldEmpty)
		{
			this._captchaTextField.setErrLabelText(sso_msg_0029);
			return false;
		}else{
			this._captchaText = this._captchaTextField.getInputText();
			//@todo modify the signup & forgot password models to have same 
			//setter & getter methods for captcha.			
			if(this.model.setCaptcha) {
				this.model.setCaptcha(this._captchaText);
			} else {
				this.model.setCaptchcode(this._captchaText);
			}
	    	return true;
		}
    },
    
    /**
	 * Function, which will be triggered on orientation change
	 * @function onOrientationChange
	 */	
	onOrientationChange: function() {
    	//@note now the width is controller by css
    	if (SSOOrientation.Landscape === this.currentOrientation()){
    		//this._captchaimageLink.setProperty("width",380);
    		//this._captchaimageLink._root.style.width = "380px";
        } else {
        	//this._captchaimageLink._root.style.width = "418px";
        	//this._captchaimageLink.setProperty("width",418);
        }
    }
	
	// not required below, as we trigger navigation back to previous screen
	/*
	onViewCancel: function(){
	},
	*/	
});