/**
 *
 * Description : A class that extends ovi.sisu.Model
 *               Maintains the wizard for the signin usecase 
 * <p>
 * Filename    : SSOForgotPasswordView.js
 * <p>
 * Part of     : View
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   16.1.1 %
 * @class SSOForgotPasswordView
 * @name SSOForgotPasswordView 
 */

//@TODO: CR: MEDIUM: File header description block is not talking about PR
ovi.provide('ssoui.views.SSOForgotPasswordView');
// system includes
ovi.require('ovi.sisu.HTMLView');
ovi.require('ovi.ui.Button');
ovi.require('ovi.ui.Label');
ovi.require('ovi.ui.Image');

// local includes
ovi.require('ssoui.ui.SSOTextInputNew');
ovi.require('ssoui.ui.SSOMobileInput');
ovi.require('ssoui.ui.TextLink');
ovi.require('ssoui.utils.SSOUtil', false);
ovi.require('ssoui.views.SSOWizardView');
ovi.require('ssoui.ui.SSOImageLink');
ovi.declare('ssoui.views.SSOForgotPasswordView'    ,{

	//@TODO: CR: MEDIUM: Documentation missing for extends    
	Extends: ssoui.views.SSOWizardView,

  /**
   * Consructor
   * @function  initialize
   */
  initialize: function() {
    this._super(sso_signin_title_noproblem, sso_pwdrecovery_label_verifymobilenooremail, {
        text: sso_button_sk_continue,
        type: "affirmative"
    }, {
        text: sso_button_sk_back
    });
  },
  
  /**
   * Overriden render function
   * @function  render
   */
  render: function() {

    this._super();
    
    var _self = this;
    
    this.model = this.getModel('SSOForgotPassword');
    
    //Creates the TextInput snippet
    //Set Error if any & hide Header Label
    this._emailField = new ssoui.ui.SSOTextInputNew(
        {   HdrLabel:sso_signup_label_email, }, 
            this.element1 );
    this._emailField.setErrLabelText(this._IdError);
    this._emailField.addEventHandler(ssoui.ui.SSOTextInputNew.KEYUP_EVENT,
    	function() {
	    	var _emailValue = _self._emailField.getInputText();
			if(ssoui.utils.SSOUtil.isEmpty(_emailValue)) {
				_self._mobileNumberField.setProperty("disabled", false);
			} else {
				_self._mobileNumberField.setProperty("disabled", true);	
			}
    	}
    );    		
    
	this._mobileNumberField = new ssoui.ui.SSOMobileInput({
			"headerLabel":sso_signup_label_mobilenumber,
			"infoLabel":sso_signup_label_mobilenoformat
		}, this.element2);
 
	this._mobileNumberField.addEventHandler(ssoui.ui.SSOMobileInput.KEYUP_EVENT, 
        function(){
			var _mobileValue = _self._mobileNumberField.getProperty("value");
			if(ssoui.utils.SSOUtil.isEmpty(_mobileValue)) {
				_self._emailField.setProperty("disabled", false);
			} else {
				_self._emailField.setProperty("disabled", true);	
			}
        }
	);
    
	/*this._helpImage = new ovi.ui.Image({src:"images/help_button.png"}, this.element2);
	this._helpImage._root.style.float = "left";
	this._helpImage._root.style.paddingLeft = "20px";*/
	
	this._emailField.setInputText(this.model.getEmail());
	this._mobileNumberField.setProperty("countryCode", this.model.getCountryCode());
	this._mobileNumberField.setProperty("mobileNumber", this.model.getMobileNumber());
  },
  
  /**
   * function which will be called once the view is destroyed.
   * @function destroy
   */
  destroy: function() {
	this._emailField.destroy();
	this._mobileNumberField.destroy();  
	  
	this._super.apply(this, arguments);
  }, 
  
 
  
  /**
   * This funciton validates the mobile or email field, and then publishes if everything is valid
   * @function  render
   */
  onViewSubmit : function() {	
	var _mobileNumber = this._mobileNumberField.getProperty("value"); 
	var _validMobileNumber = ssoui.utils.SSOUtil.validateMobileNumber(_mobileNumber);
	var _validEmail =  ssoui.utils.SSOUtil.validateEmailId(this._emailField.getInputText());
	
	if(_validEmail == false && _validMobileNumber == false) {
		return false;
	}
	
	if(_validEmail) {
		this.model.setEmail(this._emailField.getInputText());
	}
	
	if(_validMobileNumber) {
		this.model.setCountryCode(this._mobileNumberField.getProperty("countryCode"));
		this.model.setMobileNumber(this._mobileNumberField.getProperty("mobileNumber"));
	}
	
	return true;
  },
  
  //@TODO: CR: MEDIUM: Below method is private. Use prefix "_"
  /**
   * @private
   * This funciton validates the mobile or email field, and then publishes if everything is valid
   * @function  validateEmailOrMobileNumber
   */
  validateEmailOrMobileNumber: function(aEmailOrMobileNumber) {
  
    //aEmailOrMobileNumber has to be either a valid Email or a valid mobile number, 
    // If it is not either of these then we have an invalid Email or mobile number 
    if(ssoui.utils.SSOUtil.validateEmailId(aEmailOrMobileNumber) == true || ssoui.utils.SSOUtil.validateMobileNumber(aEmailOrMobileNumber) == true) {
      return true;
    }
    
    return false;
  },
  
  //@TODO: CR: MEDIUM: Function description block is missing
  onViewCancel: function() {
	  return true;
	  //ovi.publish('SSOPRVerificationBack');
	  //this.applicationController.back();
  }
});