/**
 *
 * Description : A Dialog class that extends ssoui.views.SSOBaseView.
 *              A View that contains launching dialog & post signin
 *              branding dialog
 * <p>
 * Filename    : SSOLaunchDialogView.js
 * <p>
 * Part of     : View
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2010 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOLaunchDialogView
 * @name  SSOLaunchDialogView 
 * @version %version:   %
 */

ovi.provide( 'ssoui.views.SSOLaunchDialogView' );

// system includes
ovi.require( 'ovi.sisu.HTMLView' );
ovi.require( 'ovi.ui.Button' );
ovi.require( 'ovi.ui.Label' );
ovi.require( 'ovi.ui.List' );
ovi.require( 'ovi.ui.TextInput' );
ovi.require( 'ovi.ui.ItemPane' );
//ovi.require( 'ovi.ui.CheckBox' );

// local includes
ovi.require( 'ssoui.views.SSOBaseView' );
ovi.require( 'ssoui.ui.SSOTextInputNew' );
ovi.require( 'ssoui.ui.TextLink' ); // Required for buttons--??
ovi.require( 'ssoui.ui.SSOPasswordInputNew' ); 
ovi.require( 'ssoui.utils.SSOUtil', false );
ovi.declare( 'ssoui.views.SSOLaunchDialogView', {
    
    /**
     * SSOSignUpView extends the SSOBaseView class.
     * @extends ssoui.views.SSOBaseView
     */
	Extends: ovi.sisu.SnippetView,
    
    /**
     * Creates the objects needed for this controller
     * @function initialize
     */
    initialize: function() {
        //Setup the view the header, sub-header & softkeys(lsk, rsk).
        this._super();
        this.template = '<div id=signInDialog class="SSOLoadingDialogPosition"></div>';
    },
    
    /**
     *  Constructs the snippet required by the dialog control
     *  @function constructSnippet
     *  @returns {object} A snippet object which the dialog control uses
     */
    _constructLoadingIndicatorSnippet: function(messageText) {
        
        // A table consisting of an nokia logo, a message, progressbar
        // is contructed in this snippet.
        
        return new ovi.ui.Snippet({
            template: '<div class = "SSOLoadingDialogStyle">'+
            '<table>' +
                '<tr><td>' + 
                    '<img src="./images/ovinokia_logo.png" align="left">' +
                 '</td></tr>' +
                '<tr><td align="left">'+
                    '<div data-bind-ref="messageNode" data-bind-text="message"'+
                    ' class="ovi_Dialog_message">'+
                    '</div>'+
                '</td></tr>' +
                '<tr><td>'+
                    '<div align = "left"'+
                    ' data-bind-snippet="ssoui.ui.SSOProgressBar:progressBar">'+
                    '</div>'+
                '</td></tr>' +
            '</table>' +
             '</div>',
        message: messageText
        });
    },
		
   /**
     * Renders the view. Called from Controller.Activate     
     * @function render
     */
    render: function() {
        var self = this;
        
        // Draw the base view
        this._super();

        // Construct the snippet which would be fed to the Dialog control
		var displayString ;
		
        var state = this.applicationController.settings.get('ssoServiceState');
        if (state == 'Launching')
        {
            // display loading dialog
            displayString = sso_loading_indicator_text;
        }else if (state == 'SignInDone')
        {
            // display logged in dialog
			//@TODO: CODE: Have message in two  lines
			displayString = sso_signin_popup_connected01 + sso_signin_popup_connected02;
			var self = this;
        }
				
        var snippet = this._constructLoadingIndicatorSnippet(displayString);
  
        // Dialog is instantiated with the snippet
        // Hack the dialog with a dummy button to hide the same.
        // We are hiding the buttons since we need just need a popup
        // which communicates that an operation is going on            
        this._loadingdialog = new ovi.ui.Dialog({body: snippet, buttons: {text:""}
            }, ovi.byId("signInDialog"));
		
        // Start the progressbar inside the dialog
        snippet.progressBar.start();      
    },
    
    /**
     * function which will be called once the view is destroyed.
     * @function destroy
     */
    destroy: function() {   
            
        this._loadingdialog.close(); 
        this._super.apply(this, arguments);
    },
    
    /**
     * Cache data populated in this view. Use the same 
     * data when re-drawn on orientation change. 
     * This function must be called only when the orientation is getting changed.
     * @function cacheViewData
     * @return none
     */
    cacheViewData: function(){
    },
    
    /**
     * Clear cache view data. This function must be called when deleting a
     * view & no residual information is required.
     * @function clearCacheData
     * @return none
     */
    clearCacheData: function(){
    }  
});