/**
 *
 * Description : A class that extends ssoui.views.SSOWizardView
 *               A page which contains the user details for account creation.
 * <p>
 * Filename    : SSOParentalConsentView.js
 * <p>
 * Part of     : View
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   11.1.5.1.2 %
 * @class SSOParentalConsentView
 * @name  SSOParentalConsentView 
 */

ovi.provide('ssoui.views.SSOParentalConsentView');
// system includes
ovi.require('ovi.sisu.HTMLView');
ovi.require('ovi.ui.Button');
ovi.require('ovi.ui.Label');
ovi.require('ovi.ui.TextInput');
ovi.require('ovi.ConsoleLogger');

// local includes
ovi.require('ssoui.views.SSOWizardView');
ovi.require('ssoui.ui.SSOTextInput');
ovi.require('ssoui.ui.TextLink');
ovi.require('ssoui.ui.SSOPasswordInput'); 
ovi.require('ssoui.utils.SSOUtil',false);
ovi.require('ssoui.ui.SSORadioGroupDialog');
ovi.declare('ssoui.views.SSOParentalConsentView', {
    
    //@TODO: CR: MEDIUM: Documentation missing on extends
    Extends: ssoui.views.SSOWizardView,
    
    //@TODO: CR: MEDIUM: Documentation missing for function description
    initialize: function() {
		var _model = this.getModel("SSOParentSignUp");
		var _parentInstructions = ssoui.utils.SSOUtil.replaceString(sso_signup_label_parentinstructions, _model.getUsername());	
		
		this._super(sso_signup_title_childreview, _parentInstructions,
        {
            text: sso_button_sk_finish,
            type: "affirmative"
        }, {
            text: sso_button_sk_cancel
        });
    },
    
    //@TODO: CR: MEDIUM: Documentation missing for function description
    render: function(aModel) {
		//@TODO: CR: HIGH: Why do below code needs try-catch?
    	try {
	    	//console.log('inside SSOParentSignUpView render');
	    	this._super();
	    	
	    	this.model = aModel;
	    	
	    	 this._emailIdField = new ssoui.ui.SSOTextInputNew(
	    	            {   HdrLabel:sso_signup_label_email }, 
	    	                this.element1 );
	    	 
	       
	        
	        this._mobileNumberField = new ssoui.ui.SSOMobileInput({
				"headerLabel":sso_signup_label_mobilenumber,
				"infoLabel":sso_signup_label_mobilenoformat
			}, this.element2);
	        
	        this._parentApprovalLabel = new ovi.ui.Label({ text: sso_signup_label_parentapprovalmessage, extraClass: "sso_subheader_Label" }, this.viewContainer);        
	       
	        //Populate childs information to the controls
	        var _regInfo = this.settings.get("childRegisterationInfo");
	        this._emailIdField.setInputText(_regInfo.emailAddress);
	        this._mobileNumberField.setProperty("countryCode",_regInfo.countryCode);
		    this._mobileNumberField.setProperty("mobileNumber",_regInfo.mobileNumber);		    
    	} catch(ex) {
			//@TODO: CR: HIGH: Use ovi.error for exceptions
            ovi.debug("Exception in render of parentconsent view  " +  ex + "  -  " + ex.message);
            var _errorMsg = SSOError.getErrorMessage(ErrorCode.errorOperationFailed);
            SSOUIHelper.showError(_errorMsg);
    	}
    },
    
    /**
     * function which will be called once the view is destroyed.
     * @function destroy
     */
    destroy: function() {
    	ovi.debug("Inside SSOParentalConsentView destroy");

    	this._emailIdField.destroy();    	
    	this._mobileNumberField.destroy();
    	this._parentApprovalLabel.destroy();
    	
        this._super.apply(this, arguments);
    },
    
    //@TODO: CR: MEDIUM: Documentation missing for function description
    onViewCancel: function() {
    	this.settings.set("isParentDenied", true);
        // parent is already signed in We need to sign out so that child cannot continue with parent details.
        this.model = this.getModel('SSOSignIn')     
		try {
	    	this.model.removeCachedData();   
	        this.model.signOut();
		    ovi.publish("cancelParentConsent");		    
		} catch(ex) {
		    ovi.debug("Exception in onViewCancel of parentconsent view  " +  ex + "  -  " + ex.message);
		    SSOUIHelper.showSystemError(this.applicationController,sso_msg_0020);	
		}               	
		return false;
    },
    
    /**
     * 
     * @function onViewSubmit
     * @returns {Boolean} true, if the data points are valid else false.
     */
    onViewSubmit: function() {
    	try { 
    		this.settings.set("isParentApproved", true);
    		
            var validEmaiId = this.validateModifiedEmailId();
            var validMobileNum = this.validateModifiedMobileNumber();            

            if(validEmaiId && validMobileNum ) {                
                // We are not sure about the availability of this user name.
                // somebody else might have registered with the same name by this time.
                // so avilability of the same should be checked.
                //return this.checkUserNameAvailability(userNameText);
            	
            	// Populate the necessary information onto model.
                var _gtoken = this.applicationController.getRegObj().guardianToken();
                this.model.setGurdiantoken(_gtoken);
                this.model.setEmailid(this._emailIdField.getInputText());
                this.model.setMobilenumber(this._mobileNumberField.getProperty("mobileNumber"));        
                var _regInfo = this.settings.get("childRegisterationInfo");
                this.model.setPassword(_regInfo.password);
                //this.model.setCountry(_regInfo.country);
                this.model.setCountry(this._mobileNumberField.getProperty("countryCode"));
                ovi.debug(_regInfo.dob);
                this.model.setDOB(_regInfo.dob); 
                this.model.setLanguage(_regInfo.languagestring); 
                return true;
            }            
           
            if( !validEmaiId ) {                
                //this._emailIdField.setMessage(sso_msg_0009);
            }

            if( !validMobileNum ) {                
                //this._mobileNumberField.setMessage(sso_msg_0010);
            }
            
            // Remain on the same screen
            return false;
    		
    	} catch(ex) {
            ovi.debug("Exception in onViewSubmit of parentconsent view  " +  ex + "  -  " + ex.message);
            var _errorMsg = SSOError.getErrorMessage(ErrorCode.errorOperationFailed);
            SSOUIHelper.showError(_errorMsg);
    	}
        ovi.debug('Unexpected false return in onViewSubmit of SSOParentalConsentView');
    	return false;
    },

    //@TODO: CR: MEDIUM: Below method is private.Use Prefix "_"
    /**
     * Function to restore the softkeys      
     * @function restoreSoftKeys
     * @param{obj} aContext - calling class this pointer
	 * 
     */	
    restoreSoftKeys: function(aContext) {        
	   //@TODO: CR: CRITICAL: Don't we need to hide progressBar?      
        //Enable the softkeys here
        aContext.enableLSK();
        aContext.enableRSK();
    },
        
    //@TODO: CR: MEDIUM: Below method is private.Use Prefix "_"
    /**
     * Function to validate the mobile number      
     * @function validateModifiedMobileNumber    
     * @return {Boolean} true on success, false on failure
     */	
    validateModifiedMobileNumber: function() {         
        // Retrive the details filled by child
        var _regInfo = this.settings.get("childRegisterationInfo");
        // current mobile number as appear on the screen
        var mobileNumText = this._mobileNumberField.getProperty("value");

        if(mobileNumText != _regInfo.mobilePhoneNumber) {                       
            return ssoui.utils.SSOUtil.validateMobileNumber(mobileNumText);
        }
        
        return true;
    },
    
    //@TODO: CR: MEDIUM: Below method is private.Use Prefix "_"
    /**
     * Function to call the model function for checking availability of user name.     
     * @function validateModifiedEmailId  
     * @param{String} userNameText - username
     * @return {Boolean} true on success, false on failure
     */	
    checkUserNameAvailability: function(userNameText) {        
        // invoke the model function and register call back function also.
        this.model.retrieveUsernameAvailability(this._childRetrieveNamesComplete, userNameText, this);
        // disabling the soft keys
        this.disableLSK();
        this.disableRSK();
        // show a progress bar for better user experience.
        this.showProgress();        
        // Remain in the same screen... 
        // will move to the next screen from the call back function '_userRetrieveNamesComplete'
        return false;  
    }, 

    //@TODO: CR: MEDIUM: Below method is private.Use Prefix "_"
     /**
     * Function to validate the email id      
     * @function validateModifiedEmailId    
     * @return {Boolean} true on success, false on failure
     */	
    validateModifiedEmailId: function() {          
        // Retrive the details filled by child
        var _regInfo = this.settings.get("childRegisterationInfo");
        // current email id as appear on the screen
        var emailIdText = this._emailIdField.getInputText();

        if(emailIdText != _regInfo.emailAddress) {                        
            return ssoui.utils.SSOUtil.validateEmailId(emailIdText);
        }        
        return true;
    },

    /**
     * Callback API when the user name availablity is checked from parent consent screen      
     * @function _childRetrieveNamesComplete
     * @param{int} aError - Error code of the request
     * @param{int} aType - Type of the request
     * @param{int} aRequestId - Request ID of the request
     * @param{obj} aContext - calling class this pointer
     */	
    _childRetrieveNamesComplete: function(aError, aType, aRequestId, aContext) {		
        //Hide the progress view as the request has been completed
		//@TODO: CR: CRITICAL Fix model to return correct context (ie. self)
		//    & not encapsulated as aContext._context
        aContext._context.hideProgress();              
	
        // Check if the request was retrieve user name availability and the error code is none
        if((aType == RequestType.requestRetrieveUserNameAvaiability) && (aError ==  ErrorCode.errorNone)) {           
            // create an array to store user names
            var usernames = new Array();
            // store the user name suggestions into the array.
            usernames = aContext._context.model.fetchAvailableUserNames();           

            // show the popup if there suggestions.
            // the selected data will be used as the user name.
            if(usernames.length != 0) {
                // There are name suggestions. Display that.. 
                // Display a radio button dialog                            
                var dialog = new ssoui.ui.SSORadioGroupDialog({labels: usernames, titlemessage: sso_signup_popup_title, headingmessage: sso_signup_unames_label_pickunamefromlist}, aContext._context.viewContainer);
                // Add an event handler to get the data. 
                dialog.addEventHandler(ssoui.ui.SSORadioGroupDialog.CLOSE_EVENT, function (e) {
					//@TODO: CR: CRITICAL Use !== instead of !=
                    if(typeof e.data != 'undefined') {
                        // update the user name field
                        ovi.dom.byId('childnametextfield').value = e.data;                        
                    }                    
                });                 
            } else {                              
                /* Move to next step */
                aContext._context.moveToNextStep();
            }

        } else {
            //Request has failed 
            //Display an error
            //this.isretrievalsuccess = false;
            var _errorMsg = SSOError.getErrorMessage(aError);
            SSOUIHelper.showError(_errorMsg);
        }
        // Default action is to remain in the same screen.
        // Enable soft keys
		//@TODO: CR: MEDIUM: Do we really a function call here?
        aContext._context.restoreSoftKeys(aContext._context);
    }
});