/**
 *
 * Description : A class that extends ssoui.views.SSOBaseView
 *               A page which contains the user details for sign-in 
 *				 and a button to create account and forgot password	
 * <p>
 * Filename    : SSOSignUpView.js
 * <p>
 * Part of     : View
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @class SSOSignUpView
 * @name  SSOSignUpView 
 * @version %version:   %
 */

ovi.provide( 'ssoui.views.SSOSignUpView' );

// system includes
ovi.require( 'ovi.sisu.HTMLView' );
ovi.require( 'ovi.ui.Button' );
ovi.require( 'ovi.ui.Label' );
ovi.require( 'ovi.ui.List' );
ovi.require( 'ovi.ui.TextInput' );
ovi.require( 'ovi.ui.ItemPane' );
//ovi.require( 'ovi.ui.CheckBox' );

// local includes
ovi.require( 'ssoui.views.SSOBaseView' );
ovi.require( 'ssoui.ui.SSOTextInputNew' );
ovi.require( 'ssoui.ui.TextLink' ); // Required for buttons--??
ovi.require( 'ssoui.ui.SSOPasswordInputNew' ); 
ovi.require( 'ssoui.utils.SSOUtil', false );
ovi.declare( 'ssoui.views.SSOSignUpView', {
    
    /**
     * SSOSignUpView extends the SSOBaseView class.
     * @extends ssoui.views.SSOBaseView
     */
    Extends: ssoui.views.SSOBaseView,
    
    /**
     * Creates the objects needed for this controller
     * @function initialize
     */
    initialize: function() {
		
		var _title = sso_signin_title;
		var _header = sso_signin_header_noasignup;
		var _isParentSignUp = this.settings.get("isParentSignUp");
		if(_isParentSignUp) {
			_title = sso_signup_title_guardiansignin;
			_header = sso_signup_label_helloparent4;
		}
		
		//Setup the view the header, sub-header & softkeys(lsk, rsk).
        this._super(_title, _header, 
		  {
			text: sso_button_sk_signin,
			type: "affirmative"
		  },
		  {
		  	text: sso_button_sk_cancel
		  });

		  		  
        //this._contextId = SSOConstant.SignUpContext;
		this._loginValue = "";
		this._loginError = "";
		this._passValue = "";
		this._passError = "";
    },
    
   /**
     * Renders the view. Called from Controller.Activate     
     * @function render
     */
    render: function() {
		var self = this;
		
		var _title = sso_signin_title;
		var _header = sso_signin_header_noasignup;
		var _isParentSignUp = this.settings.get("isParentSignUp");
		if(_isParentSignUp) {
			_title = sso_signup_title_guardiansignin;
			_header = sso_signup_label_helloparent4;
		}
		
		this._title = _title;
	    this._header = _header;
	        
		// Draw the base view
    	this._super();

        // Add view template based on orientation
		/*var layout = ssoui.utils.SSOUtil.createDivFromHTML(this._fetchLayoutTheme());
		ovi.dom.place(layout, this.viewContainer, "last");*/
		
    	/*
    	 * The same view is used for Guardian Sign-Up also.
    	 *
    	 */
		if(_isParentSignUp) {
			this._signupHeaderLabel = new ovi.ui.Label({ text: sso_signin_header_noasignup },  this.elementContainer, "first");
			this._signupHeaderLabel._root.style.display = "block";
			this._signupHeaderLabel._root.style.paddingTop = "15px";
			this._signupHeaderLabel._root.style.paddingBottom = "15px";
		}
		
		//Creates the TextInput snippet
        //Set Error if any & hide Header Label
		this._loginId = new ssoui.ui.SSOTextInputNew(
            {   HdrLabel:sso_signin_label_userid, maxLength: "32", 
			    TextValue:this._loginValue }, 
            this.element1);
		this._loginId.setErrLabelText(this._loginError);
		
        // Creates the password input snippet.		
        //Set Error if any & hide Header Label
		this._passField = new ssoui.ui.SSOPasswordInputNew(
            {   HdrLabel: sso_signin_label_password, maxLength:"18", 
			    TextValue:this._passValue }, 
			    this.element2);
        this._passField.setErrLabelText(this._passError);
		
        // Forgot password Link (ItemPane within List)			
        this._forgotPassword = new ovi.ui.List({}, this.element3);
        this._forgotPassword.add(new ovi.ui.ItemPane(
        {
            title: sso_button_forgotpassword,
            addition:">",
            extraClass: "sso_item_pane"
        })); 			
        
		// Add the selected event for the forgot password button
		// SSO Password recovery controller is activated 
		// when the forgot password button is clicked	
        this._forgotPassword.addEventHandler("selected", function() {
            self.applicationController.activate("SSOForgotPasswordWizard");  
        }, this);
		
		// Create Account Link (ItemPane with List)
        this._createAccButton = new ovi.ui.List({}, this.element4);
        this._createAccButton.add(new ovi.ui.ItemPane( {
            title: sso_button_createnoa,
            addition:">",
            extraClass: "sso_item_pane"
        }));

		// Add the selected event for the create account button
		// SSO Create Account Wizard controller is activated 
		// when the create account button is clicked	
        this._createAccButton.addEventHandler("selected", function() {
            self.settings.set("onWizardCancel", "SSOSignUp");
            
			// Fetch the model object, required for calling the
			// getConsentQueryVariant API
			var _model = this.getModel("SSOSignUp");
			
			// Initiate the marketing consent fetch operation, this is an
			// asynchronous call
			_model.getConsentQueryVariant
			(self._getConsentQueryVariantComplete, self);
			
            self.applicationController.activate("SSOAccCreateWizard");        	
        }, this);
        
        this.onOrientationChange();
    },
    
	/**
     * The callback which is fired on completion of aynchronous 
     * getConsentQueryVariant call
     * @function _getConsentQueryVariantComplete
     * @param {object} aError This object contains the error info
     * @param {string} aType This string contains the request type
     * @param {number} aRequestId This number has the request id
     * @param {object} aContext The calling context, this is the context
     *                          from which the original async API was called
     */
	_getConsentQueryVariantComplete: function(aError, aType, 
	                                           aRequestId, aContext) {
											   	

		var _signupmodel = aContext.getModel();;
		var _consentvalue;
		
		// Check if the request was  
		// and the error code is none then 
		if (aError == ErrorCode.errorNone) {
			// Synchronous call to fetch the consent value
			_consentvalue = _signupmodel.getConsent();
		}
		else {
			//TODO: we need to decide the default consent value if there is 
			// an error currently defaulted to implicit consent
			_consentvalue = ConsentQueryVariant.QueryVariantImplicit;
		}
		_signupmodel.setConsentValue(_consentvalue);
	},
	
    /**
     * function which will be called once the view is destroyed.
     * @function destroy
     */
    destroy: function() {   
	
        ovi.debug("SSOSignUpView:deactivate");    
 	
		//Destroys the controls created
		this._loginId.destroy();
		this._passField.destroy();
    	this._forgotPassword.destroy();		
        this._createAccButton.destroy();
		       
        this._super.apply(this, arguments);
    },
    
    /**
     * Function handler for the LSK ("SignIn" for this view)
     * @function onLSKClick
     * @return {boolean} true: If transitioning to next screen
     *                   false: Validation failed. stay in same screen
     */
    onLSKClick: function() {
		// Clear all error cached / displayed on UI
		this._loginError = "";
		this._passError = "";
		this._loginId.clearErrorLabel();
		this._passField.clearErrorLabel();
		
		//Create the error message object for the LoginId & password
		var errMsgLoginId = new Object();
        errMsgLoginId.Message = "";
        var errMsgPassword = new Object();
        errMsgPassword.Message = "";

		// Read the LoginId & Password value. 
        this._loginValue = this._loginId.getInputText();
        this._passValue = this._passField.getInputText();

        // Store the value in the Model, on publish of success,
		// Model can read this value for authentication       
    	this.model = this.getModel("SSOSignIn");
    	this.model.setUsername(this._loginValue);
    	this.model.setPassword(this._passValue);
		
		// validate the inputs. LoginId can be either UserName / Email Address
    	var _isValidLoginId = false;
    	if (ssoui.utils.SSOUtil.isEmpty(this._loginValue) || this._loginValue.length < 4){
			errMsgLoginId.Message = sso_msg_username_short;
    	}else {
            _isValidLoginId = ssoui.utils.SSOUtil.validateUserName(this._loginValue,
  		          errMsgLoginId);
	  		if(_isValidLoginId == false){
	  			_isValidLoginId = ssoui.utils.SSOUtil.validateEmailId(this._loginValue, errMsgLoginId);
	        }
	  		// If validation has failed for wrong input, show a generic error
	  		if (_isValidLoginId == false){
	  			errMsgLoginId.Message = sso_msg_username_invalid;
	  		}
    	}
		
		//Validate the password entered by the user	
        var _isValidPassword = ssoui.utils.SSOUtil.validatePassword(this._passValue,
		          errMsgPassword);
		
		// If both username and password entrered are valid. then publish the signin event
		// Else display error & stay in the same screen
		if (_isValidLoginId == true && _isValidPassword == true) {    
			// Always use setRmbrMe as true
			// Publish success of local validation & perform signIn (SSOSignUpController)
			this.model.setRmbrMe(true);
			ovi.publish("onSignInClick");
			return true;
		} else {
			// Local validation failed. Display error
        	if(_isValidLoginId == false) {				
        		this._loginId.setErrLabelText(errMsgLoginId.Message);
			}        	
        	if(_isValidPassword == false) {
        		this._passField.setErrLabelText(errMsgPassword.Message);
        	}
			return false;
        }
    },
    
	/**
     * Function handler for the RSK ("Cancel" for this view)
     * @function onRSKClick
     * @return: {boolean} true: 
     *                    false:
     */
    onRSKClick: function() {
		//Publish the cancel event click
		//The event will be handled in the SSO Signup controller
    	ovi.publish("onCancelClick");
    },
    
    /**
	 * Function, which will be triggered on orientation change
	 * @function onOrientationChange
	 */	
    onOrientationChange: function() {
    	if (SSOOrientation.Landscape === this.currentOrientation()){
    		this._createAccButton.place(this.element3, "first");
    		this._forgotPassword.place(this.element4, "first");
    	} else {
    		this._createAccButton.place(this.element4, "first");
  		  	this._forgotPassword.place(this.element3, "first");
    	}
    }
});