/**
 *
 * Description : A class that extends ssoui.views.SSOWizardView
 *               A page which contains the user details for account creation.
 * <p>
 * Filename    : SSOTOSView.js
 * <p>
 * Part of     : View
 * <p>
 * ============================================================================
 * <p>
 * Copyright (C) 2008 Nokia.  All rights reserved.
 * <p>
 * This material, including documentation and any related computer
 * programs, is protected by copyright controlled by Nokia.  All
 * rights are reserved.  Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the
 * prior written consent of Nokia.  This material also contains
 * confidential information which may not be disclosed to others
 * without the prior written consent of Nokia.
 * <p>
 * ============================================================================
 * @version %version:   22.1.4 %
 * @class SSOTOSView
 * @name  SSOTOSView 
 */

ovi.provide('ssoui.views.SSOTOSView');
// system includes
ovi.require('ovi.sisu.HTMLView');
ovi.require('ovi.ui.Button');
ovi.require('ovi.ui.Label');
ovi.require('ovi.ui.TextInput');
ovi.require( 'ovi.ui.CheckBox');
// local includes

ovi.require('ssoui.views.SSOWizardView');
ovi.require('ssoui.ui.SSOTextInput');
ovi.require('ssoui.ui.TextLink');
ovi.require('ssoui.ui.SSOPasswordInput'); 
ovi.require('ssoui.utils.SSOUtil',false);
ovi.require('ssoui.ui.SSOUIHelper');
ovi.declare('ssoui.views.SSOTOSView', {
    
    Extends: ssoui.views.SSOWizardView,
    
    initialize: function() {		
		ovi.debug("Inside TOSView initialize");
        // check whether this is signin TOS update scenario or normal signup TOS view.
        // the below mentioned setting is set to true only by signin API callback.
        // i.e sign in from View controller is the owner to set it to true.
        var isTOSUpdated = this.applicationController.settings.get('signintosupdate');        
        if (isTOSUpdated ==true)
		{
			this._super(sso_signup_title, sso_signup_header_termsprivacyupdate, 
	        {
	            text: sso_button_sk_accept,
	            type: "affirmative"
	        },
	        {
	            text: sso_button_sk_cancel
	        });         
		}        
        else{
	        this._super(sso_signup_title, sso_signup_header_termsprivacy, 
	        {
                text: sso_button_sk_accept,
                type: "affirmative"
            },
            {
                text: sso_button_sk_cancel
            });
			
		}
    },
    
    /**
     * Function to render the View.
     * @function render
     */
    render: function(aModel) {
        //  set tos update the variable to false  so that it is flushed and ready to use for next time. 
        // no one except sign in callback from view controller can set it to true.
        this.applicationController.settings.set("signintosupdate",false); 
    	try {
    		this._isSignIn = true;
    		if(typeof aModel != "undefined") {
    			this._isSignIn = false;
    		}
    		
	    	var aHideAcceptedTosLink = this.applicationController.settings.get("HasAcceptedTos");
	    	var aHideAcceptedServiceSpecificTosLink = this.applicationController.settings.get("HasAcceptedServiceSpecificTos");
	    	var aHideAcceptedPrivacyPolicyLink = this.applicationController.settings.get("HasAcceptedPrivacyPolicy");	  	    
	
	    	this.model = this.getModel("SSOTOS");
	    	
	    	this._super();
	    	
	    	  this._headingTextLabel._root.style.display = "block";
	    	  this._headingTextLabel._root.style.paddingBottom = "14px";
	    	  
	        // First textlink  
	    	this._toslink1 = new ovi.ui.TextLink({ text: sso_signup_textlink_oviserviceterms1}, this.viewContainer);
          	this._toslink1._root.style.display = "inline";                    
          	this._toslink1.addEventHandler("selected", function() {
	          //ovi.publish('toslink');
	          this._openTOSLink();
	        }, this);
	      
	        // Second textlink
	        this._toslink2 = new ovi.ui.TextLink({ text: sso_signup_textlink_oviserviceterms2}, this.viewContainer);
	        this._toslink2._root.style.display = "inline";                
	        this._toslink2.addEventHandler("selected", function() {
	        	//ovi.publish('servicespecifictoslink');
	        	this._openServiceSpecificTOSLink();
	        }, this);
	        
	        // Label 'and'
	        this._andtextlabel = new ovi.ui.Label({ text: sso_signup_label_oviserviceterms3 }, this.viewContainer);
	        this._andtextlabel._root.style.display = "inline"; 
	            
	        // Third textlink
	        this._toslink3 = new ovi.ui.TextLink({ text: sso_signup_textlink_oviserviceterms4 }, this.viewContainer);
	        this._toslink3._root.style.display = "inline";        
	        this._toslink3.addEventHandler("selected", function() {
	        	//ovi.publish('privacypolicylink');
	        	this._openPrivacyPolicyLink();
	        }, this);
	        
	        // I accept.. checkbox
	        this._termsacceptance  = new ovi.ui.CheckBox({
	                                                value: sso_signup_label_oviserviceterms5,
	                                                text: sso_signup_label_oviserviceterms5,    
	                                                checked: false    
	                                            }, this.viewContainer);
	          
                                             
	        this._termsacceptance.addEventHandler("selected", function() {
                if(this._termsacceptance.getProperty("checked")) { 
                    // When user selects the checkbox, "LSK" should be enabled.
                    // But if the user has already pressed "LSK", progressbar will be shown 
                    // and no more LSK presses expected.               
                    // In other words, Progressbar and LSK excludes each other.
                    if (this._progressBar.getProperty('hidden') == true ) {
                        this.enableLSK();
                    }
                } else {
                    this.disableLSK();
                }
	        }, this);
	        
	        this.disableLSK();
	        
    	} catch(ex) {
    		//todo show system error.
    	}
    },
    
    /**
     * function which will be called once the view is destroyed.
     * @function destroy
     */
    destroy: function() {
    	
    	this._toslink1.destroy();
    	this._toslink2.destroy();
    	this._andtextlabel.destroy();
    	this._toslink3.destroy();
    	this._termsacceptance.destroy();
    	
        this._super.apply(this, arguments);
    },
    
    /**
     * Function to open TOS link.
     * @function _openTOSLink
     */
    _openTOSLink : function() {
    	try {
	    	var _tosModel = this.getModel("SSOTOS");
	    	
	    	// If first hyperlink in the TOS screen is clicked then it is subscribed here
	        // If URL is not already retrieved then this.tosgeneralurl will be 'undefined'
	        if(typeof this.tosgeneralurl == "undefined") {
	        
	          // We are setting this flag to mark that we have started retrieving first hyperlink
	          this.istosgeneralurl = true;
	          // begin the retrieval (Refer SSOWizardViewController for this function definition)
	          _tosModel.retrieveTermsOfService(this._fetchTOSLinks, this);
	        }
	        else {
	          // If the URL has previously been retrieved from clicks on other hyperlinks then we directly open
	          // the retrieved URL
	          // to launch the web application to display ovi.com.  need to provide appid of Web.
              //@TODO: CR: CRITICAL: Avoid hardcoding of App-Id. Move them to 
              //         some configuration file  
              try {
			  	 var appmanagementObj= this.applicationController.getAppMgmtObj();                
                 appmanagementObj.launch({appid: "0x10008D39"}, ovi.service.ApplicationManagement.prototype.runtime.NATIVEPLATFORM, {docname: this.tosgeneralurl});
			  }
			  catch(exception) {
			  	ovi.error("Exception in SSOTOSView.js" +  exception + "  -  " + exception.message);
			  }
	        }
    	} catch(ex) {
			//@TODO: CR: CRITICAL: Use ovi.error
            ovi.debug("Exception in _openTOSLink of TOS view  " +  ex + "  -  " + ex.message);
    	}
    },
    
    _openServiceSpecificTOSLink : function() {
        var _tosModel = this.getModel("SSOTOS");
    	// If second hyperlink in the TOS screen is clicked then it is subscribed here
        // If URL is not already retrieved then this.servicespecificurl will be 'undefined'
        if(typeof this.servicespecificurl == "undefined") {
          // We are setting this flag to mark that we have started retrieving second hyperlink
          // in TOS screen
          this.isservicespecificurl = true;
          // begin the retrieval (Refer SSOWizardViewController for this function definition)
          _tosModel.retrieveTermsOfService(this._fetchTOSLinks, this);
        }
        else {
          // If the URL has previously been retrieved from clicks on other hyperlinks then we directly open
          // the retrieved URL
		  
		  try {
			var appmanagementObj= this.applicationController.getAppMgmtObj();                
			//@TODO: CR: CRITICAL: Avoid hardcoding of App-Id. Move them to 
			//         some configuration file              
			appmanagementObj.launch({appid: "0x10008D39"}, ovi.service.ApplicationManagement.prototype.runtime.NATIVEPLATFORM, {docname: this.servicespecificurl});
		  }
		  catch(exception) {
		  	ovi.error("Exception in SSOTOSView.js" +  exception + "  -  " + exception.message);
		  }
          
        }
    },
    
    _openPrivacyPolicyLink : function() {
        var _tosModel = this.getModel("SSOTOS");
    	// If third hyperlink in the TOS screen is clicked then it is subscribed here
        // If URL is not already retrieved then this.servicespecificurl will be 'undefined'
        if(typeof this.privacypoilicyurl == "undefined") {
          // We are setting this flag to mark that we have started retrieving third hyperlink 
          // in TOS screen
          this.isprivacypoilicyurl = true;
          // begin the retrieval (Refer SSOWizardViewController for this function definition)
          _tosModel.retrieveTermsOfService(this._fetchTOSLinks, this);
        }
        else {
			
			try {
				// If the URL has previously been retrieved from clicks on other hyperlinks then we directly open
				// the retrieved URL
				var appmanagementObj= this.applicationController.getAppMgmtObj();    
				//@TODO: CR: CRITICAL: Avoid hardcoding of App-Id. Move them to 
				//         some configuration file              
				appmanagementObj.launch({appid: "0x10008D39"}, ovi.service.ApplicationManagement.prototype.runtime.NATIVEPLATFORM, {docname: this.privacypoilicyurl});
			}
			catch(exception) {
				ovi.error("Exception in SSOTOSView.js" +  exception + "  -  " + exception.message);
			}
        }
    },
    
    /**
     * Callback of retrieveTermsOfService(), fired on completion of retrieval
     * @function _fetchTOSLinks
     * @param {object} aError Structure that contains error information
     * @param {object} aType Request type  	 
     * @param {object} aRequestId Request Id
     * @param {object} aContext context from which original API was called 
     */
     _fetchTOSLinks: function(aError, aType, aRequestId, aContext) {
    	try {
	       // Fetch all terms of service links -- function definition is in 
	       // SSOWizardViewController base class
	       var toslinks = aContext.getTOSLinks(aError, aType, aRequestId, aContext);
	       
	       // Fill up all the url properties
	       aContext.tosgeneralurl      = toslinks.tosgeneralurl;
	       aContext.servicespecificurl = toslinks.servicespecificurl; 
	       aContext.privacypoilicyurl  = toslinks.privacypoilicyurl;
	       
	       var appmanagementObj= aContext.applicationController.getAppMgmtObj();
	       
	       // We are checking the flag to make sure we open the URL which was clicked, based on 
	       // the flag
		   
		   //@TODO: CR: HIGH: A Generic method in SSOUTil can be written
		   //     to launch app with a given URL
          //@TODO: CR: CRITICAL: Avoid hardcoding of App-Id. Move them to 
          //         some configuration file              
		   
	       if(typeof aContext.istosgeneralurl != "undefined" && aContext.istosgeneralurl == true) {	    	   
	    	   appmanagementObj.launch({appid: "0x10008D39"}, ovi.service.ApplicationManagement.prototype.runtime.NATIVEPLATFORM, {docname: aContext.tosgeneralurl});
	       }
	       else if(typeof aContext.isservicespecificlink != "undefined" && aContext.isservicespecificlink == true) {	    	   
	    	   appmanagementObj.launch({appid: "0x10008D39"}, ovi.service.ApplicationManagement.prototype.runtime.NATIVEPLATFORM, {docname: aContext.servicespecificurl});
	       }
	       else if(typeof aContext.isprivacypoilicylink != 'undefined' && aContext.isprivacypoilicylink == true) {	    	   
	    	   appmanagementObj.launch({appid: "0x10008D39"}, ovi.service.ApplicationManagement.prototype.runtime.NATIVEPLATFORM, {docname: aContext.privacypoilicyurl});
	       }
    	} catch(ex) {
			//@TODO: CR: CRITICAL: Use ovi.error
    		  ovi.debug("Exception in _fetchTOSLinks of TOS view  " +  ex + "  -  " + ex.message);
    	}
     },
     
     /**
      * Function to get the TOS links.
      * @function getTOSLinks
      */
     getTOSLinks: function(aError, aType, aRequestId, aContext) {
	    var _tosModel = this.getModel("SSOTOS");
	    var toslinks = _tosModel.getTOSLinks(aError, aType, aRequestId, aContext);
	    return toslinks;
	  },
    
     /**
      * This function will be triggered on view is submitted.
      * @function onViewSubmit
      */
    onViewSubmit : function() {
		ovi.debug("Inside onViewSubmit");  
    	//if the TOS is launched from signin then publish updatetermsstatus message 
    	if(this._isSignIn) {
    		this.showProgress(true);
			this.disableLSK();
			this.disableRSK();
    		ovi.debug("publish updatetermsstatus");
    		ovi.publish("updatetermsstatus");
    		return false;
    	} else {
    		 ovi.debug("Signin is false");
             var tos =  this._termsacceptance.getProperty("checked");
             if( tos == true) {
                return true; 
            } else {
                SSOUIHelper.showError(sso_msg_0032);
                return false;
            }
        }    	
    },
    
    /**
     * This function will be triggered on click of RSk.
     * @function onViewCancel
     */
    onViewCancel : function() {
    	//if the TOS is launched from signin then publish closewidget message
    	if(this._isSignIn) {
    		ovi.publish("closewidget");
    	} else {
    		ovi.publish("cancelWizard");
    	}	
    	return false;
    }
    
});